(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    125110,       2293]
NotebookOptionsPosition[    115946,       2116]
NotebookOutlinePosition[    121926,       2240]
CellTagsIndexPosition[    121254,       2218]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Method of Exhaustion", "Title",
 CellChangeTimes->{{3.842012315152514*^9, 
  3.842012342398947*^9}},ExpressionUUID->"b9e6fe14-67c5-4f7d-9ec0-\
13c361826e91"],

Cell[TextData[{
 "Initialization Code",
 StyleBox[" (optional) ", "SectionGloss"],
 Cell[BoxData[
  TemplateBox[{"Initialization Code", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{"Provide any code that must be evaluated before the ", 
          StyleBox["Manipulate", "MRbig"], 
          ". This will automatically be built into the ", 
          StyleBox["Manipulate", "MRbig"], 
          " in the final notebook version. Never use a package that is not \
included in the default distribution of ", 
          StyleBox["Mathematica", FontSlant -> "Italic"], 
          ". To use a package, use the ", 
          StyleBox["Initialization", "MRbig"], " option (with ", 
          StyleBox["Get", "MRbig"], ", not ", 
          StyleBox["Needs", "MRbig"], ") in the ", 
          StyleBox["Manipulate", "MRbig"], 
          " itself, and use the full name of the function from the package. \
For example:\n", 
          StyleBox[
          "  Manipulate[\n  ...\n  ComputationalGeometry`ConvexHull[...]...\n \
 ...\n  Initialization :> Get[\"ComputationalGeometry`\"],\n  ...\n  ]", 
           "MR"], "\nIf you provide initialization code, include a ", 
          StyleBox["SaveDefinitions->True", "MRbig"], " option in the ", 
          StyleBox["Manipulate", "MRbig"], ".", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "81fde376-e763-44cf-83ed-5c52ec315067"]
}], "InitializationSection",
 CellTags->
  "Initialization \
Code",ExpressionUUID->"1d34a731-8c48-4189-8b6f-89ef5777db9f"],

Cell[CellGroupData[{

Cell[TextData[{
 "Manipulate",
 Cell[BoxData[
  TemplateBox[{"Manipulate", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{"This section contains the ", 
          StyleBox["Manipulate", "MRbig"], 
          " input cell and its evaluated output cell. Make all control labels \
or labels in the output as descriptive as possible, with only proper nouns \
and proper adjectives capitalized. More description of the controls can be \
provided in the Details section below, if necessary. If you change this ", 
          StyleBox["Manipulate", "MRbig"], 
          " after creating screenshots and/or thumbnails, use ", 
          StyleBox["Update Thumbnail & Snapshots", FontWeight -> "Bold"], 
          " in the toolbar to update any copies in later sections. You can \
control the Flash preview for the Demonstration with the ", 
          StyleBox["AutorunSequencing", "MRbig"], " option. Use ", 
          StyleBox["SaveDefinitions->True", "MRbig"], 
          " if you provided initialization code in the previous section."}], 
        "MoreInfoText"], Background -> GrayLevel[0.95], FrameMargins -> 20, 
       FrameStyle -> GrayLevel[0.9], RoundingRadius -> 5]], "MoreInfoText", 
     Deletable -> True, CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "d12d57a6-93e6-4518-8a9c-9df2eb688354"]
}], "ManipulateSection",
 CellTags->
  "Manipulate",ExpressionUUID->"b7acceb9-ca4b-4965-b319-bd8a6214a587"],

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"attribution", "=", 
     GraphicsBox[
      TagBox[RasterBox[CompressedData["
1:eJztnQdYVVfW929i7C2CIpbYwBABG1LEith7F7tYECtSBRUUNRrsFJWigggo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        "], {{0, 30.}, {154., 0}}, {0, 255},
        ColorFunction->RGBColor,
        ImageResolution->{144, 144}],
       BoxForm`ImageTag[
       "Byte", ColorSpace -> "RGB", Interleaving -> True, MetaInformation -> 
        Association[
         "Exif" -> Association[
           "Software" -> 
            "Created with the Wolfram Language : www.wolfram.com", "DateTime" -> 
            DateObject[{2020, 9, 11, 10, 7, 17.}, "Instant", "Gregorian", 
              4.294967292*^9], "TimeZoneOffset" -> 4294967292], "Comments" -> 
          Association[
           "Software" -> 
            "Created with the Wolfram Language : www.wolfram.com", 
            "Creation Time" -> 
            DateObject[{2020, 9, 11, 10, 7, 17.}, "Instant", 
              "Gregorian", -4.]]]],
       Selectable->False],
      DefaultBaseStyle->"ImageGraphics",
      ImageSizeRaw->{154., 30.},
      PlotRange->{{0, 154.}, {0, 30.}}]}], "}"}], ",", "\[IndentingNewLine]", 
   
   RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"circleColor", "=", 
       RowBox[{"RGBColor", "[", 
        RowBox[{"0.540383", ",", "0.518196", ",", "0.014786"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"polygonColor", "=", 
       RowBox[{"Purple", "//", "Lighter"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"thickness", "=", 
       RowBox[{"Thickness", "[", "0.0025", "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"vertices", "=", 
       RowBox[{"DeleteDuplicates", "[", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Cos", "[", "k", "]"}], ",", 
            RowBox[{"Sin", "[", "k", "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"k", ",", "0", ",", 
            RowBox[{"2", "\[Pi]"}], ",", 
            RowBox[{"2", 
             RowBox[{"\[Pi]", "/", "n"}]}]}], "}"}]}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"polyArea", "=", 
       RowBox[{
        FractionBox["1", "2"], "n", 
        SuperscriptBox[
         RowBox[{"(", "1", ")"}], "2"], 
        RowBox[{"Sin", "[", 
         FractionBox[
          RowBox[{"2", "\[Pi]"}], "n"], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"circArea", "=", "\[Pi]"}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"Graphics", "[", 
       RowBox[{
        RowBox[{"{", "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"EdgeForm", "[", 
             RowBox[{"{", 
              RowBox[{"thickness", ",", "Black"}], "}"}], "]"}], ",", 
            RowBox[{"FaceForm", "[", "circleColor", "]"}], ",", 
            RowBox[{"Disk", "[", "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"EdgeForm", "[", 
             RowBox[{"{", 
              RowBox[{"thickness", ",", "Black"}], "}"}], "]"}], ",", 
            RowBox[{"FaceForm", "[", "polygonColor", "]"}], ",", 
            RowBox[{"Polygon", "[", "vertices", "]"}]}], "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"n", ">", "3"}], "&&", "showTriangles"}], ",", 
            RowBox[{"{", 
             RowBox[{"thickness", ",", 
              RowBox[{"Line", "/@", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0"}], "}"}], ",", "#"}], "}"}], "&"}], 
                 "/@", "vertices"}], ")"}]}]}], "}"}], ",", "Nothing"}], 
           "]"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"Style", "[", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"Text", "[", 
             RowBox[{
              RowBox[{
              "\"\<\!\(\*SubscriptBox[\(A\), \(circ\)]\) = \
\[Pi](1\!\(\*SuperscriptBox[\()\), \(2\)]\) \[TildeTilde] \>\"", "<>", 
               RowBox[{"ToString", "[", 
                RowBox[{"N", "[", 
                 RowBox[{"\[Pi]", ",", "6"}], "]"}], "]"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"1.85", ",", "0.6"}], "}"}]}], "]"}], ",", 
            "\[IndentingNewLine]", "14", ",", "circleColor"}], 
           "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"Style", "[", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"Text", "[", 
             RowBox[{
              RowBox[{
              "\"\<\!\(\*SubscriptBox[\(A\), \(poly\)]\) =  \[TildeTilde] \
\>\"", "<>", 
               RowBox[{"ToString", "[", 
                RowBox[{"N", "[", 
                 RowBox[{"polyArea", ",", "6"}], "]"}], "]"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"1.85", ",", "0"}], "}"}]}], "]"}], ",", 
            "\[IndentingNewLine]", "14", ",", "polygonColor"}], 
           "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"Style", "[", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"Text", "[", 
             RowBox[{
              RowBox[{
              "\"\<\[Epsilon] = |\!\(\*SubscriptBox[\(A\), \(circ\)]\) - \!\(\
\*SubscriptBox[\(A\), \(poly\)]\)| \[TildeTilde] \>\"", "<>", 
               RowBox[{"ToString", "[", 
                RowBox[{"N", "[", 
                 RowBox[{
                  RowBox[{"circArea", "-", "polyArea"}], ",", "2"}], "]"}], 
                "]"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"1.85", ",", 
                RowBox[{"-", "0.6"}]}], "}"}]}], "]"}], ",", 
            "\[IndentingNewLine]", "14"}], "\[IndentingNewLine]", "]"}], ",", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"Inset", "[", 
           RowBox[{"attribution", ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.1"}], ",", 
              RowBox[{"-", "1.5"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"Automatic", ",", ".25"}], "}"}]}], "]"}]}], 
         "\[IndentingNewLine]", "\[IndentingNewLine]", "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1.1"}], ",", "2.9"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1.5"}], ",", "1.1"}], "}"}]}], "}"}]}]}], "]"}]}], 
     ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"n", ",", "3", ",", "15", ",", "1", ",", 
       RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}], ",", 
       RowBox[{"AnimationRate", "\[Rule]", "0.7"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"showTriangles", ",", "False"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"True", ",", "False"}], "}"}]}], "}"}]}], 
    "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{
  3.842011651108673*^9, {3.842011733240135*^9, 3.842011738782467*^9}, {
   3.842011787449421*^9, 3.842011790142973*^9}, {3.8420148124950743`*^9, 
   3.842014823729822*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"1c8a51fe-61b3-446f-b3f3-b27c622b6763"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Caption",
 Cell[BoxData[
  TemplateBox[{"Caption", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{
         "The caption provides all the information needed to understand the \
Demonstration. It should be between three and five sentences long, but \
clarity is more important than length. Include only text in this section \
\[LongDash] no code, graphics, etc. Do not change the cell style or copy \
cells from other sections. Do not copy text from books or the web. Write your \
ideas in your own words. If you want to refer to something on the web, link \
to it in the Details.", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "a97b5d36-1c59-4018-b3f0-6bfc71662d3d"]
}], "ManipulateCaptionSection",
 CellTags->"Caption",ExpressionUUID->"3ed78bfd-4459-4d2a-906f-3e9e6aba33a4"],

Cell["\<\
Approximating the area of a circle using the Method of Exhaustion.\
\>", "ManipulateCaption",
 CellChangeTimes->{{3.842012116056075*^9, 
  3.8420121715597153`*^9}},ExpressionUUID->"71921e4e-c8c2-4f05-96e3-\
4e3047349e9a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Thumbnail",
 Cell[BoxData[
  TemplateBox[{"Thumbnail", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{
         "To create the thumbnail, copy and paste the output cell from the ", 
          
          StyleBox["Manipulate", "MRbig"], 
          " section and adjust the controls to the most visually appealing \
setting. Do not convert it to a bitmap. The thumbnail is what visitors see \
when browsing the Demonstrations site and while the Flash preview loads.", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "5363174b-397a-4e31-b8e5-95e1af887bc9"]
}], "ThumbnailSection",
 CellTags->"Thumbnail",ExpressionUUID->"401cc3c4-8319-4e19-82e7-df5fcb711a42"],

Cell[BoxData[Cell[GraphicsData["PDF", "\<\
9E14ARda;S<:9LCUl^G[Yo>Pd<C62S<P<21_HVX:?3`P;dIYK7AULR0_AVaQM6E4
IF=_I6DP;daUKVMdJ20h<CTP?Sh:LgAbIF5]2WP1[EI=Cm]04;g_[iPTO3Q8;?_]
GJWR0:XZ8OF0/=A3jBUZQBZXA3WdkoO]Qnde93FQ919hWIgW=c=_g_ZA[^VA1;kJ
2E;Jd>o_m8EnTN21oY2R:m9LFOY<IiM?TSI?n<4JXE/K;jBGg^=2B==jjmWC9Vnk
_4V@PVh^PBkChSCnR`oH?93dPD:PO=5J;UDPf@I^5EW5UOI<>/FMTJ@]ecK@QZBa
_7D:XMahTTYagdY:<?7W0Q9:O=VFXmT8TX;c8a0k187;1^/N]CbS?;545dI/<c`R
4nkYiiARIR1Kj<GE@3a_ka<KhD[R`khHDlDWKWMSbBi>d;:a6@hOjm03SHobC?1b
Yni5OjoOQNeUenh6/M`PiKRG:;_VASRj9jaSchgS8_Qa;JgT@BSLT7f4=m`6Pc]g
K>SgALomm@[YhA81mSH2HoE^T]jWRVA@99;=nNHfg]>fSE6j`lH9;fBI0]PD^@ih
G[RI1k2bObc/C<2F`/N8Z1Cfkk4UB6GKU5id46nIGD<B_KBHNMHmd5WG@A;DoJ1V
/JK^9gg/]]@eIPn<`8<>a^Z<=:bDd6Ae@@=lAU^^iP4[DTX11:BXNf0PiGZHFE8e
QSHln9`LL>S/Td@KTM/78H@lWd^_AS8AZBLDZn@bD[?LRi11TMX93Qb?_JkJ=AgK
PXjKl4T5H/eZU/o@YgPfW0h[iC@QBiD:eGFVi7L`ReOcJRO5cSf;aEKWK4I;=HZg
dkIe7JXDnoJEV^EZ3FK=hV1aN;BVKmAMIHW^m<gA4KL<@cB8jC0X:DS2k]i[5R@l
Gl0_Whg3hM7aKK=GJ@gV<_5jncPTeJ2D9Kej6]ANdn2RS7/nLAY`[9On74>0j<ob
]/5g3OE/JE7bRbgMb;K2:RU4Ji8h1??`SW[B/g@5EjeRGGbm68a>XA5`nAj`LYEI
UMNTU<8[U1^9_HMUJZS>nQLbFNc[VSKRi7Z=7WFhUm0LcW^HiPRC3`Cf7`L2g^MB
M/nlIOlQ29?dTQiH<m^lR@H2[7>7Z_Ib:BfbUhme6TgZ99]DW81j07HMaM68HLE`
WU?YL>@Y7OmV1i9R6:d5cQZ<e^X0MJ]Q[ol2PPI]0@YUKVAcM79UHFd:IFiTKf9Z
2S4P<21_HVX:?3`P;eAiL6DP;e1QIfDP;e1QLVE^M20b830PDR0_DVEcKgEbHfEc
83@P<21B82m3KfidIFidLb0c830PDR0_CFETJF52KgPPFc0P<20c=S0P<S<dG@X_
@g9_L49_N21K=Rhd=S@b=SPP=34^>C@d<3LP<CTb;SDe<c<P<S8h;S0c<c5M82m2
K6EUI49_N21K<20`83<f<20b<cAM82mDLVU]@Vmh2U/`830P<cH`838c=5dP;d5b
M49_N21K<20`83<f<20b<cAM82mBKgAQM6DP<20n?PYUKVA_HVX:=20`86mRJPXl
?20_D79_He=UM21K82m@A4HP;eAUN7@PGB0_@fm/Kg9CL65SIB0l?20_@g<a83DP
<21B83hn82m6Kfid83`l82mDE38P=b0`858:;eAD=20i830PDR0_E5@f834a830P
DR0_Ac4P<C8P<21B82mDE3PP<C@P<21B82mDE34`834f830PDR0n?R0n?PYUKVA_
HVX:<CLP<21_HVX:?3`P;dhP<b0_@FadIG9^HGAU82m4IGIYHfEBAd8P;daUKVMd
J20b=S4b82m6JFadIG8P;dI/HGAUA6ESKfAU83hn2W=dLVEQK@Yh0IfFMeACfAJ7
ckdg_M0B8R0Um1Yj2B3B>dPE1569BH1@0XJ49WI41DHD4BUFI5C00DN78V=550^3
PV;G2O8@D<K1DDA5iMf<J`W_[CGcgY[maeWOfNNgemUWkggG^P1@o884`WAH0H0d
XEPDk^_1G18CblCg0QP@0@iH0L3QIVH4AoQ40]Cl_CfIVJQ8a[?fkRj0I;_K;;m@
9W?FognA8SM390H02TGE=San9QOU0YAC/lDI<_l4b_BE:C:6<C8FX@VR[2;Sa:m/
mZOV:k_9V9LVi:4JFLhI_3BNS;]@gYXUhJ><1:5LV2GPIj=l1fFmE4VJ0>Gg:=?C
n9a<030DVEo<ibJQK8TbAA@IkXWb0P08U<@i_78>RoTiJ9h0N:IWi8X4RDURYQ7G
V6WUj<QVn_6cDoUR<B^D`dgQR7Q<coBd38h`5h2_KiI50BEIKIUXTNf]7>g]FMKV
J?VofMlNOU?m?LQjneGa9^c?WT6<WUWOK>b/;kdF0?HTFY/M/kjEE@2dK@I0iN6/
CnlP0?850;CNW?<NQVaNT/CR32L;Rnc/K7<1Wf/^:nPgnin2KlZoQSWgVL_^neHk
YQLoPB=95C=UANFVYjI;A<c<30jGcfCmma3ohl0iJLg9`bbLWl0GlHGXEE7XU0V4
RFRkQCb1F90^I0Z4OmGQOaPf9`LIOYe[56QeG`1mQCU@^4T7b6lm04<S0bA^?gX2
ON]K434:b;jlJ:fA[g>?<W[nioXO2eb:K^5<@B9Ci_H<SfAb9J8/6J?OQ6c10Q:@
1gBP2SB1;S02;60=780cL0?N8024P4P@0iH3;TP2JD04/T4nf00:@C7H0GJ3JW00
e85jd0A>PSI`1U`4El0=L0/<P4M02XK1Bc01gX5Y28;`41FR@JZ@5Z@?VD;F41]J
27U3@E0h50?5@hV@4990nM0VZ1PZPjZQ@e0mm2=d6[X8GH?jX0O@83@6o@5mQ16H
0]=Q3MP0]X3I/3/L24O2bn14N1FL1aO0fn5:^1Hn3[O25n4Kl00/QEo2T`Q0b0P3
dDIH21_aA4:@F2@14B5[TB:T0ZU5VY0>Y1^iSDRALN@31XNQHIPH5/HIhhMIS>5R
EV7FHTX`eIQSV5I<5nHfIQ0cPOV2YF;E/JIH9j`oMPTf4I^=;LAFH8mPFk2G/@?H
HN`k70k7`1WR771n^1QL<Vhe[PBg3mN<^h3[``gQ9_5h_2[N5>n23l5cl69l8Kh:
Oaao7]n?7lJo9i09FPA[PPlQUR0TK2AD41X8i`SmQ172=561Z4md8XH@NLALHRVa
S]Q1_4TL9TjC54V691MB92VI]85DBFXRGBHm9[dQTlTjI4Mb65U0GTn^99lPGbD?
TSm@U2PV54m:74E2fDhiB[U0ND1i@jEB3JQ^e5RZV;ZMFTnmA7e:OBm7Tc>GliOS
bJfCZi5[UN^GNbE?U=NGMiMO;YlWGb5oB_jVo;P2DL50`E>1Xk1FXDKQ]<8mQDU5
VZ:EHXQRVV:9HX?R=LEA9KbBPI:g4TnY@>V`dRFU8AY2djEid[RdCK@jfVGJ<1e7
=jCkdi?YaO@Oj;gd2FDUIE_U:>DLiA[U/lYB1/8`H?PcDQVUS9><^hb?lcCV^LoS
cm/f[fUNok`YUOTZKRYlUB:EIYD1UHnZC5E_eACEWJY]ZToD<6XVJV5ZfF[keBj[
SLnWcgNNcieO=?oTo8OZ/;Z9N[SjJ_G3jSgZTaZJ6[hJ6AYE6YLdaSDIVVjJbI[U
V^LdakAXFP^e15[UF^NeGS2EVNk<E6HU/h/iXJf^kJL]dCjTgJ/m[F>X/eQWXdjc
cQ=MTRiK=d6gG;MCMd9?BbmH;en_DNnQ?U6O[InT_dNoFgo:`=0PfV2;@I_1Z:6:
XKmQWV6ShF<SZY6[dBZSFZ<kaSQS]W6:lCkSFbJ`RIe9TTV=bDeCf=CNE62jckC?
36_VJ2HdZcFkaj:`g5UI[4KFX3W3?<QlXgVKnB/;?H]HRidFgAIO;>d/Dbg[;1mI
:ET5F6fdj[3j`m[4VV]MHgg7QV[SHk?>Y]gV]JfY;Mmf_nem>iYM/=dF^djkcoH>
mR;k9_/a1cf7N8Nm3_OHM7HX^hAmeA7[j>6hc_6<h`LWNbNaddVWgieIcRW>3LjS
2``Gl1OD;AQbdG7Q^1abTBiT;XaON72Qe5GKUN=Jjo[<CMN=igK4KLCMf3gIoKSk
:`m;3i57RlNDYi?W6/l;GXRG[eNAEjngT_MRkf[_Ychj?XTnSChC_WJnZgd_n67m
0_efn]gceo3Wn]OkC`@h1:`9j0ZT14H4EPLn2c894PEe1<?10L6kPQl_dUlTG=@F
0T;l@gJ5?0Te35dEnW<H;R`d[2K/NKQEN7ihM`@]HTE4@lBkB8o8d/Q7RhdFBaIg
A/U7aDGEAde5NdFGAD^GF2aI/nA6S5Z<8:Hm5QlK5G/TMW:Ymm;MBhOSk>8:hnh^
<ebF/ncJL[GUZL_?[Y1O`EUa:QhK7agO4?n94l:YiDb^m5niMnD4ei>kQo^BilH[
ihgaGOQUo944UhBbQ=54UlAMRF=9[TTEBN<2Cd6eh7FbGo:1i:VDT9BS:C>YdJW=
JHBdn;CC@REQR[0[GC<m9kd_`cBS<4>jbVWEkUDCXT3ATD`XLeUV^iR>oTceB8`T
VbF3F@^cJ[;NIdMUWlYAc17Vm>BJi6k;7LWcbO]n=FHeMgEW_WKnQ_c1=Ni[3Zf5
eZiLfkU>Meg1^^7e_^^?KB1]B=W`bdK;SFDKgfj:g]AAX56`_V1X/noVaT:i@U7Q
_Bg>F`i/aF`EK>gMI[>]J]^G8UkAmF;;hX[RCbGLT^_OFGeGnMg<mXC]_JGfYO]g
h7H8MmcMjK[cF9URFEkId:kPGJgUc?:Rl[NkEnbnEV5KLF0?JHmTSk@bZ;:mBZmZ
AmFWjZCZPAZ?V^JmjW^gkIgJam_G_mm]Om<1S@?51chN51blOlSgD6^]@Fg5HMcQ
[<??jj;Z^[mWOemoA>e8lI7?AhE7YLO2SgGE>mCG=jPgU3K2SI;6/N=aafomh?E3
Na>[jE0cXkWh13PQ>O7RaoPOkih<?=UiRWfZjBOmWoJfd5Z:FZ7Fg=J9]Z@fJG]<
NmoYP=>M7LhM;CnKogcdS?JIV[?:Id_?TLhEW9/iWgMnlT;6QO6;RAN7>UMd?[Zd
i=:M[[2^g/^1UjmNlKUbZM^mnoaEUj]W[SUM>gfMOKg]Q_f=eQjkWYIOk7iYjKG_
KKgYL;?mU^>]S[h5ONOjGO/_g_JjONF>oidK0h/6n^h^_W_oG]`mjGgNoM47Z@mN
?laj>?eXoF?/hj8W2TlZWZXo[OgEn=MVZKgdk:3GH<ncR6N?Q[Q3;onEnJm?``G?
ZLl[A[A6jTN]Aln<nHcMN[7daO3;S9OChhFo:OjfmiGAZimnMo^mIf;9a?1[dN^I
?d[NZ;hin]KfKNMTj>CCMfW_YZN:gZ^n?oJ1oJ7kHoC7TNW/CoQ?UIn=?gMl2Ocb
N2I]I^KOmhCcn`YUKVAcM79UHFd:IFiTKf9Z2SDP<21_HVX:Fb0_BD=3@V5cIF@P
<CLP<21B85d:IFiTKf9Z2S8P<21_HVX:?3`P;eAiL6DP;e1QIfEc82m=IFAYHD9_
N21K<20`83Ha<R0g>C9M82m3KgE^M20a82m;JFAc85/P<B0`858PGB0n?PYUKVA_
HVX:<CPP<21_HVX:?3`P;eAiL6DP;d=QM65/KfLP;e1QIfEc838P<21B83hn2VE^
I6mRJPXg830PKf9Z2S`l82mDNG1U82m6Kfid82mCMF9dNG1U82mDLWEUE7U`IB0_
@V5cIDI_KW@P;d51@D51@b]VKfid<30`<30`<30b=c0f<V@gHR0_AVm^M4AULf=b
JG1dKg8:<CTP<21B82mDKeE^JF=_I6DP<S0P<21B82m6JG9cM4=XHG8P<c<P;daQ
LgA3J65b83<c82mGJFAdJ7<PFb0f=SLPGB0n?PYUKVA_HVX:<S0P<21_HVX:?3`P
;daUKVMdJ20b<S@P;dIYK7AULR0_AVaQM6E4IF=_I6DP?Sh:LgAbIF5]2WP1GI31
K/<P44C_O<DNTd<4SWY4B5FZB3hTZN;f0c2/;JAh@APOo?L1jZIB3g]PIQh<bdo]
Ad/^0On<gWBHH71T8linR@JQam4AJhiPWDWKZFYVdX7a37O[W71ZJO0P9@?Pmhc<
:Jj`NkNnaggAK]5RM3C2k__DEJEK@WSPQ9A0<:G0hY2_^nQ`eA<2[nRQ]MUgJCeT
jRoa]@J4g2PCcDlUhbg>@A^<VTITDPPUcfO5T>`oJ`?jHD/N6bG;2?7Fe?b_Dm3b
aELU/lBHfm@me::UP2=l[B[hD1j/l`A_6W0E2VE^I7=dLVEQK@YUKVA_HVX:<CTP
<21_HVX:?3`P;eAiL6DP;dI_KWA4IG=SLVU`M6mb82m6KfidCV5]IB0_@D51@D53
:fI_KW@`<30`<30`<38g<3HbI3MR82m6K65WLb0f>0X_AVm^M492KgPPFbde<CLP
;C<b=B0a<cLi83Ti=edP;dUdHFaYHd5^IfaU830P;d5cHfE^M20i<3DP;dAULf=U
KW@P;C8a<R0_@f5`B6EYIfQd2SP`=B0_DgAUKEHP<20_C6EQI6U^Ib0c<b0_F4QU
JFMXM20f<3@P;deQN5MYI7AX834c<c<P;dI_KWA6JFaU<R0b<B0`858P?Sh:IFiT
Kf9Z2S8a830PKf9Z2S`l82m<IFiWM6Pa83Db=30P;daUKVMdJ20c=SDd82m6JFad
IG8P;dI/HGAUA6ESKfAU83hn2W=dLVEQK@Yh0HEH3eQDeiDoimhglfIPP05A1XVn
=kj0bS20J40@W@5V23[n@c0k@fdcZ0PVoV4E;FHC=G7m/:=AdWcKgFI=Hh>RDA?O
P=X1DkF]gDfCMI]=njEYoVa/?dgBV<C4eJJ9PKOW_AUAm^_^_SOgg??WMnlmmmbo
KcXfK6Z1I=P>78YG[6e^1n?9n3O:aZoHg277I@]UY_2Zm]JeLCTUC?;beSEKE/GU
S<l1<=SFd[`b;/<gU9NfTB8^h`c:kfeKfm4IUc<^D6iI/gi5`Yka4LWV]LfMROKQ
GI;UMLe[Fn;hc3[:Rm/g]2C/62AhKmafQajUihi4759RT4I9OaSHX@RF4^=Q2`b=
KSL17>kLeo1PF^E=BkKNCh2N3CloYnNo<5m^__GND6^bEKa5YJe6OKZ1bXUcQQM2
CM;AFnmm_BCI2Th@ML?8`j:=aFOHDD9jfI6nl^WN63_BKamKX^MmXRjnd6o;:=UF
ULijh@BULiB^DA:PV>PRBPmBhUBl]fnOS^o]Nm38nQOFUf`W/Gon0[ffgWi_GCa?
BXWWeXYhGSaMaag/mgOZl/7nTXZhW3l];]nKBlgKfD7blIY1dhPFDO9@fTI9X<H?
mXnM42mVcMB;mOB?cbU9>lMj2=53iGX<5g^lBFC>F6AN9;9[EFEhUNYlcZ3K3?ZP
@Cd6;C9XVT6ghLMjj`HmIm0C1RdbZ<NPR`bjgZ067SnUma=j[m;k<Gk/cH0210W]
1FRGd5^0GPT7d8[9OC>TYf:Hk2fK8AG:=E89YNWboE81iA:U_l^_TmbDW?TnZ@`1
4Jc8`09IFCB:6NTFK`b?ofBh:fFX:`F/<OCdiLnGZZaH0H>2gU`YYFLX2Ggi6jBc
E5XfA02I7N^CK[USn42Om;DD/f2Om9DDHnPM8oe5^Ram:IfAKT[cY5oU7i<62?E<
WaBCHP:Q3^C7f35_V[AKFT;>GIHjYCGB>]T`[G5BiTfFEU2QY_`V:BPC]4mJ:1^]
g2mA=JLU?aUmnC74di9GnYhdgFdD;M6;WYJVBA^T@QgG9aG4Vi/Jmff:WYfF9U=S
ThaFo=;B56^:]JckGK7kR=SM:gI_5K^[a>iIHWNYf7fOf5d/MQN9gBja>eO/WR1V
FS8/MT^ZaFI9/UP/IX]PHAJ`I<JdBejG_U8bcGHm<`/j5@cNC^/ASDE92hVQQL4l
D<O`00/dE6=0?Kl20/]UmLl=BPbCjY]DTe:=JTH00XgE3WFV:a0C]BEZVB^PRX^o
5H`RkPfAEVFkHPR=`AQVjjZM>FY6CG20ASEkii<iNZk]O38DPW6K?@i?aYcdlU[O
Gb5Q@aWf^NhlSS^/cPDFKaVP@@ofRm9/TL@64[]e/E/G7A?D7`@JP^[A2B6eA6Nd
2J60nWB3_2`hP2oQLKm_05oD/e1`P1OPBohU^YhGn4:Q00f=P@<?j@WgTYhAc_8V
N7@LN2a_6SP1hcS5`=6dRn?6bJ0H>6FL?0Xg4EnTnR1OcjRn[4/`dL1=c;Yd5bhj
Z?QmDHD8HJR^@@<c6:m;[MBKS4XB@Ia4249;AC8P4S:m6[Gf3/BMP1B>@0Z=U[SQ
NK`J_BjZ9TFnSDWA_AhMk?m=JZUf^Ob[mKVb>1Re@7FXQYcClg7fmSW6^:MTccVD
<`Q_l:^@k0ZYBDZeVZaDPlOSL=T[/LQ/DlfT4RWY/fBFdk4eIe00?6:PKJA>BISL
ENhZgDBcEjlXUMAY2I=SjbaWcR0NBIS/Y4jW=^ib^Z=S4cgPl:ofSO`f9Yi=RK`3
0VYn@d3ee3L5Xj;XEkeQGhQdaKMebLWnV7Hn[R`TIJD>i7`4>::cFQ=0R/KYA@Fh
B<8bEdM7b;FAG=Zh/N<^ae`M^/kE@@_D=0SIA^Z5lD8N>02d3bWANJam>;aJndbg
3JoGo/SnB;_RZDB:7g<_`cWH0og@BflDk2S0B]P2^nWm6G`<4GPNW/:C/14NPH?4
Wl6O/WIXP^f@1Ng`2bQ6[[d>an4aC04cI<2_h28l04mYng0<gDNbX@Hf`01oQOm>
n`a[LAe]5cWPPbE`VWl6Kj70IY/LYXfJVli_:o`;G6CcbNmd60]U<1LF`S;bjC3i
nd]h1jNHJ[CgjHCf@P>e_0Gf@PnlR_]H2m_43_9GC4^eIcAZQFZb@1kD`VY2KHC_
`S?DSf^HQ6?`IgR5>hCm`mN7_m8>D^LW``bX0Sm/X]iLP=OPmg05oX9;LAEc/DKN
;YR4EVfLMY9lWP0U];W=P`Edk`S3Xk2=8_H/A5T?gc=lHOQ;fPHi_Fkb^P`ZZ?m=
5:^;l3JVHcKVhVB/``ILS@O`5Q=I>G^L7FAOLQ>O@VlYkn6Wn7_lOOj5D2Md2QnH
TkDYFT1[dcZeikAcfQlXYQ9<POUDic;h3SAC[kh;Sl<>f4FS]IoNIn4i>0BW8@H3
<0RoPOOQ3g0M_/AD;<5IF8V[L0efdSid2Wn2_lHgf;MI<g^NGN@:Kj:f3m:Rl0V;
QHg26l<`?7=hcg1dn=neE:e?neO]4ff8XRUAc7<YXVh8@P^e_1>NPQmBRlOP1:Sd
3/8kM<ok4dG>BZlM<c4;klFYj<HR;<G5F8m=f8XM^0FO`;gHSCo4oJQR?gUc5Wn9
Kn=7n3UNYlQ@V5TbBf<BVl@:V9/E/XF/UGFaKWJLWF8_do/jnbekRkg3[[0_f5Ll
WFOB>hWWlCXnSboSjgTWgl:glV<DcmOh9D6PlD/CYPP5`]l;Qh@C`Zn5Zl9GYVCC
G]?CYWlbGC5M<H?IKYi]GVa^<on3>FKn_LS5NW6E^5GL9ShQWZKCCk4LQciJ7E7Z
jEd?F`HoQ]oPFOQ?k>FIk1P^IXOa1iS:7O0`ofOl3e<0_/LZVHX;f3SnGkPI=l=H
oP;NP1]`VPW/;G@9Qo40_4`[J@mkV7D:JOPg`P_247H8K`RLGHINmYWNW3UC>4`7
jfHjIMOR7>9JHBglR6G2JgB[f`Uo2cn77iV][9_6OAoT/CZh3nOZHl>^`EEJ7NWX
PHMXW@aQSjV3oAPOhAla6cb0@namW6GZP5EdXSn>oF`QO`d_dlYkVNI;0=]H>Bj7
8OP0WlL?f59H`7I0Sm1ZnRfnQbiLJ6ZSn@O29CjG[f9Sf9Vk`Q9WCl19FPTGHCio
1IKQmfWeGf@^V<_F`k?lYoPW>8V?2ZflSKc/I0;^X;E`7?YiWI0<eG2BWhBcN8Bo
RBhh8GCR>WaJl`mm6fjJNhFGN=AD:]bS_C[l;Qk2ekE1mPFDJJobYL>]^5o8YWGi
::gN3ABQI3Q6iOOCS]4;5^9bJCg^YOTjU_Hf:jgbF]Zii/=gl3Z]V1dDYE:L0P_I
97RHEHVb>I>n2BK3DDeObN]P:[h]7:7mHM1KeNSec9UM>J^RO6KIOC>VUd`[;RYd
5kSbYdjIW9Mk[c;9:D/C9mbC<ckKTCE^K>JHS7AkFVZ:;CW9JQ7=9QYEQ0:oDQ^F
eKb`:^@YMGE^GEJJBM5lUb:/bZBZ7HeAIKeL<iU68Kf4G?DoT=hhdS^2A;]L2IG^
0]V_b>Y5Wd9GcJKj8?5?nYB@[7iZl0/<G/PcQ1@BW4hZ8O/MKCiIaK3/Ef/g]dGl
HInk0:?9BCE:CD^B^`2RBLW49Q>WIRW]DLbJP`K3/_`EDKZ3Ye0OeO6:cjmV:eBD
Z^6io^JEj^;jX=nGhgB6g0DZeZa@UZ^P7lP^0`8eAS>Z^DHESFKTeBYe1gK;dH;c
TCda>b`?^f`[UIG=bh8ZKjHjo6ZjRm[eZEV?G7KL4JUb^QEdgFg=hA6oHkF/Pb>A
;UTmD1nlZfb>DjlQ5:8jZ2c;[@e7JZWY?CADj2PRigCgmJk4>mFRn7E=n25I]B[E
BU_TXC0=b?R82T^f>?_6SoL>J9MP_5n>=0HEYn[9DD;=_W^RVA1I/ZDofb]WSkJh
2j;fm7PdXjUY2LJFLSOC@Y6>f`c>P>]LH<U8>57gB9U;]`mEGR6C9d65>S9C9bdc
8K9R9TFMWQ1B:GDU3L=ZeEXCS]P[M3f54UEC[UfA8cN1QUgim9?AV^J4aYa[_`Vj
DIlL8a=<aNKK_>YbZOWin[`@JfPPbLLiQWbO^f1cS9DZkGKjl2VUl<7R81D;EAAA
c9e>OEAgakb`W0AeNgd`;/^`?:L?_4EdKf=QgG;n]VG/D]fboKIUY7QHXNUkTPiU
P;6Z9FoTUfHO=lKOEZ7R^?o3g1:g1aZD05gAI7lTW9RZPLIAD]b^1iCRA[H4YhjY
2O8LYTm]hUP>=j`d4iLeSD182=YD8IMnIV<V[hb95YZ:QPKUF]DN[X_CD9;CVEPX
oenQV?JiG/[8kQA;M4>]L2DLSK^]cQXUSg;?5^61A]YXF:2a:A996VF[YBd/4ZUE
i=Y8>=8LdkH_EfBk4QUPQmRQB;^O=YohR<Jd`MdiJ^fN47FU3B]XgS:XSRZhZckZ
aEd=CL41nX:DMcD6naRbVW1e:>BVlhi6c?B0mS/J=_Z>9`YP8jF=L^N81^QnMI`d
]:7ZOo[@gcjLo[>I5fEh1P/9;K:b?S09<B`lbB59e9UC2=TF/dVg<n1HdfomeUWj
P?QciE3U@_^=bPE3UN0Qg_h=TFW5cWAWNRhAn/Z5KfAnoQ^_2Fj1;9bW=WGOQ6]d
UaHQ5@ihJbeV<c=K;:;9VV@Cc9IDVdddFm9<E[_]7fg8I79aXVS;54DK/`W2A<hb
>Ad4HQXM1ma^^dEM]eZL9W<<cgQCAE4@>0N;kHFd7DlhG=Wf6n3`E=[em`KiiJWl
5=>cb]?;bk/:GEf?GNPZM;PN/em`YFNDUm>_biij`GCQ@YM1AG]UUog2]685YhmA
^9>STnM==X]C^NO3jfO_7cYa5CehYMaY:@VK1[n^aMkQ9SHKfmoio]HG:JAjk3<B
dCOCGAfZm:O6]F[m^XkRa5=BEUaJ/[9/>H7o6hfiBod:IFiTLgAbIF5]2VE^I6mR
JPXi830PKf9Z2S`l82mDNG1U82m6Kfid82mCMF9dNG1U82mDLWEUE7U`IB0_@V5c
IDI_KW@P;d51@D51AB]VKfid<30`<30`<30b=c0f<V@gHR0_AVm^M4AULf=bJG1d
Kg8:<S8P<21B82mDKeE^JF=_I6DP<S<P<21B82m6JG9cM4=XHG8P<c<P;daQLgA3
J65b83@`82mGJFAdJ7<PFb0e<30P<S8b83<c<`Xe=CHP=CDf83De=R0b<S8P=C0`
85dP?Sh:IFiTKf9Z2S8c830PKf9Z2S`l82m<IFiWM6PP<SLf82m6JFadIG8P;dI/
HGAUA6ESKfAU83hn2W=dLVEQK@Yh0EfAcF[3<124kgZ:?JJ7H=U^TaB<XJ@4O>P?
MO/0][@fPUXF/W;`fgNTY2Wd<8M?^k?<[[9SlmaH4bQkmk=Z>M1P[?Jlc6N_V7XN
SAEi@MZXL:GdYZK>R@cVMUd2ChdMIZXZ@IAm`;84_m;VBLlmglFg=joI6c_Bi^_H
YYOfk=`gCf`3BE7GY7W0^9O>_GHCDiJ/fdJSK/:jQN^_hg=eC4P4Agj9Y6K=Rn/D
nlj>;2XYjnYdZPEKoJmd^1SjhMYIi7DE9NF^[4EE5408n1Ra149BkX^8md18bS;Q
0a12ELKZ3PS1>dCL0b6PRWP0@VS6I0CkSA0caU_NMUMWkk5f>WRjB=cDF;kmRI]M
793d0fPiQO<:IFiTLgAbIF5]2VE^I6mRJPXb<R0`86mRJPXl?20_E7U`IB0_AVm^
M4AULf=bJG1dKg8P;dI_KWA>HFeU82m1@D51@DD[IVm^M30`<30`<30`<SL`=S9T
=f8P;dI/HFMc83@P;dI_KWA2@Vmh2U/]=SHe82dc<SDP<S0`<20a<30fGB0_BGAQ
K6US@FiWK6DP<20_@G=SIFid83T`=B0_A6EcHfE^M20]<S4b82m3HG18IFUWJ7@:
=S8e82mCM6E]ER0`82m<IF5TJFiW83<c82mHB6EYIfQd83Dg>20_CF5hEfUTM6PP
<S0`<20_AVm^M4IYK6Db838d830PDR0n?PYUKVA_HVX:<S@P<21_HVX:?3`P;daU
KVMdJ34P>CTc=R0_C6E^IgAX83L`<SPP;dIYK7AULR0_AVaQM6E4IF=_I6DP?Sh:
LgAbIF5]2WP1QET9N5AEUSkg_UMkENYEEII:ZY9jBBEQ:C0@0R4QCEhf@:>b1C^5
A18P@UR44<0M2QF1^<0h?HjRdkS@B^/X;`]d/GBC5]@FANSF]TMK1AEK]3]2chOJ
;ZCV_jl2BXoOc;]ecSggW7>gLliMgZ]E:eNgTX=R9=6XnL]JEY3aI<J@3IfoIYEZ
5<WU9c8gG;mRhK9TfKNDb?Ci`ZDgGil/IahPLYiJe=Zb85VVki2?F`A6//a:T>L_
F[KZYV@iLhhX;ednOe2N^A?Ue6D]=`gfCnnR[=k@/Z`eZEoh6?9A:eJf3/YI8i7S
=dWImoPI?=nG@360SD;43BhWQH[X6R9iTIa]L8CLa;LD_M=RV^^^n<8J/1[/9chJ
<U`@Qn@EFkoIMGjQ@UHWRSJS?B50?L_4PJ^YAZ5_MWecRi;/BDP^?;Jme20=kBWd
QhhOT8KAB@2GQWE7/T=kYB5BM_N4T1JG`SgN]69geDQ9AH]51UJ1U`=f0@h2I9X[
iD2Z0:l3a02k00L1a`5V8V0QE@7;0M/19`5V:E/:MZ/QYFZ8U8VjVK22FlZP<h04
@:8@L15P:V0^H0]P>l1/j0W>L/0j`470FH2I=2VSnh4a67]6mce6e[=hJK5AK4TF
ic@IaIjOAY?iEM>CNNgUBKGbY=[XTRCk/^YT?VA4<_LF5<O@N8oMEMaGUBjUHi;Y
6?P:H<H?Ti/a^?<a:Hed09L`E8>SBMjNo<;Rk@LUVIS49DH;:9CXTeRgbe=LINL9
OXJl5>:OlojTQ?OgY7R:]eMM`CnTGH2308UoR?@1oh3FlI?2i/2EP>f0Ph1SP3<0
<cn9M0;YOOhn^OUkE0BX1<`5K0LL19`1F?Qk`0YoEdB<P@EM2N3lGF25oaWCnS>`
Vkl3jQgnCZ:?_m5MFUJleb0RAH=4Z62@b0P<4]kdhSSo@oOG`a1AQO0d8VZoU4LC
JHbDeed`>QBGo=dEKJ4hojQ7SH@NZa[5gb@M`36B=m7cVj@2YP6J0B/0IU1_PGZ;
HX2]P<L0>P1A1Z`0E7h4l1[P;AX5d03C05In_1_Ma?Vak/;ZD5DjOifoC1V`n57n
>b=oSKmTi:ob5hgl5N@iT1oQ;gGWQ:S:0CVQSX9L@Eh4^HWo]ROO6dYDNOQ1F304
G0BX14`5c0E/0ISi@IkG_B3TAB?kj@SFL8QgdjM6oQ@mHBE]LDP[[440ZP8EU_l4
5=1fMG/Qe`XOO1Q5P@[_O`2D@8Egg@]:X<9KeX<BZ73Y6U025BiH34ZP`]Uc@@UD
>;D1552LooaGnD=2YE>G<;G:cFn4UFj4UFj4UFhTVMlX4Wd]Rc4ndSel>2bfCH/<
6aj:kF>a0b`fPlFNH;5F5U_;H^]I[8;5[V>a28/5FBb7aC@Fflo6`a@aY_ENDRcC
o2afQ<FNHk4>5R]T/@8FbfLaUIEZLIkKOCUF7K8j8n^Y4X^>ioKlI29f7cO?QDEc
4O>if1<>0Ql398bB1RDe;jVLVB?b_9kQULWbING5bj^Vl4>XN0Q^>4@W038LM0QQ
M0R=749cK^1:`5a07n0<804`@c/?lmQRH3M`4J0B<1N`3W06H3J6L`I3hK@LF0aa
Uc6`8^1:`5AAhXN@lY1bNJjF[@BER395fQ9TkQ`f=BNA`d/Y?Agk/]MSmLBIJlmG
[WmliB9KUHgOckM@=QbaMC3Od_eeMRS>7^X^g1nZBV?oCSTbXXjEDB4[@3jN>Xcb
F0YJ1Kn4P_aIi<GM`F]@cMeM>2:dSjF8FW]2G`M?QCh=aSW8dl7mXCnYLIUeQoh8
c[=k@Vl6=hMN:HYK`CU@66O8mZV6j]kPn=1cA`cEmA1/j`j]5MVNd>g1bJ4U@D?@
VQALeh6BiPk=:9`MVX;fJX?c@UX7f]`CZPaN5jY8JXdEMOJ4AV48TB@i78<M5S@j
3NLH3LhZSK=5fPS;PiI6beC;>4^aIH@Uea:bI5/2UUB[ejYHDja>ZmeZ]IZ]/YEK
bIXJCicD8^;DBcDKQilI0Le8=VP5>``Cf```LFKUM0GY?ZVNeln/I_EjggbZWjOZ
Glh<aiUmnVcM5:iV^[NNjQ^ZmO6An[PU<D<_SMC[UVWG=WHaMWlDG9e_RS=ZJ8bc
Q61]2>SNV/Jma9QW`gd1T@oML5ldB_kd=IGnB^m4CmVTfQm1c@Jc^CKboN?oWXch
8mWjPoDc6oEW/Z=j/B0BfM5joEmWZW<Jmk;oIVO[J_Nb_h//f[QGV/Sn^fj6h4/C
Jj?AnSRka]0SUOdMNXPHI=2chV0FNZAJLi9jfi9j1JP?_GbA@LmVX`93[l1V<oAT
9_Bj>_;[J[_bPJ2CXE:7XM>AXOi@idP1M0Z0X9<NXb>6cY7dV=3A9a[=18=@b@62
2/^RX:4BI5V6RS7b;T>UJ51UldFEcDI?DW8dQXi0J<IelX:>jbAdOV38oi]/[Hi4
F<n4j?`iMJgQ^^I`GB^PFKmWcB:o7Y^WZUgcXd:PjU9QlkciRdCNdZY7`jfen_a`
[MXe`JSgCn8i@S`QG=]5LnXJ6[_VJ:fegA>d2GGQU]YXcnAY9JFGm;GiHUlUdgjT
[fVR/A;AefBSgSoeEB[4TdEOYJ:_D]7GI6fbdALI<Cj]/L]:eM4Jn4oT?MaQAk`f
1g:SeNW:RXU6l4k8mJl=k<=]IBLi8U7M6JkFG@0Aeb>[AUH94MJD4:F0kAhDnMM>
b0g/Hc/7A@[HWW0eAEJ]kUQ=o[Zff^B_0`mHZeH;EbAaA?1nm85:WJjee7J/8Z[G
Qln/eb^Wcfk//US0KJj=PUMnPNM`e<DCODWVIF2F2dE9^ZPXN1F2Ik<=:_k_F336
13J//aLGSOdmC<]QZjPS:^Tim@dLFd73K9QQc^c6OKQ;RD>R8hX9M[08jkS@VYR7
@E>B@iQfa`EH]GZ@6[C5Z/7LD>f8D:CSPTT^=1LAaS:@HJ]E4Fa]YWfD2LPb?DfI
LR7QoBOa2N2db0OJ4ZN5G>Cl<fadlD4PfTW?/CIjSPkB2n`/J^fR_MA;hPYDBhoB
KO@cfXQSKCHhVfT6TPWlWk7<A2oNC1k7POTh7HG^CfT]kJ=diTmlB^]XPo@6JVdP
5nEA5DfSiG@O^c:aV^K@2OU>:ZD[j@IJ`F:9a/CmR@LB>nPG]5OjGN8lg^ZbJ3kB
dLCWY_m:_4/SDN?Oj64j`Aj`kBH=_LBPnAndT[I9CC9;;4alPa7TdXdHPdaGdE7F
ab=X_IDnHGifVeB3EYi<j8W3d0YB4bfRKKB?SFFCNJiYC^:Za55:AalgXMF7ZI_f
8<GYeo@>Li[>9WHTcU8VSJ3;<ImNNYgeB@?We`mD`VhVF6THUD6bW7i3;m=a5VJo
iL]=CU>aBC?MTWRCDVTdcL9XWdK=_k2_n5ZTMM9;lZA4=JG0;_lR[4d_dPL/RaFa
ZN`J?X`_icnGEY8E?Hi6FT1]/?M3J?emQ=4Nk^C7Y2OUInE_cMT39a<Yl4PQ?D;o
@KmU;/aDIAg/3_HFnhSGl;Wl4OjQm3?iUo8O;2fHmGFdS>jSInT[iVGSfGAf;E_4
KV<KfKn`QmUAMYbMiUFlPBoQIjA5D[_dJkTJJJKL8MmY^]]dSoWd@>?0hH7O3gbE
:4kLCM<A3n/anWnSWf=VNnTH_HedPSiT9^IP:DPZbfFcf:e8JmUmk0VfTofBmJ:G
hna3mRV>Y2oH]a`W;COc02hohPXDiR]a`o`IOi@O@c[>olJoUS:T?2TRSIDZY:Rd
7:?J:6e5fRem86O9an@4k5a/N]2dgKCCm:cY1M=I/m=b1lkhekikl_c`lnl?d<2V
P@L7^PMj4am@6Wb8d`>_H1DHO@_BH_Sk@DCL;WZ3>F6k;3JLCFAG`S9cfF;FcVj2
9NmRfmP_S;4oc`k0BWmRIc1V5`lJHkj<SnGEO2[BMKbE]n<bmP3_iFoaKbB;i93L
DYXdG9X/=DV]dR[YI^U1BIMNTmjC?YBnU;i3B/Qf>BCWbHEbA9h/ciEGbcnG?i4o
<Lda_F[jf6`g;c?OKHjKohiKcDC;=<]dBi=URfF?iDe[<j;c4>fVGb42;ck/Y;AN
ZY=fdoelS9b9EiSG4LmcJH5d5DNTlYe/4knMmO9lddgV2G`2^i[>bXF`mD]l>onB
Ci2^H_E/9RgVXi<=VU=UlCFR@Si4oO81c>ee]7bCfLWFlS=V9gGSSUB6>m:;dRPi
8[e:kdPWV4EnW?h/feT6jnM?Bm<@1KnF9iXJ:EMjU9jGf]W]]9_G4MVo]Mj;>;jJ
?H=mXH4E/gm82Eb3[dHDUDXOdIfdQ?lGmF<MKj9oI`_TQG@oSF6gdBOd55K5<=<=
i^7V=?H:Ki<k^Hoe4YMoRMVE/G`VVE;Y;]HTKC>OhFoCJSXVfnUmjClanV?lNNTZ
nJaY1U^45G0kgDg]ROEd/jUAoP=KB1:kQP[TTmSMKY>:iEcTjk2[c<6N]PN[Naof
PB[Y:W3lR9`[4ANc/4=/@gX8nhB<26[36_lYM[7GZMOL`>>dd9C2/>_PBlf[0c=X
M^8YNSRaT6i8?40S/Am/C=b65WOBakB5M[8=0kOB2[a:_XfeOJEY4SmVVY@HbC_i
fg`VOo1Bol;J1La?Wb4m3lm<=>fWC_U?=9<Z4oLVoXSX7XXMmV6JQ`_[:LcbLo@`
ANZS<@=Gljk496T5iW^2YRNNCXBHWAHUU]9D>T2o/9RXaA:1SgGf1lcgEV[U<a:[
Y=J1=]QQ2jbP`EZ[/Om/eVYV=EAYUA=oDS6Q_6aljMRB<LFSAaEM=W94I?R`XD<:
2o;3NKUZ:2Lk6<S:m6NTYjGj_1k5WN9b>^`fZlE/TRG>J4AMN5:cZQLfjg9QN<ZD
TJ8LKP6Si@N<IUd5Jm:U>[XZj[E0M8VV1/g[odUCBfYZ5cFIXUI@aLPAJUeHeHoF
Q]DhVcfm4OAm]N6XZ_LKm5D6_MFPGJ1cLe51[O<_ZUEeeZcFjI?F;>Z/JjhM>H9e
>N`ehIYFnlPAe6EgP7B0dS?2:kYHaTAV43bS[[b;TmF5:NYIhMXj?C><ZVQ6:ZQ[
FJ1?VmiHEa_8cHf>7:6cV_WQNCZ9Ve;4D:4JXa_MG:=KS6kD=]aaM;Y7kA[AegU_
G:5icA7WP_22USV=^]B2=^YdC`Cme^XI]icbOem4hkRCKObQ=21ee_WKE:7LfKUA
eAnKg_R3^X5LdD8dRSI@UaM<J^jLQ:k_QJOZaEeLia^RSC[KP2ia/B``IYFLGo;F
Fm2lF=E]hN[`X/k5cG1=EZM><fk>kLk:d_HVCU9FWM[Id1S>eB/3hFQ;KK0[UCYW
g=bCZJVIUdY6S^QB?4W3MZFh1`VWjhM4:hbNU1VDXBjXnQTG;L_46<>GhbJXZo=E
S:@aS3V=5jQe?7G>7`l7h8Tbe=8G`2=]^ZfV^E<Y5ga<TNVV0RF/MWi1R81`oml^
iK@<L/`5bQLTQ29>;XJJcUX^d7XTXPlO;T;4DP>OHX`CSO;HTB?Fa7Th_4;1nk=h
JJ1Y/6e;];`8i/o=5@jn9jkA?1Cdf?C6I5VUNH5^dXY`]nK=@]9g@I8fBdQR5b@G
ZcN74LVmhWfFdWA[hLFOFdWgeBdZeeWjob5^CL[[IhK[LCEFjcZK1j>f_^6BDU8^
30Zk@CI8jKjJARW0`A<D3dR6=7U3_Z22jg:SDiL;l3<K@KdPK[4R:Pd>DbOYB_>D
98kJLg<7elcoEbVN>2]Z6MWge@JWXIM71PNJ7;HnhI;b9L=cMT[e3MQb>6kfWIgf
Bf@8]N@X;ao<4?5hdLmEJgBJQIEIP1mN>LH;R0Id3BJ3Y06[b6170h?5Ba@3PiFR
N4AdSQ`a2G]VInNT/3ZY/kVc9Ij8c@^[B[Qc;gn1_m2iXPjkGC9`hXUmm`CdBOM6
HK55[1c;Pe=eEiQ]V]jU/DdcIcO^aBL>ME=3HcMW_:Ji>R[L`V/J6PO=HSQ4Q3il
R7m<435hDi_6GZI=o1WJ87OP=]116`6eh=d9FBi2RQV1QCm@D24;iEcLFlD750VE
CN1ID1I?>Yg5fOVi94]oTGmWVVANRJl[H9^@X6]1ADn^Y`18m?ZM:_EmYiWXFe;U
?U6KdKC4JJUOWTQIK7HG5h?FBU;F^IWK`CBlEJ`@oGV33X/o:>?fVFJaYZC`FAJW
bbF`d`V/>1c0AN:ejNRK;e5UOfFoL[RYF<3XD@5]//g9@/4JGdg6C=o<S6IOLlHS
o15YVf^7/R?;JGEUfQOc=VVaJKEcQB_VN/ZifkK7_]_YC7ONkOb8BbUiLmg;gN_L
TY_5nC?JcJ=`K4jSIPa[:ce69nT/oWia^afh4U`HHa13cdna^UcVFBUi0L`_ga49
<ARC<LgQ<<mRVZ80Cg4jPK>46[/lV9Ioc<92UTX;]j@89H]M:5Vl@/Tb>U1bf1mA
_/ClV][kSCcB]7;@]OS<96:`OnFiB?m:HnkN/R9?FI7BM0ZodJ>XZIde]DMIQ]TL
cR=?RGOLV>;d34]QHCS?W9JJ?ZIhW5CAUGgVnGL6_U[ijNKWgPg]bU`gNm<c>niJ
O3oKT?6[HbbKfOnClOFk7Pl/FG[XSKMN^0>G<]cPR5GPGE?hmjQfWFfLL<5DfeKK
HcKMeVLkHC][/i0]I5]QRmVf3k9>fQ8fNlP6BeQT;]W<dUY6IY=I]Y/]1BJB]l^?
bK[L9inDcGgbFIVC[<[7DI;UN>8O_H[2Ih7hA//@kYMUhGSI;WZEDhG18?/<BPHa
d2^/2/igVUdHD;kJ>WWJX06=Mn^VmYDEib^X/[:R/Ymi_6EU0TJ?HTd[fb>n/F?B
9<lHcjKNgUki[lN>OI/V5gkkSXSC3IShBhQC3kfRCBSb<DEVHKU4[/6;e?Gb:]U/
leQ]EY_;ik6iB;8bAm1/HFJbfhI^]C9[W^YS?YkW:F24?D=CaX`[>H/fBJGSR28I
c>@L1J5ia1c9V2>IaAc1oLjH7HQcF[[KKIi5IS4eG4<`EK[J>oU2Q0a><59a7_ho
]o8DIUWIkl4DblZ<ZI;bb/JDf`n;`5S9V/IhaZB=@d@P810?5W>JIl<C4m/Z[ke^
HWGeQ>]BLnC2am^WU3lmI79Ull[cKbKGJ`F2gF;ZXacfLYOIF:lfSn;bngcVFBh<
[mOS<HS?=I_`Qb/WeI@CCicF<XA2CXj@iPAC8<W16PJ>lofJTm/c<_2OX8Mc=@AW
5;eiE>2SE=@_iU<Yl66aV0Lg2=6Qdn_UAXNJcNd1UNcWY>K`n_R/W5C14fegXfUd
gb_<2>9_FX[H>Gj/=n`NAWnR=j<cKM`4d`CcO]=1lgk;bmIGPYK;WE5W@lXBih:D
Fkbgn3Ik3gPoc_XhL3K;NM3a:al?h1=o]Y:SV7n3S`XFg8V/b6f9/eYFSUfaV/e7
PUVY`F2F=IPU<Fk=2TZ^72G>MoA<mC3l0N3O;FI0QSWLS3_]7AU_8>Zdg709floG
8e0D=UicNWIGh^Eo>Eo7IKj?in<coiJ^NdA/=idC>d>5LZjO:Q7LUOgWVdii_1W2
jAUU6e<^RjCL[Q`F4@3?SlO31:8Va7`dFY2FFePjKQanHd^<>1PRHP8GOC=2`VbA
;MnElXb29kNMfOW`[GLlb_Kjo_7k=kjLl_@;Clc9NNjiZX[iOF/?OgcmTWmm]==g
k>g?WV]li/2>CBgRKI?CaX4f>AM[aX]XVJOMkeA6:SmAjQFiD]EE7U:7>L?IaFW5
fMGI:mB]Z[DlXca`ALHEPJSeF^NLS3V1aMHUcSIUFLJB@9ojA^Yko_Nbg/PiUGXZ
ijBJD=?3LTB9Y8fEbiE9lQG:K>ESaenc1aB79dE:3aY;;cfHhZ2Dc?cSMZKH=G^c
?FJGEFc1O9JZRAR`aa=odAa^=bSoH?VKG[6_@?0ih/D/R7>mH[61>:f5aH:c[f:n
<Gb<]h2XSk6]k36V/k=<3[5:O>6AV=Qc//GZIHYXTRVR?FHLD<aYk?kaa9O6BSID
SIG<L8[Q4?0JAd5VJ7:YWdF^E/hI2eTP/E]MYI`oMdXiOh67H`3[^]mHfHI7hLOf
UMC^6ec>jO0MagiO><@S6G]ldZlKMi@o/6SClLF[Cm`jNl]UWZOFg?C/dj/j^PKJ
C;o^W3kmg/A3C`ilNlnEiNNoUGHL?OcZ7elmlROQ`m[4JGT8O>RRC;ITCaY/IIkU
4d]:46iQV@i1IAX2[lFNjIa/WV:maQbe;SBgFJdUB[Vg?7f/_djYmmJWeoWWV>KH
IRQ=gZKd6OiUYVFf1LXbkk;d1OhKFI[=K79M:cFH6^cG>YM:[JIFne:W?B<XFca1
Qb<e?f2h;F2hd8;mG_<8ieT<i`eN0W0[=3`7lEUSO0HQG6P@`]0PnSAOOT79:0/S
Rf9A;I9Um8T02`SniCWQTU6PDo;9VH;62Eh1=^hIQ460=/iW`Rj2OMLYMSQ:=gIR
3Df6Z1866ieEDVX/b@_^R_@[kI6V;i^J;S8Rl1n^:CQcfY^X7MMTcCKC==<fccC?
9[<VO5S6he=:/@Y9[4:Lg;hOn;5fanHGolcBKog[?BL6n_MfKkbk^fO3aVil=1Ub
oiZ13lhOoN/M;8NiGW_e]Mnon>XAhhie9kJBD^>loVR?bCR/CIQ^CnWh4R<_6I_<
Ahe>iWT5AZhEY6FD^4dQO8@kHI:W0YdeBB7C2U?<U33Q?dNbLbUiX8VFL3KeJFUS
aYI/9mJ7Ra7odM?]VnCj63cMS1>LS1>L[8HahhWTlHgF4UR=<>o5Lib^URlmalGB
R>2T4dNi>;i5BC`heCagmY[fOC=9W=^i0m>Uco6]?8]m=GQlI=]CgOR85ladNld>
/doc^UF7iUCMOQ5?k/bRB=IkFOjSFIV:b8`357/XCYlN=ojmSBONeiH5bhJVG^?N
IILdUnKVKWGXZ19588_CiTegnKe374>L@ecSW>=LHe<NmSR6NXOjYZA7_E5O=:g=
fnI[Bk_I_<Ie/nNFe5_B=[Pj?OMjkoE]CWg8_]=a@=W_fIOjVOfCe2mLiiF_Da?1
7>oP:I_^L`@3/[_FOAM^XiTGQillh;eUCLKa7]1:gFjWh_5jkBAUY_Yl1Eik:PY^
Ym_S;73HHFZkch]kYL</iTm19LR;PPN37?l0Enif`aIJJY`gJ8i:[nKULkd7_M`K
ImEkg2b?jP9f8C:/YJW>DLjYCVVJ<n7TCVSd5>7NRcIj0nY]eo/S<=kimW==kEWn
OY3mO^GLZDcU5?J];;oBKe3Ta`ZXD90fVRj;F74j8OLKaaCQV=ZHXUADF0oGjbWh
llJ?=mCmi<CO78k4JIaLdBSLKOaCTiYhOdmYVCf_]2`5>m7^]39?GUZIR85XDc_n
;fU_RV0inHJ8NfjYB6b<;ceSG:U_31=7FcQ_GNZ44AEC<Sb59/O0/QONRnB58Qoe
3Rb]bQmefcDU0`]oZ@c=3baaIl]3ccnlN_e]JoRBKgngZcXj<gTClXXK71hc1HRZ
a5<G^Gki3J]63Ck5YJ?65BlXW@NEo`6g:ALC2VE^I7=dLVEQK@YUKVA_HVX:<C4P
<21_HVX:?3`P;eAiL6DP;dI_KW@P;e=eHWAiL6DP;eAbMFEDNG1U82m2HG=UAVm^
M20_@D51@D57:fI_KW@`<30`<30`<38g<3HbI3MR82m6KfidA6EcHg9YL7A_LPXb
=B0`858P;eA_EFiYHfmTIB0b=R0`858P;dIYLW=d@fQQLR0c<b0_C65cM4=XHG8P
<cLP;eMYI7AXLb1K83Dh=20c<c<P<c<c2S8f<20e>3@PGB0n?PYUKVA_HVX:<SHP
<21_HVX:?3`P;daUKVMdJ20b=C0P;dIYK7AULR0_AVaQM6E4IF=_I6DP?Sh:LgAb
IF5]2WP1GE3;K/<P4;cc5G]<3a6HY6X?2:U:5LV7?UBg7f33fT:Z0F5ll=mg8FTZ
mC27fMTIQ^FWm[We;P=oCl5dV65dgRIL`YX<`X2CljbAH9g9EeIWI^hShfC^]RGS
g?XaP58<P7n@ILUYPmfC3@?NUMUK/YRLWf3gMN[ZY5]So<HIO@K1]0J;8lFmm?6e
Wa5h]NiKBk[;fiiLOa^OFdBPA^AX;YE</;S4gV3ZoHA<2J7EnJ`IN_]?>Uh<`gSM
U8eF1D8L[6I:BZ:7@^ESXDNR124NC:7gA0VTdS:5olJDMlXmK_g=VQ9E[dN[_bY]
WLOKGF>89J3R1c5MNLl:IFiTLgAbIF5]2VE^I6mRJPXb=B0`86mRJPXl?20_E7U`
IB0_AVm^M4AULf=bJG1dKg8P;dI_KWA>HFeU82m1@D51@DL[IVm^M30`<30`<30`
<SL`=S9T=f8P;dI/HFMc83@P;dI_KWA2@Vmh2U/]<S4a82da=C<h838f<cPP<S@c
=UdP;dUdHFaYHd5^IfaU830P;d5cHfE^M20h<30P;dAULf=UKW@P;C8b=B0_@f5`
B6EYIfQd2SLa<B0_DgAUKEHP<20_C6EQI6U^Ib0c=B0_F4QUJFMXM20e<c<P;deQ
N5MYI7AX838f<cPP;dI_KWA6JFaU<R0b=b0`858P?Sh:IFiTKf9Z2S8g830PKf9Z
2S`l82m<IFiWM6Pa83@c=3PP;daUKVMdJ20b<cLh82m6JFadIG8P;dI/HGAUA6ES
KfAU83hn2W=dLVEQK@Yh0IeGFf`DeaTnIoKRmGE]O0UTFWZFlA[RWEeLO<74Rn?/
a@jH`]ZHM0H:VOF^5jO5H:RCT]:dYT3[K9FZDZ@nA54OnXBR?Yba6hWBA4[NZUjN
j4^U?[CUPKB?BJ=NA4boolc^HW=YZhcTnKmco^oliknM<mjU2bo=/DJfc7b/[k2@
GfCZ2Lm0k2Rl_2Bl<Ol@<UUJ?;gPSKE^aYZkCYmiYNB=`b^<lLclG;kXSMUMb:5i
C7QS?P3I?Kn`M=4KQi>@FlnL:eCdHIY_FLQO[>c?oXRa>9]OV??h[Kn5k5^l<5OA
L`_SecgMoOOKN>j?P3SnPZb;JFYF0m[9OP1l_;U;cI2n2A_oO^Cj2n7T9faKB4go
k/P_JCofQnMoo9_eg<M[WG[kZaSFEn`X^l7BNSmk[U=OcogkEZN^MU9[:jlPVkc1
OSE]^Icod9Kl5b4FHXE5UmFUE[MaeT]P[BW4@akZ2RXDB]gdSL5D?FK[DcMI1O]H
a^gV:e>F75^aG5lahoK@j6IXVG7of4YQ1Y</Hn=IJ`WaY]hKo=hejGoMeEQV;E0<
/TaVXfLKlG_/?OH6Nb=`Tk707GnD/OGimYF?IP:gk]g1N?nm>n/WJ2bI:B@kIVE]
8A1FbmBT31hmK/T1GNjbWI8X7k>T5/ek@AJ<FCdBTLbF;6eTEQ5>fTW59CNUL4Ya
ZIVR:>Ck>NW_>KjjRcNT/hF/36J]R?A5kNTCE/B8j6E;b5`>Df>f;^@`XF7K5Zk7
cQOU;TaEAT;fTKj?V>oW;05_bWTQ6g:FPaU1^PI2@hB67=e1VWC9HkI]B9JciV`k
;WfVb0[YSnKQFB2M/fC0B<VPTD8LZ9dCUgkCP5nRj0IVDh8di;7^ND1_T;85jN^=
@9TFIE761ViO88XPYb`WYnNWKL^`8kJ@HdL]j7@:[K9oG0I<FIN>[J:kE:J261XY
0aTgDWVYcIHT;f036NR=bcYCT:^=jL8=?i/51Lj>>CIAW8ab=FB^eSFbM3KE6jWU
_]kLG8/6c`Z?`HDdhWI4]VcTZBhZGdbWW4ZQ`lVZUjR>TLmhFc@nI[W/aRX/[XFf
LE4C]I2AFVe/l:7H^Q6aNb=afFbjVYJEaG`V;U]<1224K4XOY;P0S9@]VfTdSE4c
AW4IQYUFUA:131CP]Va9>j;/2=V2Y<EUZcV9ln0_I^a^fCaWG8c;=W=bbYXljTgZ
4LbgZoT]Y/_2jF>F6`jSP?VD3<NXIm79:KN9G/ehBMj5B_RR>IaTU0O9BYEAGmZf
=f9PFAFS6dQ?Bg0DB6/STPWh?h7IcJEjC05Ma]X=Y3P]fNPZieae@k_9G:IUIb`I
=U8R:a_AO0gHf4T91m^odmK6F@];YLZ>^bDHTjo5m1e8D`MRJho5IJOYLY9Mb3?9
9dcGAg:[jOY9KS?M0<TWCCM8DSOM>Y:O<md@bLnKKSg9YdaT`L^k33[8/24BTYnT
0a:G_A^DGCGUNDlIfj3/ZBT_N<[]9Y?=/Ll@gaL@ggKh9A0Ob@SR8kT3lI4d41o9
K/A7<X[hB?HP?Y8k4Ao9GHR?Y6V:Y3XnLA=YKG=4VU9<_I27U2KeJ/:DlIR<haC^
aP6H@:LnlQPJnF63K/CobT0KaVEO[KBlBnk^M@>l<f_Q8Z<2OW5SIQiFkc75X?:g
7cbNOOPf`2GcB?MXWWGmG7d4<Z?6/;^7Me9`0dP0?7kT6PNW8SlLUh=VhXUTG0km
;bXj^03jG]B4MDE5@Tc@bDL^3iC;4lH4KQX;W`SL[;P>QSS_k41:Qg55MLUFd?bh
=J>:9^_C/KUb`Q0RFHJmOI/Y8^7ITWh/0U=8Qbj=/BU[CA<nXJmY?KhWkAAMY27L
bMPG>a_S><8XjnKcR<^3akc_QYIfRXKdYO=5g6EJ>Zl3>cH^P0OGi>4F[WMS?3n/
6mQQ7?51Z5ePka6K`16jLOfh9E2403X;7hP7?875?1I7UA=hhj=5EnGm_M0JCeOc
8>11X:NB1b>958gDE3:4fd:8LF>2=ZGZ9J/j5D`U`fc6BXPT?[WT_NI=`^Sm4PBS
61f0Z_Iemh[gL<LiAZEBl3L^meMgDmV_U<ZQO`4N3;UJgU5L50W:h[Q/CE/i7Im<
TK@CKX9gh80n/dTk[NLfJLLfJJ][=mYkL<FcYQb>KBAD5eDgC9UbGjb<eZ?n:^=8
?lhg53@Q4g0a[D:VmZgFQ=[B`;U:h9aiHFA`kn0C@[f^n_coKn:9AkGDInUKbS1M
DDUSF8m/j928GO4aRk]e>5K=`cQ6nf8AZQ9UXQ99;NP91=gY7G3l^h6cg9j@0cS?
cceVoP3<lHif>@S>@E?^QIRT_6FAH36>kfXeDhM<JV4iRLAnbEaU;0=`680C>6:^
LSFC0e0cDlC9@SE=7097RD=PQSP4SYU[^?NN1GXNR2_dIG<=?`9XcP;biVcRLIXk
CSb5CQ1?XJl@Cj6C]6LJ]5>d9h4GJ4l23^e984nLLH1IhQ0X48M0TCP4iYAO:J2B
lX_@JNDGXGWU5j4GUEn4_Z[l8_@eiANQ<lX_@P_8lM>e0YiE8cT:aCT??P>hB4TW
VQc3j3`nXh34^N11hWaMLDQ1W2D/7ZUIODV=e8ZG?DP[_^51XUn4WA7?i2/N9<8g
?DR4Bn0VJoJnYDK:gZ/N9?Zg?DSdkf1Ud[>gk44RG?HP4Kh;k_jJ_B]ZY>aMmB3A
[gV@j=o3b_fN_NmkT0P[7RC2JnIJ_En[o[>JR/W@W?AeibiF?m=aa_b<;O]oa/i[
Kk=;n3^XMK1gJH`^@k?PCKl^Pj`3</82V=7`:m/?i3eKFAncf3;k4O/Y9S@PiU/>
U/2YHj5gPWk`nf;mKI6fJ:@]/^aSWbi[K9d5BomjLcU@0_llni=oa3MNhf_4ii51
/0LSoY6k@kiOdiofTn^O_WTM^emJWmJL`2gFbH9[SHb3Jb@dKG1PE=_Kgn;[k=R^
JLkUg9ECo@>W[Qbi?;5hJ5O/l=WejM;]_g=fiMZmSfk?;ogi[olX;momn0kliN`P
k>f^f6/=T;f>5Zg>6?D=3RBdWOgK]BgJKVEZO?7@Dk73im:GLeM?mV]K[Y:Y2goi
fcmGH>[3<jGKWjcO8g__[/mc2km5OO1?loa[jnOFFfn]cmM=@gnNOn0OdEkLX:o5
bCnhk^FD/bePdQ=T>Phf?A>ad[VcBgfEIloN_Z4maKfcX?`70B:=Y@YUKVAcM79U
HFd:IFiTKf9Z2S4b830PKf9Z2S`l82mDNG1U82m6Kfid82mCMF9dNG1U82mDNG1U
<20_AFiSKfAYKVLP;dUTIFidJGAi;DPP;dAULf=UKVAQKWA6KfidLb1K<SPP<21B
G@X_@V5cIDI_KW@P;d51@D51B2]VKfid<30`<30`<30b=c0f<V@gHR0_E6mEKVUS
KfAU838i830PDR0n?PYUKVA_HVX:<STP<21_HVX:?3`P;daUKVMdJ20b=3@P;dIY
K7AULR0_AVaQM6E4IF=_I6DP?Sh:LgAbIF5]2WP1GE3;J/@`3;ck:gCL?Bc>XhDN
PV7I/Y137cC]1cRf70b=KAcWT;n_k;BkD8456VW68o5;om`kVh2oAjl6C62/da4G
_dJ5<>9T7J/Kd5JUgjYPJYJ1LB8?fi9`kYgad7D<P7l@IDUaPl=Ina6?6G^;6Z=e
4abn;T=1QSF4KicA9JRH4:3AT=b;3:mbA^25N^XemFgJC/BjCga^0H4L4J?N;BV_
L@UBHIA^@]IE5::kDPR6C_m[]c]Y=?OYFVA>cZfZA15X2TBiJAjNMZP]D<j]NBc:
Oa[iTgb@f`9ZSI6lUj^E]K9Mjo1ff>13]UKN3g6DNKP:IFiTLgAbIF5]2VE^I6mR
JPXb>20`86mRJPXl?20_E7U`IB0_AVm^M20_DgERM7U`IB0_@dU4AVm^M5AiL6Db
82m2HG=UAVm^M20_@D51@D58:fI_KW@`<30`<30`<38g<3HbI3MR2Rm3BDACNG=d
IFe9KVI_83`l82mBIFMYLgAbNB0X@FA_HVDY82m?LVAULVU^Ib0XBFAUKWAYM7TY
82mCMG1`K6E]IFid830P?Sh:;eLP<c0P<21B82m4Eb0a<30`82m6KfidA6EcHg9Y
L7A_LR0c<B0`858P?Sh:IFiTKf9Z2S<`830PKf9Z2U/P<B1K83Hg>20e>3@P=3Ta
85dPG@YUKVA_HVX:<c4P<21_HVX:?3`P;eAiL6DP;dI_KWA4IG=SLVU`M6mb82m6
KfidCV5]IB0_@D51@D58:fI_KW@`<30`<30`<38g<3HbI3MR82m6K65WLb0d82m6
Kfid@T9_N0YK;C8a<B0]<CDc>20b=S<h838d<cIM82m9M65/JF=1KVM/IB0`82m1
Lf=UKW@P>30`82m4IG=SIFid82db<SDP;d=QL4QUJFMXM0Xg<C4P;e=dIFeF830P
;daUHFAYKVLP<cDP;eQ8IFUWJ7@P=C<c82m=HGQGJFAdJ20b=S<h82m6KfidAVU/
IC8P<c8P<21B83hn2VE^I6mRJPXc<R0`86mRJPXl?20_C6E^IgAX<B0d=30`82m<
IFiWM6PP<SDa=20_AVU/M6Eb82m6K65dIDAUHfmTIB0n?PYcM79UHFd:N06MF5e/
75LE_WMVM[efh[oHjmRIe[kSlCZ9MgKSa?5?4/Mam/N^hoi/W:BMLFXbVedk;RCD
BM?P5T9=Bb5MU19AU8L:2Q8o:Sl?Mf`ZYD6E:Z@:4?1D2JTll<93Q11B1D8EX3Ql
IlK[fXT3Z7kHniec_W__>NNNNfK6S3?6:]T2DeUMhM95LNR7Om4HDgh6kN3<g9Uc
UhZG;d7nT;7ZYS=WWi]ilo7F4VcOPZiiMSYOK1Ukhcg6jR;@mLe2/Nf1VTk8`i0k
I/mMW=lBi[LQ5b7GWGfjT>Mck0n05b5GWL_?co5]=EW82i35g8GY^IJLDPOi^i2_
<PEn<GDQ?0?_:UST[K36VM8MkjTgjV=6_K6P/]/;2U]VhIUo_[h@VV6LcC<FgZE]
Iad/=]b^:@YSXJT`3hGZaeG>NBeo6>]f/8kVJ7=cODE5BiaG63EZ];5YZiWT_G^7
U7j85NH@kamBnhgnl:kFiHoZSIJjc84?^^?e^ZQM?]9TYLoTo]`ad[IoK;NaIOWO
[M[fjj?G[WeS;?nmlLMnm>CH]Jno>W[QX`oo>=WiB5O^kOMnNNXjD/G>lbV]Gi]T
KN`@h]PUJRT>GZ>JkDW5K:mA/:OJ/jMEjMT37a[^XmOj@nf7YdOjIPZWM[ESLohM
YG?dZFcOVL:YI5^RMH_jkAEkg^gNd:i=3UfdNi<3bNJMoFg3cccA/k=kIcBfnh7U
[:o_Qki_[Ak9@TjobD;J[6K3mlA`5i89GHQ=`j2XG9UVZZY=<Df[eBRgKJcEj:a_
=5IbBi4I5DHhfXS@0=XkNoOf8KLmfVa/nHgSccna?jXlf7[kCiGVhJWmo5C7L_7=
kmM/fW[/YA^G=O/Wfammm]6[?Kf79i9e?oInd3_KLnkG[dnACa_m_L?NHJnaed8g
LNBg]1QSbk<=Eoif??CnWE^@3mji]GbBI<T/8MT9>n/8<Gj3eA`MUn5STkKLZl/M
SS/SBRM/ZLCbKdMHQ1D:iVWM<2Ac94^KVDF4W7IC2LT]:MbIQ5@/DACbgIcD>RLG
Mo2ZM;J@UN6/KDPeiTbL]0gCd4^fT;TLE<>>;^@0X@774Ek0cQOU3ZQF926kbMi=
c7Mc]X0gYKb@ECWKQDJ@[HY@7j4nEgLMam4USc^>:EW>WWJLQ5@]TAEBRnGQFBRM
/fG8C<V`VD8LS^A^@VZF2Km4d@^MCPVbT<Mjh07mPY@]B;G;P34]BZ:43Kc^D0a1
7[GMW9jOL6cC<A`QQhoI/>TDf/[n2AVbI4Dj_XR:mc<EQVRVC6CLC>FULWY6lP8f
T:6^Q:b`1;Vj:EfhXK7CX<3IHMLQRY_aGHeHRaFKF3ZKjS9FLemY[Cn;ZV0E7XL;
JLC]RVc9c=>in?UR>^ED2Qe>U[g4jISiC;35Y_]<UafHQLV[XJfM]9U:b4`]KZYB
LMRjJCQMAT9FFijRI6DaWdW86P/1224gYhm@G01VbY7E94e0ZXJDT;EHY/i?RD06
2W1KeZAMDG:5[47B4[;>6Sm^NeXahgC8jVUc?R7[[O6Sm_Ra@:TKd3OhnRfFaf[C
9fb_]QH7V4o9fSSE;2XiiFfVWf[lB=j4Te1S>M^S@TJbDRFL;fgKIIRHE/JX1[;C
55`5/SZ8I1CnSd:koZS^Lh0NH`dVDYbFK6PAWMN_QPJ;NDc97[MU[ITBFKT9aEN5
SMfDL;7mFoGeW=F`E:[TNU_2LOU:G6m7VQXAFd<l8J>FafU/@YiYg6Yi:Xg=UZOA
f69i8AZgFEjHA]gb:VQl`?8R=3iXNIDdk[B@QB3_<^`R`jI8BSi55b@Q^mHHVeJ=
i`=SO8faLmEh8C2fFTaFacm1O6f8[aEn2LA7Xh7hJ6a7O3BJR8o63/A7H`cadMR9
n6SLS_QXg87hJ;@/<NQOWhB5]=Jk8TdYYU[8Hi@FeF[BTXVhC>0Fk/8564FUKWP=
cOb0BAga_c9@QPWI_GZd_4W^j_92?9ZedLSX07N_cLbmiSfFj?Gmk@6?Ino]1VPb
6kY7N]I4KbZ<IHK<0Fl?Se9`Ni40N;cQ71Ng8Sn@T;eFL^]P@_Km;bXZ^01j?lj4
=LE4DXcBcDL^adZUDG<DWLK68`:M5NfPSo=X8e8jP1KE9>]0dm0eHci=EZKSdjFT
:LAP2N_]FdlAbF0]ZF4BV4:je3B6SmY;RU25_ZAdZ]^L53GB27Xbm/G>iPR^<8ie
oGe4ln3ah;VQY=fR:MEd_XQNYZCc>[3[X07L?BL?]m3NcI7lP6iRQa74Ql7O1N]]
/0TLXHj[XD_P44:X;3`Pk_84:nHa>NHkPEll]:QEO[`GBV=o>@l27X@jEo9P3R95
1eI=<X9^8LB8>DZKd^T=UVen<2/II/O]Y1S48iNlE`8U5_gh2<8aB6<`[CkMPl>k
]n9LLnFTh6m27Rc_iVMoiJQLNPFh>nCbl@jQDB@YRb>b;VgWM3`baJ2Cm9:l4AOd
d3[[Q9iKIaeNIbg?GK_NgC<>Fg8P_YI@WUCN<6G9OO4BBXoZZh@[OCoOL:19VHB;
JCmT:]obVE1IV[QGBMbc88`<nPhN8EC[OYgoodDl^U59OI:jY@aCRaXd1gASCHDH
cXZ?FOCFPGPi3b>@m/D=>RG:a4XTZd6?8^QXL<7a^X6kg92DNg6O7kZ?OPc;lLH6
f@_>4D_fHaRW_6FAH362ifXiD`mKE<9b78Uma5Y4/`9h580CN<aJi;hV1n1[SQ8W
2m<4L@PL8`j1hl@QL<9J@]Lk3?@h4?OA4mHB?^I8I`<5>XMhW7BCa??ABN;ij4WR
nFR:mTb3mRWJTl0YfY>0Bg/Bb1=W1>0dL@PDR4>PB1`2dkiO:J0Igbm2Igbo2<gj
OQ5jb_N;d:Mm_`Qma_N;d5WO;d;WT>?mZ`OhFEnB@c0l7L13P7>DM:;9HDSWlAP5
9<j501;W6Im31^9La>@3Zj/njd_nS4/1Y1VO2b3Aik7>PF39i`98Q>L3B8C?Pc^h
^]hGO<UOkg80ROk501;m1L`L3=IK220A_QA08[`8k/7EmEkb9Gnm;`N@j2l7T>QO
`Lb3`GYO3B0A[PB@2:mHBiFJDWiICLEUI5ZZ7KWilV<jPEZRo`=/I^cbRknO?eDk
n0oF@YodS?g^/IooU/H?7[onVnGLgiNRN/=UR9Eh``on<2ll/mc37X[ZbkUo_AoE
oIEFS?jPhAl:2j5cK5kk:C^_oQGOTh`e/b;k1LMn?U_SHKK=in8YbkJc[`5?ESOi
6WbToFX2KjclECaUPlnb>HmEY1IK>>/R/;@i`R<1JP[k:9:jZ@iShDYX:e<gf@YF
FLK[h5N>hS?SR^fYaHcGBM;=b0;Sf_2E0]je@L4gUK=D4n6K^fk`>bm;kBZNo9VU
D37<<QThm1mG5IF>2VE^I7=dLVEQK@YUKVA_HVX:<C@P<21_HVX:?3`P;eAiL6DP
;dI_KW@P;e=eHWAiL6DP;eAbMFEDNG1U82m2HG=UAVm^M20_@D51@D5::fI_KW@`
<30`<30`<38g<3HbI3MR82m6KfidA6EcHg9YL7A_LPXc<b0`858P;eA_EFiYHfmT
IB0c=20`858P;dIYLW=d@fQQLR0c<b0_C65cM4=XHG8P=38P;eMYI7AXLb1K83De
=R0e=CHP<SLh2SDe=R0e=CHP=CDf83De=R0e=CHP=CDf83De=R1M83hn2VE^I6mR
JPXc=20`86mRJPXl?20_C6E^IgAX838h<20_AVU/M6Eb82m6K65dIDAUHfmTIB0n
?PYcM79UHFd:N05MTLeZ`c0@Q>mj2QgC@k3/Y4T3aQ1B0SkdQkYm04MJ6d4]2eTn
n>dkZj@Ym327KgO7S<KIZGj^WHdbN`nSKRS:cSXCJ1[WX4UNZ;M>i8DdE/LKYITN
FRlbV9]URSCD[Q]UF@XY/`mHYQPF^CZJlD8??7/;QX9e_EamWIXdJFK__fTP5jDB
EBD=MOSLBn]Ofh5TUZc[fV1_hk:6jnoRLo4TT@R>o1Y9ShHVgfX:[N]9U4YEiOUL
2G;VgnY`=EbjffFAEbE;ZDeNRK8XP11``kP1@TXEa;P5?ZK]UW47Q71lH=`38F31
n0B4P7_60a02kQQK80AD:NM_8Xk<eMj[d7<8J27eW`[RQe]7meoTAll?COX1^AV9
60YUKVAcM79UHFd:IFiTKf9Z2S<c830PKf9Z2S`l82mDNG1U82m6KfidA6EcHg9Y
L7A_LR0_AVm^M4iQKFDP;d51@D51BR]VKfid<30`<30`<30b=c0f<V@gHR0_AVaQ
Ig<P=20_AVm^M492KgP:Fbdf=SDP;C<b=B0b<30`834`<3IM82m9M65/JF=1KVM/
IB0`82m1Lf=UKW@P>C0e82m4IG=SIFid82db<C8P;d=QL4QUJFMXM0Xh<3DP;e=d
IFeF830P;daUHFAYKVLP<c<P;eQ8IFUWJ7@P=S0d82m=HGQGJFAdJ20b<30`82m6
KfidAVU/IC8P<cDP<21B83hn2VE^I6mRJPXc=B0`86mRJPXl?20_C6E^IgAX<B0a
<3@e=R0_C6E^IgAX83Lc<cLP;dIYK7AULR0_AVaQM6E4IF=_I6DP?Sh:LgAbIF5]
2WP1QGX9H5A5dWme_cM7<]NKbCE99S=_638L4`b48`@RNH44e72CH8HU9X54`Z60
0ECTR:h8A1Ad5HEEDEMGD9790@b72`[ZRR:^l;7[SKO[]a7L3gEG9O?omI_Qf[oo
komNZ[^jZoZZZZj^OY=5=be^90^eT4CmImi@_h3d9g<=/[bIBaJYlK;=CFB/_7k1
[1_RiIAiA8I_IlfkmOYh>O==8_/7CHge3O4boH9lB1<ZhVDf27W?YQ/FgA8_Idi7
WSM_o/`4?K<CIOL=mKLTaZL?D5I_[;nQ<LkONb_boP]^JTc@FCFAiDmaf/GdFC`G
Bl0H`49ia?EJCP[Ude@R^DW>dF/4gL3GofKm@kiJAo7giVbcG_gTIkgj2^B@_633
Cc_>cE;8K4DaBNm?4=3>=:9k?8eBj:LM?beEhR<9b_W7/XLZYMhM@KO_kOeB7cX5
h5:OmU2>KhoDBlYY7nkCXU:P`iEFh2S]9jWX<Em?EJCc0C/01`0beDYND1FT:`4]
P1f00h2g0DHRY8:Z0^H3]P1>0HaBS^AYEge:JBlY4fdc8@F7U46W0C60A3jTnH09
P5[0N/0FP57W4cGc0B/11`1W04KBY8cfn`MRkQW]Mn]Iaiai1GZa?UjLGZ<G>jh=
ao=aTn9ifMEa]V5a]P63h]EGS8cW_O;R^B^gX0FMMbCK2PjFYT_YF6@j9[h0:N>7
bL4HnNQa:HdR02iQZWZ=9[TjNPH;]Qb@I68BUaPeT2mfD6;]=VM1JC:?lM?T8Qoo
UWO5:Kb[`nh/f59j3OnDMP0>02Cn:Mi?n2NdTYlB<TMJ0]P2>00h1SP=<?9CN3o6
na7oR1cl@lX7U01Z0E/01`2W0BKn8E:5Ob0/ATl5GP;Po0>T2WlObgXOZH>o1n`m
oUk/83oNGUQD/4M7@_T9a9NK@3:b4hP[_B3:gfWoMamHE12JQTG]Tg[@21XXmFS?
7N2;B^kfh]Vn:?n/@`gi7Ro]cdm@1<0aTa<Hn@BYP8V0>/02P17HBF0WZ@F`0O0h
80:0UB5E02Xo0WPCL9;j0cC0A82I_mf>HJ;lF7]`Y:ldWKo5Gj<<B?`Xok>N_lUO
eO<gn2]joSYb;nQ7n:_]GQnEFT0W]56@:lSc@CO`UcYj^WbaDRLo00WjT>H3BP0C
0;F0m@0S?l1k]3OhG>QT7ag17_KaM_ZkW_nAWSBC=/NW1DO105FA18MM2@c95WE;
T6_1SI]@54W`g_^1RBAhicYP8PT^_AfHB8;cUP0CBK1Q3S2A1:OE0Q=9L48U<2AA
o]S^W[elQA?V<[GD`Fn6U6j6U6j6U6hVVMl/G_Zg;>KhnoJnOB6acEZXCemObekF
/YneC6H]Ck:FA]JbP[GLcUZ:FL]e[2G4FSb/aL]J==JbS`f5:5ZHeWUI/DQc/iHS
[6DkJfUV;D7FT/]JN[8FUAEZDNi__aZk3UViWWFDRTg7oAeGSX3gLG0o9>Z7cO_Q
4`hP?@J8jBD=C6Z?>7>VEn@m>_ZFa<]G32^HGgXE?hB6Qj26@o@a@8J23/6<3Z6C
@nS>PK@4D0/h23P=R06<h>j1MJcGD`OBO409X1J`4W0JH=BWLaYChC@OZISR3WeR
nDQ;01=4RAo2f`>_Wo^e7<FSQ9B[Y?DNi_2b2MjHUaMBNS[l//]YMTJIKMN?]Wom
J:>TdRAn;em?>E34QTBn__gO>KhXNkPm^<mGV/HN8Zl<Zf=556Bib8MB/ehNC1jc
Z1m47_hLlX9fce@dLk@7lgakVEfdf^Gk]nMcgmlmD@kdJllngeoEZ<cJOOn5V^Mf
nDihe_YNchnJDK<o66G8mZXjjak?D=of8c[[kB1/K_N]4=T^gg;?6=mLSdiXS1>^
JdI9LoPV1jOi[T9oIIhI?ZdIONkbUGR^laG7^@J;=[]loC65D1c]RlWflNR31[aj
QeF5DMJTiITfVZY=4da3C0FV?9?Oi3?UV;9=ZFJGFC7KcEIc/]U/=YYU<cNC>CDJ
>jF5a:VGJ]@??b<<VY6/h`Xl31=^1RUaI^Id3DEBY0YN<FDTZhPLW4TE<mC83e<2
DIHlJE[441S98Zh:ZZPL6ATJZXRJHY<SQJ6:R6WRKj[K6;/gS=X8Ga=UE5TMIC5A
]BXkhQYE_HLHLjjj9e_T_EOM4`jC>ge9RK_4=L9I=;[/Ei8j_K:^;7CaLEm4@ni@
CVASaICZb;<ihDR1@68ihH[8kjJXdj_g/7nb<nEUNmQg8P]Gki56/7nFCaKedXRb
L;PRbZKZO:Bbkl07Rd46?S<>I/57Z]TKim/Lil]5No3e51WhTY8XEnO;CD[BnF@V
n=ZJNiJG]OE40Yh<UIYeW^H<mE:N8kWPbDD2W_@F>Z;c74U_4CbA4GXg7PmH_4S0
`[;8Xk=hF9K>X/nlCFO9Ck2/_L2bEQm9R/m6ia49^[6M>/mS>`FNB`Ci_j>=8d<Q
eS4l?7=jNF>P_2i@gPRXRmbmY<TMJIVQZVdc`h:PAZAPgHbICB:_Khb40heUTIV1
<[E]^=k^?lSC1GUhX:b=YYMGE[M=ea[;fXM[`l/3mFGQSS4C1aEN=]KJ2f<=V_P[
HddDW@dBHhgAfog7F8F2?4J<EBS6:QASSM76j6>AK^<CZm_<=38l2_XCN@Ng9<=N
jk;mhI7YbX8A^_4>mk]GI>m5];:E;:5`a1XH6K41Q5gg:neG:TSHDh9TAkDS@G:_
6>k?g/^f9TP:ZYf1TAAJ];Qi<KW;IiO5oi[aX6[AHZ6:N1XBMKojP:DlX]FG=BlR
ZXSdWE8A:ITd[K[=I49]GETHML?>eeT/iM7H`GSU5JPL9QPUj@:SZ2/FMDU92LKo
faKd>J4Jd]V3@6=O1m>lK14eQjF8]j:B`aEDCX<HYTn[gX]HBQ`BcF4//9V5F??i
g/@jM9cR=HAU=in7AH/CF48FRa:ic]XLXU3cNI6LkbhTQ:DW^Z`FQN3J37/Y4i1U
N8HbiB3QoQ?k2_2eb;]WakhFM97cKn3XXPTPfT[KfFcJCPOXIGH6[GK@7^XT4@:E
dB>dS1jPeCSFYZ5V;Dg6Jd3m0b`ceXVKbA<h<9nPXn2mUUK@GTYWk]SOJBF]TXjS
eBZbD@lZYHTdWniQHf>;JCYm;?nF2VT/gDP;F4^/>WI_k?kHDo@dkI7n73^7VdlF
cLAk=?J]hFna3jPOFSa8VnQSMWoBC]8`BP/h7jFKJ;=D8k?H[=Q?V86OK/HLI1Y7
AmU17T;_SO@ELk=UdRSdlXMH97HHG1jZXBKJC7_IH3J6n`gCHn=RAbTMHmb2GSMA
>ng26jDGjCeV=Ib9?ADk@iVhREf=mGCBFnbPe7g^m^hBb<d0:OFQ8U3VdioX=GZK
1MQ;O;k1JRP`J8JU/A>DBP>X2[=m1RfoI3ob5GQGBZo:Xf<Sb@jig2NTCJo@9bb;
iK<9K2[_`nOcajBKb8`A1n1]X=V@ml?XoB>HdBi^iLNT?lS?bClKLkY?aNc@B91n
ChoBBlb6UJZ/VMg1C[;?n2QNbgo??iDNT;O9kiSZ/N[[j0JjQijS7iV;3FFCf6mH
4e_6E[?kf2IfU;g=_^JU_9;?iJNU9VVQm:8l4^lD^EWn[N4^`mg6[k^[^`mgojGk
aeQ1k2jJ17^h7K=oT1k3b_K@<GXGklOd:C<`2k?SEIVOEK7Kl:iPmk0WfEJfSGER
U;OIYnc_>9:nIcmcW;CLb;<Ao8P@:<1_@XCi07n47l?k=_l7okND8OF@@]9PZEP:
Bo<aZmGB1[`kYDoT;?VH78>L2``K3E/<F`g?6EhfW35JCGOPS7ocUcnLjg_^XfkZ
G]>m/K^m^c?f2JE1QcPmL0D[a^c[lLj1_SO2hWK@LFJ5k;9HGcJ2SHETJ]TL]Y3M
0TWNbCJcYoFi_l3f@dYoIJLaIa_gj7>nPPoV8oT4_=OaA[h@`MSm_9>Oi3m99/TR
>J@dZJldAZZA6ZE5dZgBARTR_BUm:7dZoB3mPSLV9l/n^HLLU4?b6;UFGR`o9WlU
OfFHKWS3l8DafGR3lBiSe?PMXYXAYXVVBJHJdg[C;]<9Laf/la3]Y=f``0/?>bGM
;YE;>nUN?U3>a1GV;MQc;CE8hcP/UFmUJoQbe/Uk6Vha3^O3fGPj8`LQjeOi5_h3
7bj=HaE/2/gQ0n8M6U=UlCFRF3i4GO9n[>d]m7b;dLYFl==6:kDSARY2S?B:e5l>
BFo@Nm;7c2@o@No;bBb3MO5WY8V`PQOU4HIZlT^?d0_B@[JLM_9bX^BOcN]Pan?I
/o0;UJb0oD^:8@`N3b/ZU3jSgm9LoSOZ`SiN@`na1WTFgD/3fC;jR_j8GM77L:>a
[c6=_LiWbjdlQGDBUkMQMDF/9i<<ZG@WZi4f6docMfTa7I>CjB?YNLcn67m16RNO
<DaVCMP1bnT^FQRkWFheE<__/5TT/JVD:in2Me/V5LQni2_QEJK3Yng2k]h;?e0Z
SD>=6iHc5WIA1@na6No3l1<b;6Pfm_Rel69_DJNaTTMYU/7>h7G`YNJ=k/Td;OI7
fQBKACO6kZMnl0N[Hl_@heKjP]KCE[JZncIJP:_T^mSKH`fSnC73j5Pog/[OiE?h
a/_e2fWW<SMmPoL5J6J4HAnebWnU:E@BFaOk;eQgKgSHCC@30N_WF>Fg6>4ZjB0=
k1k?ff:SY@EHklLd:OI<c<NBZBTfSbK@OW[JI:1jD`PjS[1g/=kKZ95?SRfB6[]W
@`k[8@D=dUX<ok=F6eEEFJZES;RbN?R`XZ65P`L=;1S@?on:OWVQ_Wejm`[VmPcd
l:/nKhhW>b_CWI6NUY[RLRX>^leZBDhbVh`6FN:<l/X3Xn_DB;0^8PL3EegECi@3
mJRX_jBR;Z:RJ_CU?15E]:/7jC9>3IcGo`NW5^OD;W0bABfVhWiiJWU0SA`]2jQA
=VeB=O1kbP9Q=M:Uhn=dO8>>fh3koFRPU[^Kb]@8Ze?;8j>G=;FFeiGebf=]U^AA
PE6=bOgbZ2gI0]@2;98AF=36<TH`7N4IiL?J>9U]F68T:e1F7/T<X2VjTG;;ja/R
4bMEUiMUnogQOWTA=VYVH4J4A:@DdUUXU3i<a3PZH]:7DFLSaXW@gFYKg/7FME65
I]B5[0f1Q_[YeA6Y7WfDAi`QS5/FbESj^O]R4IdS9U]m:CEKJRegceH5Lf_[JSGb
n:CZBmYVndD?hC3j@5^N>kZ^MCB6GPM=EHQH?<9GQJ/SK1F6A62IZjlZ_[ihe9]K
=dN=90E61YYJimA1=EV]4IYlZklm:d_K4c]5FNEZJfEe`1lYb@j4jl/lKJWD>_WF
STa=cKbLdRn_CG761M]VMb@@ZneBY152Sm=dC6LGF<GT2i9UHXj1Za49A]BI:VIB
7L2JQXZTLBRecQ`:1N09<kB:=40S/b=9XnYJUF6R7T]T4D>^4U1K_bMH@:3[7iOG
e2MZS;W:mbB8`Th^V5Z4eIo78j5@Y6mOHB:VDM0YiSQ2;`o^UkLTbP>11@[^cn;B
@1<Qfo[`/7b8gnlG2[hkZ]4<528]Tj[SIIEVI;NCUXoHV]L9b/7cU;@Z@FTiCkW@
_2h0BnhDmeU:RiR35ohLBWY:NM>`24_oGlR=LG[5U405@V>e_;D^HKDEUINEhW@Q
D<P=]0@FBAUE;FEce0V<Id/j=AhQWfM1^5a]SLRin3?ZA]d@=IUQUGX=DdM7U;Z[
hVThfNm?k9WoGj=Xk8aXYFLGVbFF4ATFBT`d?^g8l<_:Udg?fRYEE<;UL4Cf[Jg9
Um5PJ_5IGYg8H?6hj?_EDA6Z`/k<aAn^74<5Q;<S6T@6BREfTEhMcThD;f?<CS@:
ha7FfBm_=7aVJn_XP3Zj]Jje?QY[VA5@UD3[7_hbOkUe@CVlGMa`X[6mMfM7AZl;
@f9=K1Rf1jNAK@6fIU:Ka]I<VEJm1ilhe3FEeNfLlE5e8l=2;GaDIGE2;;Y2Q>U3
QoS511HS=b=:KjJY>>_g8/l2E2FP67TmH9`X`kBHKV14ESCdX^bWI=A`A=/bXV@S
VA3?9Z5>?>ThYfmR6kPVNNFQQ_66Yh`KC3ORJ`]81[aXHd87C[lc5`UV@KnXd/5O
=0?mC:YlD?C046TBomU`43g^d5A9/cT7cIEGl_ElTeUnGVI9I3A`:LW0[9`MBBHX
@4_f1`Ke9jJR;Ch0MBX:[`;bSNId>81i[5JTMY]=[cfSICXLaRYB[5JAfVa8/j`6
cNHHI11mfDEO1ZHRa^N6C<]NE/aFTC/dG_VlIV4XY?b@^9^QD3c^G36EU6@D<FOA
P?j/QVY2oX3CJ3@=7S:TL23o^K?dN>E3WnH_TVlK/Lcg`YPS]F9]Df=Ob^UHFhR5
fkQ@T6K9M6]RKVh?<C61T1D5eRN@K7=H7MkTi3iYGXo/kN<am;45K5Ig9R>GR/Wc
:]DDS<JnkQC/`Oc@DO4WGW8EUI@XGDZGZbRojeGUEENALSQD8610ofb]]l6FKR^g
gFFCbigG>YMTBi?CibUcDQ_B5m]^CKg;eYZj=_]YFk91ULBG=8_5J[?;9XIaFI@o
eJ5Q0O/@Z?@Q6a_LJKFVbNjmo2W:i4eJ;lcBP6WJG<fejWbEZfhQFKG5e1cDQ4B3
S89:T6?6IgL;BW13?gND3Fg??<kf/Z6h_1kD;>1C4IA`fY0GIONggNf6^6]2GFNk
87G8^n]/Z:J;B[Y:^/imkQB;DlkE28@iGAU20D>72Qf`QN6D`_CdP@E31Pl:1WZH
2RnPAU>_8D<65Z@SOS6JA4Z17/6YWKh7ijkLlNCbPF=CGIKVj5ecIZm;kOAoll8]
AnINgg37Q^j_CkhDHkmeKeXM^F?I4jV?lE^FckcScS_EWJo=JVnXON@:kh_g7^cn
oT_MK_M2`J]aAiDXEg?cHT[VaKFh?:k49DAn7:9kG7kRHGe=nS86m1lhN63JgZ=7
Sl;LLG_1Ed[LgI<QfZ0fa5E]KK9^]Vjc_VheS9G6fQj@9AO35dj[DC8ITRfBRJaF
Vnf89:M:TRcIR5]]/TWJQilIc=Q/Sf_99<]PXB?9LYAO_m]PB=IbO8>Bcnl>85mf
2Z<3lRd@8a1FZ=U<FXo085>;Ok1YPh<;HkCHDPLAEkS:9IA?jFf0O;i;]>4kkE6f
C]OC?d:Q6WecW1GkXeSiD]7gQW:fn8MRIi5@DE7AjR]2lW;U/<?QP;;d[bbff4O]
[R9K=7I2/``/TW[d:i;TW9aRdDDHZPB?UV[E;4GFUXU5EReHI>gQ@Mj_B324`W0P
PmU0il2dP5=b<[kag9gldMnmnVYWmf1FnkBdjiM[W^inP/_l`G=c8O^Zf5Nbgo17
l[:YlGf7[k=HWdd8PGW/bMjd=8l[b_MY5XL/Ncdf>b>C6cjTDkP@7M7gJ7i8gfFj
5L84cag6_Q;KZXl;jS1F>OBd8^_FW=JLSBW?Y1bbW[BnWfe>BW7KnfI9BOd=oBek
4B]9f5]:BW:J:bGUR=fAJTm9]C]/f61JRYR8IWoLc^efQiK64Y?JkI3ILK7iX/b]
ZF9jcUYU_[9BFJo82[JHFmmRKTI^aLdafOPFLfm@GO_IH?`BnB2<JVRkONN_KCGl
@73YE[^hfF[Pg;Z``dZ48jUa0^1D?Um]_R9TP1H96]Gg77KM`QYXhm9=QifFhToc
BmQ]U9IZ<V:OEKfH]VWN7IgKeefk[_NfNoVkigI?^?>nPlblj9jcOck7FYCF^`lo
^KUm@TTjonkikRGC^gohbf_g]Io2]/;N4;[;Q<odDUof@Y]AN<gM5QnFVn_4HWn0
RXa2AFMe@`IbA^/]W;_KZF_3ZG]jYm^I5k;dmS[/?_/4^fBgYm94aWB7Je>LaRXV
Y=[3Vf[@EG/hE5<PE]eEX5/^]8joT7;da57U`eNPkkP9GC:9RgJRmMD=aFTE;_[o
<N[UHog7D1SYhT3JX65IHm>e`6oB[`eL;le;_b5[EV1YeW;_^Zbk_I_C]fG]coXV
oD_e1cGUb_C7d[NWBl?j=1Qi;f5S0MRHfjlJeMkN2OIJHE0N/CafO::`8mkD:BJ1
WhF:b<:6J/k;CFQ37X=ckZBM^Lg>lhNRj]BLg;TQm=ZUOUVhIN6C;mQ9El8XZ6HQ
Z`TW[6847cbXUa5VP9cPPG5ki<8XV?3@a[ADhJ8GK4mOESmUnL@QK<Rn6gKm`Tb_
[^njKNUgCcko7WoSjDFg]6mK]_`9=TEIN^?HUGmKH7E?WL_<Oo^H:I^k?n_nIoMG
gAd_7906oGkGhDOFkMP1=hc_@2BKQ<f`en8FXbDi5I/k9LEH1Gmc]]<9W@?iET]B
562@S1N7ZIHQ6;aN@OEjk:1hMA_b2/mPiLTI6ORo1BOWZTlL@2N>R_@XiGL9Oe@R
d/?RT4dLk690Zl_5m@6e98LCF7`LW:b^55kUCAEeX^mfM2g>LX^5E`7iQjI7:klf
6_b??YhHCAm<6c;L<=bhcg30^<odV_UeSnUZJmQJJIm[KK0_MBe=FN_JkoXRjh_/
<eWF0iKM:C`K?d?V:5k5n2Mln3C1C/c8Tk1U/[c9R]UX?>;9B_Eh//bN;0WWCII7
/WTELOA?L3;lB>WN:EI0^SPLS5^CVc>>@m[2oK1mo7IBBH4aFIdkBo21LSiO2ONk
UoO4Ci7[4jNikUj:UK>`VN9caK[MR==K?l9Gfjl8fN5Ja9HKd9n6h/6I?W@Xc_BJ
Vl;Qg3Ao/12AeI3h`Gkn=<MQKSCQCcKmD/PcL_n`nOCFCKOMl@SKTo:__acohJYW
GWib^WOkm];RV@MG7?kRn[VoNj@eiMRkgfb_OWKoDf_ZaALaQZn5Q9S/6Gc7GZ3I
3m^HS3m^UY=`[PZmmnM<C[;JVRF9RhE>d9LVlBb7^CWY_fT2?RSFLZT4fGbfT/T/
4hNRkU77:fM[5QJ?>m/eG_U1A8/:5ReFGNCDcd=/U8De:H?mJDJBS:K049N[/5kJ
^JjkZf:8Hhmdaon/UGoJ_^k1KUOgcm7g]k=_f6^?25lh3[h`3GJM0elh8F5X?POc
HGR9IOOfJSIV/l6H/`gHkKIT;ibT0W_G<XEGD[`IRSS?<_Ch<@>V3Eah=Q4l`[Nm
L_iLZnUB3]N8LjgOg4aFI];BbS;;e6V^BWF^e61Z<<ma=JR;c8/mZlagNDjJCj@k
CJXhoG[58`ASED0?7TFEGbNH1:6G6U3mP^0D/iaXhiQW=S]N6gM7F];i>@_?XkV4
je7dHdg1?k`PX/LZc^`FKUgIT9L/@TH_:m;BBc9Z<nIW[<b@<m85;B=M39XAiCdk
4Wh:LDWGQOPa4CgZDB>LNl9ERLd[8/L`<`Ek`B49Ja:1XT^HEZ07>IE24CJbe8]A
YE7j^L>MMoGLZJEE<gSYoUVMifinnli?^SmoM>gGfcllEcSQg_4g?OGTKD^OUJOH
io@Oego4]ao<[>_nlIgF[QGh5;^<KG]Yjl^oO5ScK3Sjf<?2GBG>>2OdZU0>Zd[X
=CW;:a]B_CIKAY9`3T9c0XW[</U9E_ejPhGSHZ?[TQ:jQ8l@HK9`AOYYZEgFdeWm
`4A?8P@dRRjoeC8]5V3>a7dXLCLBMANj_=QWYe7=E3a@Ac]G;Gn22dT7^00>:7N6
K5c=eeSF>5jg6i9<5SL_CaVKMTgVZ>c:U>UYdc<WIllecKG<C9VG=SNc;_]FO[=a
RFFYHkGaHM=6iGGgNobTlJCUODOFQHDg9nTfT<@XBDWRBA]lcVKmaRM^JF[l[^2m
L23Q]X3S:;5dE[<@?`D9oj5k4Aa5RT^X<MfEYQln_H8YRSQgW8Z^lZZiaamOd[iX
i9cSCibhmKhmfiH]fkI]aK9[J_QaK>T[Wjo]j8jmemgMOFSk`k_IXmd?WCj3geOV
O3_k;Q6Qh4H648nA/XU:aG==j?[i=bkZWgP:2_/?:FPXW06Fo`?M0>[o2VE^I7=d
LVEQK@YUKVA_HVX:<CHP<21_HVX:?3`P;eAiL6DP;dI_KW@P;e=eHWAiL6DP;eAb
MFEDNG1U82m2HG=UAVm^M20_@D51@D5<:fI_KW@`<30`<30`<38g<3HbI3MR82m6
KfidA6EcHg9YL7A_LPXc=R0`858P;eA_EFiYHfmTIB0c=b0`858P;dIYLW=d@fQQ
LR0c<b0_C65cM4=XHG8P<cTP;eMYI7AXLb1K83De=R0f<C4P=CDf2S8b<R0b<S8P
=CDf83De=R1M83hn2VE^I6mRJPXc=b0`86mRJPXl?20_C6E^IgAX838g<20_AVU/
M6Eb82m6K65dIDAUHfmTIB0n?PYcM79UHFd:N05MTLm^Pc0<a^mi2Qnk@dEPU6XB
@ZXjEN:`?a[K0d1RD:@AXQ0>_?fnd:jCM_P>?m^OHc_9^Gj^[@VD_?]9=AbX=eIk
WZO5:jJ>1f=5VY4f:]aXRjVaMB:1^EWW`6=]nhW:DQ0U7k3<`Jnd>nVYhhLHNo>J
_K43kKk>cAIY5^NnNF@KB8ZZ8/dmf[fdk[DMVI;=^ZlelRJ/NkSn:SiGahB9h4R_
8jU9lnaJaKje0h]BbZZlG2[1E_m;7Jn6[[mEIVUEATVIiIDX/``8BITG4An1T9A5
6S47@/2WR0LP15@A2b04?4@l0R4P>V>BgcOSD?5hmfGEhSgfg2jlWB2^IRcO?l5=
;SKHm0<m3h:X2VE^I7=dLVEQK@YUKVA_HVX:<cHP<21_HVX:?3`P;eAiL6DP;dI_
KWA4IG=SLVU`M6mb82m6KfidCV5]IB0_@D51@D5<:fI_KW@`<30`<30`<38g<3Hb
I3MR82m6K65WLb0d82m6Kfid@T9_N0YK;CHf=B0]<c8e838`<30P<C0`=UdP;dUd
HFaYHd5^IfaU830P;d5cHfE^M20i<3DP;dAULf=UKW@P;C8a<R0_@f5`B6EYIfQd
2SP`=B0_DgAUKEHP<20_C6EQI6U^Ib0c<b0_F4QUJFMXM20f<3@P;deQN5MYI7AX
838`<30P;dI_KWA6JFaU<R0c>20`858P?Sh:IFiTKf9Z2S<h830PKf9Z2S`l82m<
IFiWM6Pa83Tf<C8P;daUKVMdJ20f>3De82m6JFadIG8P;dI/HGAUA6ESKfAU83hn
2W=dLVEQK@Yh0HEi2GQDEIK`^OL]]JBZDQFBZTYBBKe:YBXTUI2M912CUaD`@P8T
V<944R0BXPPa[8Y@B2<@DMAYVIJfaJe]e55N5^TRf4<Dfik61DKA7VTEE1SAj@SM
7hf296o>OAE@n^m_o_MbUW_>^M^iiiikGfGUGJ/j80Y2`47>XVG]:d1kh]LSlBmJ
_E::U<e>0;7a]QE;UTG:4nh04;iML/Njfb;Un310e7>M7Nf;8fFhPWAb9`XRIE:0
=;EcfLZeTG9l2e;YS^F;a_Gacf4iIUWkf_7nhA>V_k=mFDO4g/O/LeKLeC6^9lgH
gkoKemdWaiK1STM>gbMolk[JLfO?OK:TO;GiUHeH6BT@[:F74Y`KNbQH8A_V0O2M
O98VHGZ1k_cbjEnm_B2jm>ojA;dVO^K;]0c67>IG?7aignPB:nQ=F3AXkC45e]>E
SLf2:R]LgWOiKZ/VHHY[Soh0=78C1oa>mk7G^7@hQD2im?i0T_/0UlHUmDmebf7>
>a0CUaMMTLE9f6:fQRG4ba7f8Aa2h641UhaJ:n:=2264O@R748hQR028VEI2F8j`
1n4DP/PULJinbFf]B>?R/FhlcSnJLl0i11F10cORK8AjQ0D8>a7f88RJ7I</AmR8
L0SQ?888<^OXOc@OankXOd0S0eegi6W5mTRaYED[3]`LS=2I/b>dNTK4K4[4;;LP
8YiD6J5YVA4Jhl/;HN<3AW?NL8FM/n<TkCS`5HP9OA>R2@4g?<G5PH90>AbZ9Y6i
V85DOmjN@a`?Q:<LPLGPEXLidVnfiEDHZD[?@@bhjKMd9::Q8`<FFmjNRQ_Y5k0?
hA02Ako0mg?j>FbTYiS?4ILSk44hQ70DhAb2B4oQNa;OcnQW44doQFb4LX@527/@
3R6L@m3ACa5KjBL/HSC<n784BSm1K:EoaVWm6G4d?H7L2GY27JHOm1NEi1g@V43f
>>?fSC>>a74VaYhGY^ogGd[7R?;SBV=47NABX0cb^IAnGjhkc3WkBiNj`oC;0BWP
OZXRQah71H7RB8iSclM1@VQ0J4=HPB0Rma5b7d48hF64Ya0D18`ba5H4RAi1N0OQ
8lQ1T14J4?CdF3mf4jI7nofEkPXkOHon0AcXlGOYOfSd7OZFA]nV_mOX7i4VXoh8
OJ/of@dEDJP7[6=5JTFJSGZ1_Sj@6^=F:fcd47[@SCPKXAbQ7V41`Th4TAjR:Of;
gC7Hb44hPW_HCO_QJhdn3loX@NibbohZ34298OnD6i13]4OJhjNbOmOSF6C8om2S
b37TomT>i1Sbgkd9>HKlMja6SR7ohRkT6?;?Gh0L@okjA^@@QNVC_de=LaOEgdjT
RVRj1[fd1[fd1[fd1WRjQ[e`RFMSo6EoAPIjK;LLB<m`QhI8j3DBVT=2ci1@1`U]
8:5=95A:@[NBD824G2BDC48b2AdTaNR:4947[b^Fb4hB>T92;i=@3`WiBLQ7@ZTT
994R>D`moC=`eb6YdLQ01M]de3=`@aUVWfSZ@Hmj<>HmV1<>8Cj:X6XU6HfTU8Qa
O3:S:@<IiI7bY2Uibb^Vdl=HlC0^`f4hRL3S0Qg6<3Z<SAc6iZ8AUb</@1Q6>8NP
8XQXWH;cf:WQJ<CI2>D82a0f8Ya34;GQW<>QD5R>V0eaWcJ`K<CU2?F/A0oSVh:_
Qg[T9:_;6[1>igJjB7@bZDmFTfTAf>fHV6=/NU^HV?MoIokn>c<H:Pcd8KXCTW0Q
7QjW>o/_9KW3i1OmoX?^RSSb[i3<HmBA4_0C7m9Rj=7:QN3B<gT1^>Q;B??jGO>`
FWBo?m<mA2b/eWkg9MMYmmN^<4Gf[>^PndmBV2OmkPmAl]9nmg7GM_LO/l=jU;cV
3a<T@i9VN/1Ek7kiR6Jj2AFknmdK6=W__]LecGfkBe=dA1BgmV19SWK?lLmgClOf
ZUd;gG8?][WOGNjjeEdJ/BYTMOJkLg08P@RKPH==MfVMNY>e1Y^:`ZACc]C]dSG[
jWFCMGVjC9e7imHUjA9e/OXH_EE_dI_dA[eN;nYi?MF3?SJ/WY83k=B;5KG3ClB0
9/1[_1Dc365Y1S5@XZM`8bPC^3YJ=kNBe2W3Rj1^XJALW>/=4n?/nH[P[BA:C1gD
=EHZaH6j/4jMXa@5jQAM`bg=OH@l54BY@[N52C@fQhW:A5/BUIRZiP=0R6g;PhV<
C]cbH308C__ZLVMiC9V]Y;KjWj0fCMQF7OSaLOk81Yb196EGgMaViLFTX9;763DY
F:OlbebYYOT0nA/iGe=mP?bETF3c0Jj<o:eV3Y=cIMG1H5fHc=?/@29oAC^<62AX
YlN3VMV1Y4n>f>f>f?V`?]ZU<X9f1P?h=3^O`J3IlHCImOFTeUCgYB926hL4?IY=
Sd?jZLdA7m[h4:6=?@A7=9/SmQ2cDLZdIU`^=4U6Q2HT0EbJRH/TJ2KJb?/dTnaa
TngGC;I[?G6AdFPf364ciU=GKLbWd>HWS_bofHk:@80<C0d^JZWYl=JdNF/j4=ZD
1eIg>YG@@TWZFaAT2TWQo6d;5gDbf]jQ1;dMeLXRKkGD=eF[m`oZ5ZJNjZg^PiJJ
a^Jn5[VS^WnZ?;G6fehM79SFD51dGEoK[oEEd?1?nVYPSAF`_ZIYmOjQ[b:VW/Kj
:V9m5K6nY/WC];i0Ro66iShmE0J[L?dH7J1AAXcG]TA?/=9^GE6V1NmDSg=3hQ3N
E_I2E22XV;bERQV1aGEFAEH5Dn6NHRX;RZ?7ELh=Dcf9@fC_^<Z:HY^g4P8[EoF/
0VO=d^[8G`ln:5ZiRRe510NHk9lnJ5:Sb>gE?B/1jYB<^GE:nNcicGdj7D[KZX<X
Vg9E5QEE4eJ78l99:9c233W^VR6CUC:I`C1^n?o6PSHV5:=g3^15hn00TI?9B^P9
LTYbGB?5E=0h7mg@<[mi2>mBk93X2N84NdR0m5a]SLe3hb4R0IafceEH^FZL6oO5
bW6ZVOH48=1ceBEGV`/`IfU8lmG:0:HfH@SR4A:4gd0lk`OloU6o@SS;j=QBmBcC
<dZo`DB7GclJ0>b5UlUBN1T>`A_T?=KJ1`MP4=PEZ1ZNP?G`LmR:amYlU6b7>OP:
:?liREL7lL_TJC``WhIgdOIVf013H2M>mF_H25^h3k3F5S132UA00bb71lU=jRYX
PI?lIRR2Vn1>F452J[?jT?ZXnQcl6Pi`oj6>hUMM0Rc2megeFn6oe4lP2f/l1Xo3
BO:XhEF@/IL@F_h:kX;MG2]?e2GZIAb11mKP67RH2NnBHA[0eS_P:n8TjkTZK>EI
EE7OA2/G]48Wk8HQDTRVDHo@X/iDg`Dkm[4FFgdLnV4o_V7h7I`P9^6lnYaj7^8Q
4fKPO0KQ?C;<SHe^6R]7_`WXYGClAY^1loYgn0<L8ekb>Ud^V8@l@AK^EXm3;>A2
4hkf=eSc_lUgM0>n6kVgn5Ze4RcXUdNH]n7gl3U98=VTW/bSjG@iOI:k2kom<[5^
;UkiUj:oOh6]OhIQ]9nJj57^FOhUoPLaJNbDJ/4ElL<_hEO`>S7SC2GB@nhS7i4_
JAEM@7m9_n1nc[o0_jm[aeWO2/_P@GP9_R<aY9S<9[N@C[:NK2F?T<O9^n@H>D/[
J2>mWIkS>[U^kWMl9KicnAin/g2ol81hMZaik<faoackC/eCkhOI60nKL?B?`I<h
/`=`53k6mbAl@@@BABchB/A3V/Pmn6hP3i9Wb5kb0QW4GXjA;lSGN2CmWOa0lJBU
8Tg4b`nk0WWYGGS3o3UmPQk5maSm2kg4>KPD;/0ELZELT5^>Xm[:?Hc_ZmcWO09o
U5OAcgW2;V6?/5MhBGQ3>2nJM?OQ6Oo>UFM7<dHo6h>aKF>ka_[71]G?8@kG44l?
o0@[aM6ghm^5jkd;8fhOO41<j;/4TT7:b4gXV@FTRgBC]NS9Wi7Mi=OJf5lQ[j6G
oTC>hIS=e:F=NA8]Y9Fd7]mKJ@O]a/_HXgB@OT@_LcX^RX_Vh[P<KQ[GbWE`:kUe
g2i>hMkQ?^Fnh2ibEo1ENB?_iU=h?aoPYo4;n5GlToaGo5M2Ro2fL4HdR/_4nlF`
n5NleICY6WBcMJfjWK[m^^?j=Xc>`o0Zo1HSl=Y3CW6K^1[^EGR8i_?an0Wc7/Kc
0US<cJ@HZG@_fDK_9H<dEEP[CZECbB`hco_AefoA?O@RWL[=97ET;WCAg4R3HRco
8W:Uo64HhEo3^Kf7;JlECF@3?BNJX1o_B2EhAoXmUl<7^;OQ17NBj?RWhLnlTCS8
2?d=eh1Al3^nC6P63oL4_<9eTg_QEEX3H?a1_`?SN1Ii4O=28lTSgg<ZGX=WHA@E
LEo2I[RMoQN<h3kN1_m:5_=;h2789n_Q:gPNMdFjL:NH8LJA?m:UO2nM@0J1lRoP
k4Y8:^64F?PIJNEfRnOXak0:S_96n8ck=acmDOX:=i<o;l`QWKP3kXGkXE_M1>^4
I_im/P@h<Pmlo2W<K^^i?=j3M2=VUAK<JO]aM`mQ7ZSPIZ;4RI5c4lI54fJ8gOSn
0_<4Sa6d5?OhcIS5gX=1/I66HHUP8IQel9NJ]lOV`7ceNGQLG@9gZXm25^J3[NYj
K74_W86M/9M/6K/7E^2Wi<Nh]flBJ^UAXEK=X[gdHcZGk[YnOM7K?^:4Ko1m1ENV
C3P8_ObOH2jDZc_D3c6j9f:6OA`FhXGe=<kbFnaQ>SL<nF>cJ9mJbjg0nIj4fNY_
E3La@ZMj1mC3Jo1[W@3]^P2^/D;NaoWN0aedS[ZBjaQKRWkHREj@dE^[<?m/Uj^J
6R_Tl[8KBZM>:BT^:Rc8cl_=bIjDUAW8B9nHi_NUNU<lTS/ibIFH4>mdf>=R9lCH
[=4F/bW:J=3[A87W:87<6Vm]VjChfaCNkidn?H^E_NdXJ?n9X4fAD5Ak_HdR/G[]
Z;[>DTK;fok1DXiHb]L/REDZQM:/C:W6:bW_EW^U<9To^aWi1j^m@DTIdORI6_n`
aY^AmgR`PUCSk:bF5=8VeBReZc]kJmZZ/c99GiBabU_EHLc:Q3iS5;9Ab2T>khXn
hRPS6T<M=E?j:>S=>4DU`E]MXlAk/BXf`oUZfQL[3K>KJjXC?IiPEZI2ZQIi5b[0
KTX1c@BZ]6hD/D[AJMe8Bo6>Xl03DUoVL>n>/1DF]PE<Rkf;fe^J5JhMfjQAK07/
]eYag7gJnF<A6lLkfMJOJQ>igQ[WDXTImoI^UIBWISOoY6jRQkD@368KF9OjJ]]j
Jk7[7KQBMN`^[]0]`FJ5K<4^lF;YdfHEVEoTe^][ji8DPkOBfmWKeHI;Tm2[`9ae
W_j41?V0NPXBJZCNaVJ_AbU?m0KKZeem/M0kIme0_2c5Gjo9b^bcfR:>kK=4Sc<V
ldnI3WAjA:MaVSWSj^ILlbaQHoC>`9^P8RfBL2C=GYaC<D<MaM2kZ1PG09lP`E[:
HUbAYHZQZZgG>XG9LHY44GaF[mCkMl08l8kliGY9nkQ4m5Wo3Tc9h^AJZ2VToBZ_
109:APH;4EdE[RV>/D`[5fIU[PiC[gN55KnOfDL3=:1_fh=C/]7m7PmKh0O2<Rc4
PQ:JgA`YBk0`/AoTK;aKdcJV6KjZRF]RV]1EcKGZKEj<i47f?@]aR]iokBoJJYm@
dcU58OKo@mdAdMO=mMKQeERZjFdKSmZja^]:4Cec:?X=MN>L<Z6ZVD^T:6<LCN@d
KNB6O=D4[l_=9XGghInX1OGR/4j?DJU9R5B[F=^VAg3@j?6<kiWoGjF`NYkEd/R?
eLJWXD`9S0ld<VaUjWGUjhIWj^GZ6S7UD;cImoHJ[m=QZ4E6>F>LH<CSQki7ZU:P
2GNV3oo`Tj>H@C1ATM5UZ6W4GJB9PhWSaN/<4lL[1O5QdIVEFH/i/kNgeR_Em[Ke
]XOEd4:_I?Gf7Z1_d3MjEmAP]X/4CUPMNR1AZMdAA8meTRVh?BQDmWW9]]Um<]Tf
Mgkc0Ob9@m[Ff=a?2JeZZ`bbIJ5ESLgSK]4FQ8Dn[R7na`@SQ^n16ObG/1OYSN@?
/0eQ<o9e2;DHCT@;:P0C6^<g1]jnMBRQN<?VlFH/HRWbf<Ul/YnC^=flTomNN1n5
N1B`bk>0o`1PEQjKanI3Q3g25HTK_R8;l0=8o32[cl4<=H^O85I01]j6RlUafKLn
VO0iVI<WImMjVS`=fJfC^kQ5fGMcJc`mfOM<g^X9ICldfIXKESokKEA9/RBU5VBb
Wg`b9Fm1Ukhh`fhZT^`I>IhXR3<EiNIh8:k8Ti=ca5@DJc8EiIPlAK`SC`cCioHg
24@H8JhQnQ`TdYL77>h?0V5B:1]Shn`QQb=FP8``:NXWaSbD3ZIo@<b^8E:<Y[oX
;ncahi[;aYRB7;o/3oTiOiS>TJ<ck0j7fbe9aLEiNNWYF?]OI3_4aLH60[ViDE56
H`jN]R4hQTh8Di=/42Ke;;M^]5;[47T8A58/AiL;mL96HJO02o4UOgS06IQU_M0j
LnA2m`SBD^^?knR?;><^]0I6;Xa0n@FDGbP]IlPjNU[kJce]Rg6DK;E<2Vbeg?]V
=3ji>LjZMO:=WR;CQ5BOeiORhl@H_bGJ74g58TmQ?LVOR2Qc`ZAjb34QV^`[[RLN
ZJRh82f_7_;c/V`1E0LVa6I7ij99[RT:f<02hbQ22O]hc@QTK=Z470AJBJ]@>8VV
5MTMMXO=WnKg5aHDCBhZc8mS0YgOWfJc>i9YG:bXRn=4<BkFkYP`NG9QPCn=S6em
hAkSZg65=gD]GcV_MM/]0efoJUW]7;9f=6o;K>`ZnOIgGD_G;KVWJnWfmTLn6;CM
o<J>U4NZfj;X3G4E>BoN<KbV8FKN_>RI2embMGG7S5i:VN3[N[CYh6G3OW6RME][
bg[OZ=glA<o2=MT/3PWNfX3OP]o>1WQ@3XQ2/UjoDdMd>^3hI=aAX=Lm8E4YR]:4
:=hP4@U[B5H[KH:`NW4`>WZL<I/ei[8LIC8QIhZ:4YW5f:39Y37WIJ?IS5b[LFZ;
]/;S7oZ]YC=7BfMI;kK>?0gUiJFSYC4UfKSXXjFi>OTfCac^7XBmg:MGcU1U]44H
NWU/b/^S]n6hlBM<mBc_h/_`QUQ4/nA<PmV@4Fm>b4PgIfBDV2O75BE>bIRAdFY^
cNPb;leXbnTeginnfok;Q1O<LA?3j]U1=/8dI>AhaSdOon;4oO479khIOgCRng6O
C]AGfdUbF;dPfmP4HV8H5T`<5k9Mel@h]l?]36AV59C`9ITcn>VIloC1`6gjYH7E
YZfV?iX^VBl5K4D55/9K/e<;77VNF>N2m>GY==fEKBVgk;C//JPFHHmUWnFLQK>H
V2<]HOFK@NIJI2k8LEJ[f6@a<JmIa>QXa1HGi`SC5oLk7h]e^GCXg@]b0Q/7e:@I
leaLE7Zk]Ae4KBElW]B`nQN]<LK8DDbJb[>e`O9YW;c6G=2lP99?i2SFGJ[F4IJ_
J>^F6ZJgb9Hd6OaF_nC?lNoc2bFH0@H]5]Z4ZN2SoAZCbfBb>MUKT5<bG4:O:R4U
3SJf2]JR`nM<bDhm91hEZE//5jUXHC<ELEZ8WF`l8/I:18]=XXE=EkBbFHViaMJ;
Ej>T6gMj`=[J7D19jlR5LG6PM3A`iPbDSiBO3YB?S>:V;lWFE:gM8meH`;lB`S91
KPjd<PGYAP;M?U7dY^1^W3`Imb>nQ@EYOVn:Z4/[XoUiM]bMLF`cN_fLZ;?Po[CW
ic4S[WCaPJim[dg[VEihnhTU9;mVflIeBH[ccV?K]kgHH3DhDUic>AJn^K`UKmWB
cVOlBI^KJUoJ<V_C[5R;>B7EIk`cjhIP]k?kPCZioLI9Jloo/>F6H_;YA9Meh/c/
jFfge=n`AX_YKKPQBg4_/_?SGOUF`fCVVg[3`hJW38YQf73BL=jP0h?K/<8@<^`I
5idbZ0JSfh37UXjWW47T=Q0@1I4gRSZO0?`NoRUNhHOiDk`hc9oW:O0BO`a;?1mF
_mLR19W;/X>]9Jm526mT_O:aK5nPS/FTaX`=/]E1bAGIb5J8WjFOe^0<G5^U@6_g
GKR3fCh^7d6oUfP;T9]3F^oZ3Tc0_<OIlVgK1PL7nOliN_B7>=ko``VFOcHS:];V
o>En@I^`P04eP;UGX`F54IZC6j4Y?Xg:_SQ7@KCPaQm9CPYl?J;c0^LFEPPQ@AG`
Od9PY9b?h2KAFV9DS//_;=P3I1S>HoH02HnTDna@6_L2<YOU9>H5d;`0VQM0l`;X
V@_@8^82I=B[RFgL5c2;_mhGc1T1353V3^H2EV9??_YPlj0`M1V_6QCZ<8LUH`j;
Pb@bEgJh`AE7VkQFXMG@5=G1gBh/=gA4jN?HSVF^]b4Scf5LTX_Q]9R?QL^a5a?h
g9PYlKV^RYRI2AF^fC4]lG=LkC7;4]YMJlFeLAOYAJLEOkR<=S/L3OHfn`[l5kh[
nV7[DgP4FoU4Ue47@oA58;R_FNhQc5=F=Ud[8NBa2BhnbR6K<D?P26PC<]mZ@d7V
6ld5b0c;Q[B<0/E<c0U^iVnO_h1A^H:U13Mafo>]ZCXi=J?0[B_7ofIa>XW5UdkK
oCZL2?8F5V/j5h/ZWIe=CANOG53dTh>R=C1cm?@/JgLPL14Q49R91oo8:>kVdnDS
fY4afUfZQE`<KWKBZVegdWdGLK2]3SH[W^5PRmEik6`c4`nNa[SQ^E^7<[lml?GH
>A;kbHOhfmjE/lKn;H]fS9jP/dg5lkJ_Oh7<Lc`kB=b4`aoB9Xim=WK9:^dKjRB?
gEoEnKbfGf_E/ma9S5dK[UnCo9bAlVJO^L1LKAH:H`]M=m=6hicH^JhUM;7@HEPD
fnHJMQlG?Yc`JObI2FMRccWn9oi<dRVgj[JkgH64DW]Y@Ug22_O3K]dTVVZNI9m2
2lee]<IL6c_3MK=aWWV9nHchUOdb^F2aTSS>4VF=QTAGU<h6aSQ<o/il0SiK]<mZ
?FHSEY]/Jk>5K;aKIZifblc9]QRf_QQ3N:Ra96`CFK3KW9X^[?h=CG4AK1JfmVSe
[KJlb7`_Ef[1]c8VmI3^Z>jTC]GaEeLbnBL[VJb]Y7KbjkASBjNMCV`U<D_PYHj]
6jK_kYTSXa4fDRbeS^1iSlOo2</KiJDfUSIHa/I/3MfN@YJ[<EW7C<KLk<3M@kB4
S?LT]X;57Fm^o71Eeo7=KK^b1dJUOe^en]MkkeWkm?e?k_SQfCf4jieM@BfGJfW<
>dMNOn_4>foRXV76RD5PS`R901G/^BU`fo8kEnJ<?gU5>I?c5QL]A9?o1OC>j>h:
IFiTLgAbIF5]2VE^I6mRJPXc>B0`86mRJPXl?20_D79_I7ESIG8P:6eQHdmC85IU
LW=YKfhP<C4^=21L:49eJFaT838`ASLaG2TPDGEQLWAj8514AT=_KWAUN7@Y82m3
LVEQM6U_KTAQM6D::4@j<S0b<C0i<c0a=c<h<S5J<30W<30W:B0_CFmTA65dIB0X
A3Xb<38a<3Tc<34g<cPb<EX`<2L`<2LY83hn2VE^I6mRJPYhLVEV2S0P=30:<30`
<30`<30`<20f=CDc=B1V80X`<30`<30`>C4c830`<30`86hP2S0`<30`<3@`=3PP
<30`<30PKR0:<30`<30`<30b<R0`<30`<21^80X`<30`<30a<C@c830`<30`86hP
2S0`<30`<3@`<C8P<30`<30PKR0:<30`<30`<30`<20`<30`<21^80X`<30`<30d
<CPa830`<30`86hP2S0`<30`<30`<30P<30`<30PKR0:<30`<30`>3Hd<R0`<30`
<21^80X`<30`<30`<30`830`<30`86hP2S0`<30`<CHe=CLP<30`<30PKR0:<30`
<30a>CLh=R0`<30`<21^80X`<30`<30`<30`830`<30`86hP2S0`<30`<S<c=CPP
<30`<30PKR0:<30`<30`<30`<20`<30`<21^80X`<30`<3<a=CTf830`<30`86hP
2S0`<30`<34b>CTP<30`<30PKR0:<30`<30`=34c<B0`<30`<21^80X`<30`<30d
=SDc830`<30`86hP2S0`<30`<3@c=CHP<30`<30PKR0:<30`<30`=3T`<20`<30`
<21^80X`<30`<30i<CTd830`<30`86hP2S0`<30`<3Ph=3DP<30`<30PKR0:<30`
<30`>C@d<B0`<30`<21^80X`<30`<34g<3Lb830`<30`86hP2S0`<30`<CHg=3TP
<30`<30PKR0:<30`<30a=c<b<20`<30`<21^80X`<30`<38`<SDh830`<30`86hP
2S0`<30`<CTi=34P<30`<30PKR0:<30`<30b<3@g<20`<30`<21^80X`<30`<38`
=C0h830`<30`86hP2S0`<30`<S0g=CHP<30`<30PKR0:<30`<30b<cTb<b0`<30`
<21^80X`<30`<38c=CL`830`<30`86hP2S0`<30`<S@a=c0P<30`<30PKR0:<30`
<30c<S4c>B0`<30`<21^80X`<30`<3<a=cTf830`<30`86hP2S0`<30`<c8c>3HP
<30`<30PKR0:<30`<30c>C<b>B0`<30`<21^80YdLV5YK6Eb2S`l82mCJGYU83@`
82mBKfmd834h830PDR0_BFiVKb0c>B0`858P;dU485/P?65UHF4f=SDa>3Pe=3ES
<f8i>35RISDh=cTa>CHcI38b?PXlHFEQHCHf=C4h>3Dd=F<cHSTh<F9V=CPg>C4i
=S=T<S8n85dP?Sh:LgAQLWAhLVEV2S<i=3Ta2RDUADm62P\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{186.089032, 186.08902999999998`},
  ImageMargins->{{0., 0.}, {0., 0.26995849609375}},ExpressionUUID->
  "e272b79e-a1be-4463-8fad-33ee142f359d"]], "Output",
 CellEditDuplicate->False,
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.8420121823525877`*^9, 3.84201218275603*^9}, {
  3.8420123044648657`*^9, 
  3.842012307682618*^9}},ExpressionUUID->"58c040db-333b-4c73-bea5-\
902ccd2013e9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Snapshots",
 Cell[BoxData[
  TemplateBox[{"Snapshots", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{"To create snapshots, paste the output cell from the ", 
          StyleBox["Manipulate", "MRbig"], 
          " section in this section at least three times, and adjust the \
controls of each copy to show a range of interesting settings. Do not convert \
the screenshots to bitmaps. Optional captions for the screenshots may be \
included in the Details section.", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "d854de0f-efbb-449a-8b04-a7b3ca5773d5"]
}], "SnapshotsSection",
 CellTags->"Snapshots",ExpressionUUID->"96bb7a68-4496-4362-86d3-c2a0812907f2"],

Cell[BoxData[
 GraphicsBox[{
   {EdgeForm[{GrayLevel[0], Thickness[0.0025]}], FaceForm[RGBColor[
    0.540383, 0.518196, 0.014786]], DiskBox[{0, 0}]}, 
   {EdgeForm[{GrayLevel[0], Thickness[0.0025]}], FaceForm[RGBColor[
    0.6666666666666666, 0.3333333333333333, 0.6666666666666666]], 
    PolygonBox[{{1, 0}, {0.8660254037844386, 0.5}, {0.5, 
      0.8660254037844386}, {0, 1}, {-0.5, 
      0.8660254037844386}, {-0.8660254037844386, 0.5}, {-1, 
      0}, {-0.8660254037844386, -0.5}, {-0.5, -0.8660254037844386}, {0, -1}, {
      0.5, -0.8660254037844386}, {0.8660254037844386, -0.5}}]}, 
   {Thickness[0.0025], LineBox[{{0, 0}, {1, 0}}], 
    LineBox[{{0, 0}, {0.8660254037844386, 0.5}}], 
    LineBox[{{0, 0}, {0.5, 0.8660254037844386}}], LineBox[{{0, 0}, {0, 1}}], 
    LineBox[{{0, 0}, {-0.5, 0.8660254037844386}}], 
    LineBox[{{0, 0}, {-0.8660254037844386, 0.5}}], LineBox[{{0, 0}, {-1, 0}}],
     LineBox[{{0, 0}, {-0.8660254037844386, -0.5}}], 
    LineBox[{{0, 0}, {-0.5, -0.8660254037844386}}], 
    LineBox[{{0, 0}, {0, -1}}], LineBox[{{0, 0}, {0.5, -0.8660254037844386}}],
     LineBox[{{0, 0}, {0.8660254037844386, -0.5}}]}, 
   {RGBColor[0.540383, 0.518196, 0.014786], 
    StyleBox[
     InsetBox["\<\"\\!\\(\\*SubscriptBox[\\(A\\), \\(circ\\)]\\) = \[Pi](1\\!\
\\(\\*SuperscriptBox[\\()\\), \\(2\\)]\\) \[TildeTilde] 3.14159\"\>", {1.85, 0.6}],
     StripOnInput->False,
     FontSize->14]}, 
   {RGBColor[0.6666666666666666, 0.3333333333333333, 0.6666666666666666], 
    StyleBox[
     InsetBox["\<\"\\!\\(\\*SubscriptBox[\\(A\\), \\(poly\\)]\\) =  \
\[TildeTilde] 3.00000\"\>", {1.85, 0}],
     StripOnInput->False,
     FontSize->14]}, 
   StyleBox[
    InsetBox["\<\"\[Epsilon] = |\\!\\(\\*SubscriptBox[\\(A\\), \\(circ\\)]\\) \
- \\!\\(\\*SubscriptBox[\\(A\\), \\(poly\\)]\\)| \[TildeTilde] 0.14\"\>", {1.85, -0.6}],
    StripOnInput->False,
    FontSize->14], InsetBox[
    FormBox[
     GraphicsBox[
      TagBox[RasterBox[CompressedData["
1:eJztnQdYVVfW929i7C2CIpbYwBABG1LEith7F7tYECtSBRUUNRrsFJWigggo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        "], {{0, 30.}, {154., 0}}, {0, 255},
        ColorFunction->RGBColor,
        ImageResolution->{144, 144}],
       BoxForm`ImageTag[
       "Byte", ColorSpace -> "RGB", Interleaving -> True, MetaInformation -> 
        Association[
         "Exif" -> Association[
           "Software" -> 
            "Created with the Wolfram Language : www.wolfram.com", "DateTime" -> 
            DateObject[{2020, 9, 11, 10, 7, 17.}, "Instant", "Gregorian", 
              4.294967292*^9], "TimeZoneOffset" -> 4294967292], "Comments" -> 
          Association[
           "Software" -> 
            "Created with the Wolfram Language : www.wolfram.com", 
            "Creation Time" -> 
            DateObject[{2020, 9, 11, 10, 7, 17.}, "Instant", 
              "Gregorian", -4.]]]],
       Selectable->False],
      DefaultBaseStyle->"ImageGraphics",
      ImageSizeRaw->{154., 30.},
      PlotRange->{{0, 154.}, {0, 30.}}],
     TraditionalForm], {-1.1, -1.5}, {0, 0}, {Automatic, 0.25}]},
  PlotRange->{{-1.1, 2.9}, {-1.5, 1.1}}]], "Output",
 CellEditDuplicate->False,
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.8420121897874403`*^9, 
  3.8420121899209013`*^9}},ExpressionUUID->"28ce2d21-e862-4a50-b19b-\
1b190171b769"]
}, Open  ]],

Cell[TextData[{
 "Details",
 StyleBox[" (optional) ", "SectionGloss"],
 Cell[BoxData[
  TemplateBox[{"Details", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{
         "This optional section is for a more detailed description of the \
Demonstration than the caption, but it should still be as concise as \
possible. This section may also include numbered snapshot captions (e.g., \
Snapshot 1: phrase or sentence without an initial capital and without a \
period, unless more than one sentence is used) and explanations of the ", 
          StyleBox["Manipulate", "MRbig"], 
          " control labels. Define any symbols undefined so far. Include only \
text in this section \[LongDash] no code, graphics, etc. Do not change the \
cell style or copy cells from other sections. \n\nA book reference uses this \
format: \n    L. D. Schmidt, ", 
          StyleBox[
          "The Engineering of Chemical Reactions", FontSlant -> "Italic"], 
          ", New York: Oxford University Press, 1998. \n\nAn article \
reference uses this format: \n    D. Pearson, \"A Polynomial-Time Algorithm \
for the Change-Making Problem,\" ", 
          StyleBox["Operations Research Letters", FontSlant -> "Italic"], 
          ", ", 
          StyleBox["33", FontWeight -> "Bold"], 
          "(3), 2005 pp. 231\[Dash]234."}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "b42cafa3-93cc-45b2-9bce-00512b05ae14"]
}], "DetailsSection",
 CellTags->"Details",ExpressionUUID->"b9971572-9357-4ce2-a011-62ff9eede7fa"],

Cell[CellGroupData[{

Cell[TextData[{
 "Control Suggestions",
 StyleBox[" (optional) ", "SectionGloss"],
 Cell[BoxData[
  TemplateBox[{"Control Suggestions", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{
         "Check the boxes beside items that are appropriate control \
suggestions for this Demonstration. For more information, see the ", 
          ButtonBox[
          "guidelines", 
           BaseStyle -> {"Hyperlink", FontColor -> RGBColor[0.4, 0.45, 0.5]}, 
           ButtonData -> {
             URL["http://demonstrations.wolfram.com/guidelines.php"], None}], 
          " page.", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "f1fe398c-f37e-4aca-9161-633bae63965a"]
}], "ControlSuggestionsSection",
 CellTags->
  "Control Suggestions",ExpressionUUID->"af8a4061-fdd4-44d0-82cc-\
9fec786547ab"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Resize Images",ExpressionUUID->"fcee1195-e255-4dbd-8863-4af840debdbd"]}],
  
  "\"Click inside an image to reveal its orange resize frame.\\nDrag any of \
the orange resize handles to resize the image.\""]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "ResizeImages",ExpressionUUID->"ac542041-3d26-42bf-920d-b54a74785eef"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Rotate and Zoom in 3D",ExpressionUUID->
    "df0b52c8-7325-4803-bb1e-958545cedfd1"]}],
  RowBox[{
   "\"Drag a 3D graphic to rotate it. Starting the drag near the center \
tumbles\\nthe graphic; starting near a corner turns it parallel to the plane \
of the screen.\\nHold down \"", 
    FrameBox[
    "Ctrl", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" (or \"", 
    FrameBox[
    "Cmd", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], 
    "\" on Mac) and drag up and down to zoom.\""}]]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "RotateAndZoomIn3D",ExpressionUUID->"e14e98ed-7514-4081-99ea-c2ffb624df9b"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Drag Locators",ExpressionUUID->"61b2b2a8-69c4-4012-b6da-8923112012e2"]}],
  
  RowBox[{"\"Drag any locator (\"", 
    GraphicsBox[
     LocatorBox[
      Scaled[{0.5, 0.5}]], ImageSize -> 20], 
    "\", etc.) to move it around.\""}]]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "DragLocators",ExpressionUUID->"384b79dc-c11a-492d-87e1-2c4b84403891"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Create and Delete Locators",ExpressionUUID->
    "8e06b60e-3149-4a23-ab31-0a8ab2f5ceaf"]}],
  RowBox[{"\"Insert a new locator in the graphic by holding down the \"", 
    FrameBox[
    "Alt", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], 
    "\" key\\nand clicking where you want it to be. Delete a locator by \
clicking it\\nwhile holding down the \"", 
    FrameBox[
    "Alt", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" key.\""}]]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "CreateAndDeleteLocators",ExpressionUUID->"98a81657-e34e-4dab-ac86-\
717d7eff050a"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Slider Zoom",ExpressionUUID->"c8d377e3-56fc-4adc-88e3-cf7642fb3181"]}],
  RowBox[{"\"Hold down the \"", 
    FrameBox[
    "Alt", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], 
    "\" key while moving a slider to make fine adjustments in the slider \
value.\\nHold \"", 
    FrameBox[
    "Ctrl", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" and/or \"", 
    FrameBox[
    "Shift", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" at the same time as \"", 
    FrameBox[
    "Alt", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], 
    "\" to make ever finer adjustments.\""}]]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "SliderZoom",ExpressionUUID->"b84ac2ce-e422-4d4d-953e-073d63c15a9e"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Gamepad Controls",ExpressionUUID->
    "1fbb5ded-9a1c-4ba0-a087-0d1c0be219ce"]}],
  "\"Control this Demonstration with a gamepad or other\\nhuman interface \
device connected to your computer.\""]], "ControlSuggestions",
 CellChangeTimes->{3.35696210375764*^9, 3.3895522232313623`*^9},
 FontFamily->"Verdana",
 CellTags->
  "GamepadControls",ExpressionUUID->"b4dbde82-29d9-4853-88cd-e053ae8d181c"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Automatic Animation",ExpressionUUID->
    "ec8a5240-77b9-42a0-8b9e-365efb47dfeb"]}],
  RowBox[{"\"Animate a slider in this Demonstration by clicking the\"", 
    AdjustmentBox[
     Cell[
      GraphicsData[
      "CompressedBitmap", 
       "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcIKwAgOI/R/IhBKc\n\
/4EAyGAG0f+nTZsGwgysIJIRKsWKLAXGIHFmEpUgLADxWUAkI24jZs+eTaEt\n\
IG+wQKRmzJgBlYf5lhEA30OqWA=="], "Graphics", ImageSize -> {9, 9}, ImageMargins -> 
      0, CellBaseline -> Baseline], BoxBaselineShift -> 0.1839080459770115, 
     BoxMargins -> {{0., 0.}, {-0.1839080459770115, 0.1839080459770115}}], 
    "\"button\\nnext to the slider, and then clicking the play button that \
appears.\\nAnimate all controls by selecting \"", 
    StyleBox["Autorun", FontWeight -> "Bold"], "\" from the\"", 
    AdjustmentBox[
     Cell[
      GraphicsData[
      "CompressedBitmap", 
       "eJyNULENwyAQfEySIlMwTVJlCGRFsosokeNtqBmDBagoaZjAI1C8/8GUUUC6\n\
57h7cQ8PvU7Pl17nUav7oj/TPH7V7b2QJAUAXBkKmCPRowxICy64bRvGGNF7\n\
X8CctGoDSN4xhIDGGDhzFXwUh3/ClBKrDQPmnGXtI6u0OOd+tZBVUqy1xSaH\n\
UqiK6pPe4XdEdAz6563tx/gejuORGMxJaz8mdpJn7hc="], "Graphics", 
      ImageSize -> {10, 10}, ImageMargins -> 0, CellBaseline -> Baseline], 
     BoxBaselineShift -> 0.1839080459770115, 
     BoxMargins -> {{0., 0.}, {-0.1839080459770115, 0.1839080459770115}}], 
    "\"menu.\""}]]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "AutomaticAnimation",ExpressionUUID->"6e84bbe0-7d8e-44ab-aac1-048973c18d4f"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Bookmark Animation",ExpressionUUID->
    "5bdb2812-7da3-4bb1-a7fc-436054c40542"]}],
  RowBox[{
   "\"See a prepared animation of this Demonstration by selecting\\n\"", 
    StyleBox["Animate Bookmarks", FontWeight -> "Bold"], "\" from the\"", 
    AdjustmentBox[
     Cell[
      GraphicsData[
      "CompressedBitmap", 
       "eJyNULENwyAQfEySIlMwTVJlCGRFsosokeNtqBmDBagoaZjAI1C8/8GUUUC6\n\
57h7cQ8PvU7Pl17nUav7oj/TPH7V7b2QJAUAXBkKmCPRowxICy64bRvGGNF7\n\
X8CctGoDSN4xhIDGGDhzFXwUh3/ClBKrDQPmnGXtI6u0OOd+tZBVUqy1xSaH\n\
UqiK6pPe4XdEdAz6563tx/gejuORGMxJaz8mdpJn7hc="], "Graphics", 
      ImageSize -> {10, 10}, ImageMargins -> 0, CellBaseline -> Baseline], 
     BoxBaselineShift -> 0.1839080459770115, 
     BoxMargins -> {{0., 0.}, {-0.1839080459770115, 0.1839080459770115}}], 
    "\"menu.\""}]]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "BookmarkAnimation",ExpressionUUID->"0cf5a50d-6c0e-4089-a29f-941bc4ca8891"]
}, Open  ]],

Cell[TextData[{
 "Search Terms",
 StyleBox[" (optional) ", "SectionGloss"],
 Cell[BoxData[
  TemplateBox[{"Search Terms", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{
         "Provide words and phrases that people might search for, with each \
one in a separate cell. Categories are added after the Demonstration is \
submitted, so the best things to enter here are terms (including any \
synonyms) that refer to specific parts of the Demonstration. Do not \
capitalize words unless they are proper names or proper adjectives.", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "b8b4550c-a7c1-4c5e-acf4-64f68ac8ea51"]
}], "SearchTermsSection",
 CellTags->
  "Search Terms",ExpressionUUID->"a3a3a6a7-7876-4115-a51a-6d092bee139b"],

Cell[TextData[{
 "Related Links",
 StyleBox[" (optional) ", "SectionGloss"],
 Cell[BoxData[
  TemplateBox[{"Related Links", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{
         "Provide hyperlinks (not just bare URLs) to any relevant wolfram.com \
pages, with the page title as the linked text. Links to ", 
          ButtonBox[
          "NKS | Online", 
           BaseStyle -> {"Hyperlink", FontColor -> RGBColor[0.4, 0.45, 0.5]}, 
           ButtonData -> {
             URL["http://www.wolframscience.com/nks"], None}], 
          " should use the section title, not a page number. Links to \
non-Wolfram sites go in the Details section.", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "d5b26c0d-c135-41cd-9d97-dc9003b05c57"]
}], "RelatedLinksSection",
 CellTags->
  "Related Links",ExpressionUUID->"83b0243b-b7e3-4afb-8a4e-185fec8161fe"],

Cell[CellGroupData[{

Cell[TextData[{
 "Authoring Information",
 Cell[BoxData[
  TemplateBox[{"Authoring Information", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{
         "'Contributed by: John Smith' for single authors; 'Contributed by: \
John Smith, Robert Ford, and Jane Doe' for multiple authors. To credit people \
other than Demonstrations authors, please see the detailed ", 
          ButtonBox[
          "guidelines", 
           BaseStyle -> {"Hyperlink", FontColor -> RGBColor[0.4, 0.45, 0.5]}, 
           ButtonData -> {
             URL["http://demonstrations.wolfram.com/guidelines.php"], None}], 
          ".", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "990970f3-a922-4bea-919a-d6fa2da1f6d5"]
}], "AuthorSection",
 CellTags->
  "Authoring \
Information",ExpressionUUID->"c2736cdb-c24c-4dd4-9a22-5bbef1a7a20a"],

Cell["Contributed by: Julie C. La Corte, Georgia State University", "Author",
 CellChangeTimes->{
  3.35696210375764*^9, {3.432333043774981*^9, 3.432333045441087*^9}, {
   3.8420122023622093`*^9, 
   3.8420122097789783`*^9}},ExpressionUUID->"e6a077c9-f528-4852-97e7-\
764f2f3a1895"]
}, Open  ]]
}, Open  ]]
},
ScreenStyleEnvironment->"DemonstrationSource",
WindowSize->{700, 747},
WindowMargins->{{Automatic, 145}, {Automatic, 280}},
TaggingRules->{
 "DocuToolsSettingsInternal" -> {
   "$PacletVersion" -> "0.10.2121", "$MVersion" -> "12", "$FlaggedVersion" -> 
    11.3, "$ApplicationName" -> "Pubs", "$LinkBase" -> "Pubs", 
    "$ApplicationDirectory" -> "C:\\Users\\jayw\\Desktop\\CVSTree\\Pubs\\", 
    "$DocumentationDirectory" -> 
    "C:\\Users\\jayw\\Desktop\\CVSTree\\Pubs\\Documentation\\English\\", 
    "$UseNewPageDialog" -> "False", "$CondensedBlogMenus" -> "True"}, 
  "PresenterSettings" -> {
   "OutlineThumbnails" -> {"1" -> "Thumbnail"}, 
    "OutlinePalette" -> {"Thumbnails" -> {}, "ThumbnailMagnification" -> 0.8},
     "SideNotesPalette" -> {"PaletteNumber" -> 0}}, "BlogsDirectory" -> 
  "\\\\wrisync02.wri.wolfram.com\\backup$\\jayw\\My \
Documents\\jaywstasks\\BlogTools\\Blogs\\", "ChatNotebookID" -> 
  "fef9786d-4748-42a0-a328-5496e837f205", "Originator" -> 
  "chatframework@wolfram.com", "ScreenName" -> "", "ChatCreationDate" -> 
  "DateObject[{2018, 6, 18, 13, 5, 54.5673134}, Instant, Gregorian, -5.]", 
  "CustomWindowTitle" -> "None", "ChatNotebookDate" -> "18 Jun 2018 13:05:54",
   "ChatNotebookWindowTitle" -> "chatframework's Chat - (18 Jun 2018 13:05)", 
  "Participants" -> {"chatframework@wolfram.com", "wan4ren2jie2@gmail.com"}, 
  "AllParticipants" -> {
   "chatframework@wolfram.com", "wan4ren2jie2@gmail.com"}, 
  "Contacts" -> {
   "andre@wolfram.com", "bradym@wolfram.com", "brianv@wolfram.com", 
    "jayw@wolfram.com", "wan4ren2jie2@gmail.com"}, 
  "EmailListData" -> {0, 0, 0, 0, 1}, "ScrollLock" -> False, "Terminated" -> 
  True, "QuestionState" -> "Timeup", 
  "AttachedCells" -> {
   "Initialization Code" -> None, "Manipulate" -> None, "Caption" -> None, 
    "Snapshots" -> None, "Details" -> None, "Related Links" -> None, 
    "Search Terms" -> None, "Control Suggestions" -> None, "Thumbnail" -> 
    None, "Authoring Information" -> None}},
FrontEndVersion->"12.1 for Mac OS X x86 (64-bit) (June 19, 2020)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Demonstration.nb", 
  CharacterEncoding -> "UTF-8"],
ExpressionUUID->"6b9733b2-d9d7-4a50-8f1f-ad0fa9d9b442"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Initialization Code"->{
  Cell[746, 27, 1833, 39, 68, "InitializationSection",ExpressionUUID->"1d34a731-8c48-4189-8b6f-89ef5777db9f",
   CellTags->"Initialization Code"]},
 "Manipulate"->{
  Cell[2604, 70, 1524, 30, 68, "ManipulateSection",ExpressionUUID->"b7acceb9-ca4b-4965-b319-bd8a6214a587",
   CellTags->"Manipulate"]},
 "Caption"->{
  Cell[26319, 528, 1138, 24, 68, "ManipulateCaptionSection",ExpressionUUID->"3ed78bfd-4459-4d2a-906f-3e9e6aba33a4",
   CellTags->"Caption"]},
 "Thumbnail"->{
  Cell[27728, 564, 1016, 23, 68, "ThumbnailSection",ExpressionUUID->"401cc3c4-8319-4e19-82e7-df5fcb711a42",
   CellTags->"Thumbnail"]},
 "Snapshots"->{
  Cell[84097, 1449, 1018, 22, 68, "SnapshotsSection",ExpressionUUID->"96bb7a68-4496-4362-86d3-c2a0812907f2",
   CellTags->"Snapshots"]},
 "Details"->{
  Cell[102837, 1782, 1796, 36, 68, "DetailsSection",ExpressionUUID->"b9971572-9357-4ce2-a011-62ff9eede7fa",
   CellTags->"Details"]},
 "Control Suggestions"->{
  Cell[104658, 1822, 1131, 28, 68, "ControlSuggestionsSection",ExpressionUUID->"af8a4061-fdd4-44d0-82cc-9fec786547ab",
   CellTags->"Control Suggestions"]},
 "ResizeImages"->{
  Cell[105792, 1852, 410, 10, 29, "ControlSuggestions",ExpressionUUID->"ac542041-3d26-42bf-920d-b54a74785eef",
   CellTags->"ResizeImages"]},
 "RotateAndZoomIn3D"->{
  Cell[106205, 1864, 783, 19, 29, "ControlSuggestions",ExpressionUUID->"e14e98ed-7514-4081-99ea-c2ffb624df9b",
   CellTags->"RotateAndZoomIn3D"]},
 "DragLocators"->{
  Cell[106991, 1885, 438, 13, 29, "ControlSuggestions",ExpressionUUID->"384b79dc-c11a-492d-87e1-2c4b84403891",
   CellTags->"DragLocators"]},
 "CreateAndDeleteLocators"->{
  Cell[107432, 1900, 739, 18, 29, "ControlSuggestions",ExpressionUUID->"98a81657-e34e-4dab-ac86-717d7eff050a",
   CellTags->"CreateAndDeleteLocators"]},
 "SliderZoom"->{
  Cell[108174, 1920, 944, 23, 29, "ControlSuggestions",ExpressionUUID->"b84ac2ce-e422-4d4d-953e-073d63c15a9e",
   CellTags->"SliderZoom"]},
 "GamepadControls"->{
  Cell[109121, 1945, 469, 11, 29, "ControlSuggestions",ExpressionUUID->"b4dbde82-29d9-4853-88cd-e053ae8d181c",
   CellTags->"GamepadControls"]},
 "AutomaticAnimation"->{
  Cell[109593, 1958, 1564, 33, 29, "ControlSuggestions",ExpressionUUID->"6e84bbe0-7d8e-44ab-aac1-048973c18d4f",
   CellTags->"AutomaticAnimation"]},
 "BookmarkAnimation"->{
  Cell[111160, 1993, 1008, 23, 29, "ControlSuggestions",ExpressionUUID->"0cf5a50d-6c0e-4089-a29f-941bc4ca8891",
   CellTags->"BookmarkAnimation"]},
 "Search Terms"->{
  Cell[112183, 2019, 1073, 24, 68, "SearchTermsSection",ExpressionUUID->"a3a3a6a7-7876-4115-a51a-6d092bee139b",
   CellTags->"Search Terms"]},
 "Related Links"->{
  Cell[113259, 2045, 1191, 28, 68, "RelatedLinksSection",ExpressionUUID->"83b0243b-b7e3-4afb-8a4e-185fec8161fe",
   CellTags->"Related Links"]},
 "Authoring Information"->{
  Cell[114475, 2077, 1158, 28, 68, "AuthorSection",ExpressionUUID->"c2736cdb-c24c-4dd4-9a22-5bbef1a7a20a",
   CellTags->"Authoring Information"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Initialization Code", 118290, 2161},
 {"Manipulate", 118455, 2164},
 {"Caption", 118605, 2167},
 {"Thumbnail", 118763, 2170},
 {"Snapshots", 118915, 2173},
 {"Details", 119066, 2176},
 {"Control Suggestions", 119226, 2179},
 {"ResizeImages", 119402, 2182},
 {"RotateAndZoomIn3D", 119568, 2185},
 {"DragLocators", 119734, 2188},
 {"CreateAndDeleteLocators", 119906, 2191},
 {"SliderZoom", 120076, 2194},
 {"GamepadControls", 120238, 2197},
 {"AutomaticAnimation", 120408, 2200},
 {"BookmarkAnimation", 120581, 2203},
 {"Search Terms", 120748, 2206},
 {"Related Links", 120911, 2209},
 {"Authoring Information", 121084, 2212}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 163, 3, 98, "Title",ExpressionUUID->"b9e6fe14-67c5-4f7d-9ec0-13c361826e91"],
Cell[746, 27, 1833, 39, 68, "InitializationSection",ExpressionUUID->"1d34a731-8c48-4189-8b6f-89ef5777db9f",
 CellTags->"Initialization Code"],
Cell[CellGroupData[{
Cell[2604, 70, 1524, 30, 68, "ManipulateSection",ExpressionUUID->"b7acceb9-ca4b-4965-b319-bd8a6214a587",
 CellTags->"Manipulate"],
Cell[4131, 102, 22151, 421, 812, "Input",ExpressionUUID->"1c8a51fe-61b3-446f-b3f3-b27c622b6763"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26319, 528, 1138, 24, 68, "ManipulateCaptionSection",ExpressionUUID->"3ed78bfd-4459-4d2a-906f-3e9e6aba33a4",
 CellTags->"Caption"],
Cell[27460, 554, 231, 5, 23, "ManipulateCaption",ExpressionUUID->"71921e4e-c8c2-4f05-96e3-4e3047349e9a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[27728, 564, 1016, 23, 68, "ThumbnailSection",ExpressionUUID->"401cc3c4-8319-4e19-82e7-df5fcb711a42",
 CellTags->"Thumbnail"],
Cell[28747, 589, 55313, 855, 202, "Output",ExpressionUUID->"58c040db-333b-4c73-bea5-902ccd2013e9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[84097, 1449, 1018, 22, 68, "SnapshotsSection",ExpressionUUID->"96bb7a68-4496-4362-86d3-c2a0812907f2",
 CellTags->"Snapshots"],
Cell[85118, 1473, 17704, 306, 244, "Output",ExpressionUUID->"28ce2d21-e862-4a50-b19b-1b190171b769"]
}, Open  ]],
Cell[102837, 1782, 1796, 36, 68, "DetailsSection",ExpressionUUID->"b9971572-9357-4ce2-a011-62ff9eede7fa",
 CellTags->"Details"],
Cell[CellGroupData[{
Cell[104658, 1822, 1131, 28, 68, "ControlSuggestionsSection",ExpressionUUID->"af8a4061-fdd4-44d0-82cc-9fec786547ab",
 CellTags->"Control Suggestions"],
Cell[105792, 1852, 410, 10, 29, "ControlSuggestions",ExpressionUUID->"ac542041-3d26-42bf-920d-b54a74785eef",
 CellTags->"ResizeImages"],
Cell[106205, 1864, 783, 19, 29, "ControlSuggestions",ExpressionUUID->"e14e98ed-7514-4081-99ea-c2ffb624df9b",
 CellTags->"RotateAndZoomIn3D"],
Cell[106991, 1885, 438, 13, 29, "ControlSuggestions",ExpressionUUID->"384b79dc-c11a-492d-87e1-2c4b84403891",
 CellTags->"DragLocators"],
Cell[107432, 1900, 739, 18, 29, "ControlSuggestions",ExpressionUUID->"98a81657-e34e-4dab-ac86-717d7eff050a",
 CellTags->"CreateAndDeleteLocators"],
Cell[108174, 1920, 944, 23, 29, "ControlSuggestions",ExpressionUUID->"b84ac2ce-e422-4d4d-953e-073d63c15a9e",
 CellTags->"SliderZoom"],
Cell[109121, 1945, 469, 11, 29, "ControlSuggestions",ExpressionUUID->"b4dbde82-29d9-4853-88cd-e053ae8d181c",
 CellTags->"GamepadControls"],
Cell[109593, 1958, 1564, 33, 29, "ControlSuggestions",ExpressionUUID->"6e84bbe0-7d8e-44ab-aac1-048973c18d4f",
 CellTags->"AutomaticAnimation"],
Cell[111160, 1993, 1008, 23, 29, "ControlSuggestions",ExpressionUUID->"0cf5a50d-6c0e-4089-a29f-941bc4ca8891",
 CellTags->"BookmarkAnimation"]
}, Open  ]],
Cell[112183, 2019, 1073, 24, 68, "SearchTermsSection",ExpressionUUID->"a3a3a6a7-7876-4115-a51a-6d092bee139b",
 CellTags->"Search Terms"],
Cell[113259, 2045, 1191, 28, 68, "RelatedLinksSection",ExpressionUUID->"83b0243b-b7e3-4afb-8a4e-185fec8161fe",
 CellTags->"Related Links"],
Cell[CellGroupData[{
Cell[114475, 2077, 1158, 28, 68, "AuthorSection",ExpressionUUID->"c2736cdb-c24c-4dd4-9a22-5bbef1a7a20a",
 CellTags->"Authoring Information"],
Cell[115636, 2107, 282, 5, 23, "Author",ExpressionUUID->"e6a077c9-f528-4852-97e7-764f2f3a1895"]
}, Open  ]]
}, Open  ]]
}
]
*)

