(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    179270,       3397]
NotebookOptionsPosition[    169502,       3205]
NotebookOutlinePosition[    175480,       3329]
CellTagsIndexPosition[    174808,       3307]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Introducing the Chain Rule", "Title",
 CellChangeTimes->{{3.84201518474997*^9, 3.8420151903276854`*^9}, {
  3.842015724406968*^9, 3.842015731409824*^9}, {3.84201578598505*^9, 
  3.8420157899870367`*^9}, {3.842016153096918*^9, 
  3.84201615832227*^9}},ExpressionUUID->"b9e6fe14-67c5-4f7d-9ec0-\
13c361826e91"],

Cell[TextData[{
 "Initialization Code",
 StyleBox[" (optional) ", "SectionGloss"],
 Cell[BoxData[
  TemplateBox[{"Initialization Code", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{"Provide any code that must be evaluated before the ", 
          StyleBox["Manipulate", "MRbig"], 
          ". This will automatically be built into the ", 
          StyleBox["Manipulate", "MRbig"], 
          " in the final notebook version. Never use a package that is not \
included in the default distribution of ", 
          StyleBox["Mathematica", FontSlant -> "Italic"], 
          ". To use a package, use the ", 
          StyleBox["Initialization", "MRbig"], " option (with ", 
          StyleBox["Get", "MRbig"], ", not ", 
          StyleBox["Needs", "MRbig"], ") in the ", 
          StyleBox["Manipulate", "MRbig"], 
          " itself, and use the full name of the function from the package. \
For example:\n", 
          StyleBox[
          "  Manipulate[\n  ...\n  ComputationalGeometry`ConvexHull[...]...\n \
 ...\n  Initialization :> Get[\"ComputationalGeometry`\"],\n  ...\n  ]", 
           "MR"], "\nIf you provide initialization code, include a ", 
          StyleBox["SaveDefinitions->True", "MRbig"], " option in the ", 
          StyleBox["Manipulate", "MRbig"], ".", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "81fde376-e763-44cf-83ed-5c52ec315067"]
}], "InitializationSection",
 CellTags->
  "Initialization \
Code",ExpressionUUID->"1d34a731-8c48-4189-8b6f-89ef5777db9f"],

Cell[CellGroupData[{

Cell[TextData[{
 "Manipulate",
 Cell[BoxData[
  TemplateBox[{"Manipulate", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{"This section contains the ", 
          StyleBox["Manipulate", "MRbig"], 
          " input cell and its evaluated output cell. Make all control labels \
or labels in the output as descriptive as possible, with only proper nouns \
and proper adjectives capitalized. More description of the controls can be \
provided in the Details section below, if necessary. If you change this ", 
          StyleBox["Manipulate", "MRbig"], 
          " after creating screenshots and/or thumbnails, use ", 
          StyleBox["Update Thumbnail & Snapshots", FontWeight -> "Bold"], 
          " in the toolbar to update any copies in later sections. You can \
control the Flash preview for the Demonstration with the ", 
          StyleBox["AutorunSequencing", "MRbig"], " option. Use ", 
          StyleBox["SaveDefinitions->True", "MRbig"], 
          " if you provided initialization code in the previous section."}], 
        "MoreInfoText"], Background -> GrayLevel[0.95], FrameMargins -> 20, 
       FrameStyle -> GrayLevel[0.9], RoundingRadius -> 5]], "MoreInfoText", 
     Deletable -> True, CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "d12d57a6-93e6-4518-8a9c-9df2eb688354"]
}], "ManipulateSection",
 CellTags->
  "Manipulate",ExpressionUUID->"b7acceb9-ca4b-4965-b319-bd8a6214a587"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"With", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"licenseImage", "=", 
     GraphicsBox[
      TagBox[RasterBox[CompressedData["
1:eJztnQdYVVfW929i7C2CIpbYwBABG1LEith7F7tYECtSBRUUNRrsFJWigggo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        "], {{0, 30.}, {154., 0}}, {0, 255},
        ColorFunction->RGBColor,
        ImageResolution->{144, 144}],
       BoxForm`ImageTag[
       "Byte", ColorSpace -> "RGB", Interleaving -> True, MetaInformation -> 
        Association[
         "Exif" -> Association[
           "Software" -> 
            "Created with the Wolfram Language : www.wolfram.com", "DateTime" -> 
            DateObject[{2020, 9, 11, 10, 7, 17.}, "Instant", "Gregorian", 
              4.294967292*^9], "TimeZoneOffset" -> 4294967292], "Comments" -> 
          Association[
           "Software" -> 
            "Created with the Wolfram Language : www.wolfram.com", 
            "Creation Time" -> 
            DateObject[{2020, 9, 11, 10, 7, 17.}, "Instant", 
              "Gregorian", -4.]]]],
       Selectable->False],
      DefaultBaseStyle->"ImageGraphics",
      ImageSizeRaw->{154., 30.},
      PlotRange->{{0, 154.}, {0, 30.}}]}], "}"}], ",", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"Manipulate", "[", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"plotFunctions", "=", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{"showSin", ",", 
           RowBox[{"f", "[", "x", "]"}], ",", "Nothing"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{"showSinShift", ",", 
           RowBox[{"f", "[", 
            RowBox[{"x", "-", "1"}], "]"}], ",", "Nothing"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{"showSin2x", ",", 
           RowBox[{"f", "[", 
            RowBox[{"aa", " ", "x"}], "]"}], ",", "Nothing"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{"showDerivSin2x", ",", 
           RowBox[{
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{"f", "[", 
               RowBox[{"aa", " ", "x"}], "]"}], ",", "x"}], "]"}], "//", 
            "Evaluate"}], ",", "Nothing"}], "]"}]}], 
        RowBox[{"(*", 
         RowBox[{",", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{"showDerivSinx", ",", 
            RowBox[{
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{"f", "[", "x", "]"}], ",", "x"}], "]"}], "//", 
             "Evaluate"}], ",", "Nothing"}], "]"}]}], "*)"}], 
        "\[IndentingNewLine]", "}"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"plotLegends", "=", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
          "showSin", ",", 
           "\"\<\!\(\*StyleBox[\"z\",FontSlant->\"Italic\"]\) = \
\!\(\*StyleBox[\"g\",FontSlant->\"Italic\"]\)(\!\(\*StyleBox[\"x\",FontSlant->\
\"Italic\"]\)) = sin(\!\(\*StyleBox[\"x\",FontSlant->\"Italic\"]\))\>\"", ",",
            "Nothing"}], "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
          "showSinShift", ",", 
           "\"\<\!\(\*StyleBox[\"z\",FontSlant->\"Italic\"]\) = \
\!\(\*StyleBox[\"g\",FontSlant->\"Italic\"]\)(\!\(\*StyleBox[\"x\",FontSlant->\
\"Italic\"]\)-1)\>\"", ",", "Nothing"}], "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{"showSin2x", ",", 
           RowBox[{"Row", "[", 
            RowBox[{"{", 
             RowBox[{
             "\"\<\!\(\*StyleBox[\"z\",FontSlant->\"Italic\"]\) = \
\!\(\*StyleBox[\"g\",FontSlant->\"Italic\"]\)(\!\(\*StyleBox[\"ax\",FontSlant-\
>\"Italic\"]\)), \!\(\*StyleBox[\"a\",FontSlant->\"Italic\"]\) = \>\"", ",", 
              "aa"}], "}"}], "]"}], ",", "Nothing"}], "]"}], ",", 
         RowBox[{"If", "[", 
          RowBox[{
          "showDerivSin2x", ",", 
           "\"\<\!\(\*StyleBox[\"z\",FontSlant->\"Italic\"]\) = \
\!\(\*StyleBox[FractionBox[\"d\", \
\"dx\"],FontSlant->\"Italic\"]\)\!\(\*StyleBox[\"[\",FontSize->16]\)\!\(\*\
StyleBox[\"g\",FontSlant->\"Italic\"]\)(\!\(\*StyleBox[\"ax\",FontSlant->\"\
Italic\"]\))\!\(\*StyleBox[\"]\",FontSize->16]\)\>\"", ",", "Nothing"}], 
          "]"}]}], 
        RowBox[{"(*", 
         RowBox[{",", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
           "showDerivSinx", ",", 
            "\"\<\!\(\*StyleBox[\"z\",FontSlant->\"Italic\"]\) = \
\!\(\*SuperscriptBox[StyleBox[\"g\",FontSlant->\"Italic\"], StyleBox[RowBox[{\
\" \", \"\[Prime]\"}],FontSize->14]]\)(\!\(\*StyleBox[\"x\",FontSlant->\"\
Italic\"]\))\>\"", ",", "Nothing"}], "]"}]}], "*)"}], "\[IndentingNewLine]", 
        "\[IndentingNewLine]", "}"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"plotStyles", "=", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{"showSin", ",", "Red", ",", "Nothing"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{"showSinShift", ",", 
           RowBox[{"ColorData", "[", 
            RowBox[{"1", ",", "3"}], "]"}], ",", "Nothing"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{"showSin2x", ",", 
           RowBox[{"ColorData", "[", 
            RowBox[{"1", ",", "4"}], "]"}], ",", "Nothing"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{"showDerivSin2x", ",", 
           RowBox[{"ColorData", "[", 
            RowBox[{"1", ",", "1"}], "]"}], ",", "Nothing"}], "]"}]}], 
        RowBox[{"(*", 
         RowBox[{",", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{"showDerivSinx", ",", 
            RowBox[{"ColorData", "[", 
             RowBox[{"1", ",", "2"}], "]"}], ",", "Nothing"}], "]"}]}], 
         "*)"}], "\[IndentingNewLine]", "}"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"Plot", "[", "\[IndentingNewLine]", 
       RowBox[{"plotFunctions", ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"AxesLabel", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
          "\"\<\!\(\*StyleBox[\"x\",FontSlant->\"Italic\"]\)\>\"", ",", 
           "\"\<\!\(\*StyleBox[\"z\",FontSlant->\"Italic\"]\)\>\""}], "}"}]}],
         ",", "\[IndentingNewLine]", 
        RowBox[{"PlotLegends", "\[Rule]", "plotLegends"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", 
             RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}]}], "}"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"PlotStyle", "\[Rule]", " ", "plotStyles"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Epilog", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Inset", "[", 
           RowBox[{"attribution", ",", 
            RowBox[{"{", 
             RowBox[{"0.2", ",", 
              RowBox[{"-", "2.53"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"Automatic", ",", ".5"}], "}"}]}], "]"}], "}"}]}]}], 
       "\[IndentingNewLine]", "]"}]}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"aa", ",", "1", ",", "\"\<a\>\""}], "}"}], ",", "1", ",", "2",
        ",", 
       RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "showSin", ",", "True", ",", 
         "\"\<\!\(\*StyleBox[\"g\",FontSlant->\"Italic\"]\)(\!\(\*StyleBox[\"\
x\",FontSlant->\"Italic\"]\)) = \
sin(\!\(\*StyleBox[\"x\",FontSlant->\"Italic\"]\))\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"True", ",", "False"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "showSinShift", ",", "False", ",", 
         "\"\<\!\(\*StyleBox[\"g\",FontSlant->\"Italic\"]\)(\!\(\*StyleBox[\"\
x\",FontSlant->\"Italic\"]\)-1) = \
sin(\!\(\*StyleBox[\"x\",FontSlant->\"Italic\"]\)-1)\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"True", ",", "False"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "showSin2x", ",", "False", ",", 
         "\"\<\!\(\*StyleBox[\"g\",FontSlant->\"Italic\"]\)(\!\(\*StyleBox[\"\
ax\",FontSlant->\"Italic\"]\)) = \
sin(\!\(\*StyleBox[\"ax\",FontSlant->\"Italic\"]\))\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"True", ",", "False"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "showDerivSin2x", ",", "False", ",", 
         "\"\<\!\(\*FractionBox[StyleBox[\"d\",FontSlant->\"Italic\"], \
StyleBox[\"dx\",FontSlant->\"Italic\"]]\)\!\(\*StyleBox[\"[\",FontSize->14]\)\
\!\(\*StyleBox[\"g\",FontSlant->\"Italic\"]\)(\!\(\*StyleBox[\"ax\",FontSlant-\
>\"Italic\"]\))\!\(\*StyleBox[\"]\",FontSize->14]\)\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"True", ",", "False"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
          "showDerivSinx", ",", "False", ",", 
           "\"\<\!\(\*FractionBox[StyleBox[\"d\",FontSlant->\"Italic\"], \
StyleBox[\"dx\",FontSlant->\"Italic\"]]\)\!\(\*StyleBox[\"[\",FontSize->14]\)\
\!\(\*StyleBox[\"g\",FontSlant->\"Italic\"]\)(\!\(\*StyleBox[\"x\",FontSlant->\
\"Italic\"]\))\!\(\*StyleBox[\"]\",FontSize->14]\)\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"True", ",", "False"}], "}"}]}], "}"}], ","}], "*)"}], 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"Initialization", "\[RuleDelayed]", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"f", "[", "x_", "]"}], ":=", 
         RowBox[{"Sin", "[", "x", "]"}]}], ";"}], "\[IndentingNewLine]", 
       "}"}]}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"ContentSize", " ", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{"600", ",", "250"}], "}"}]}]}], "\[IndentingNewLine]", "]"}]}],
   "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.842014786028146*^9, 3.8420147903051167`*^9}, {
   3.842014835148839*^9, 3.842014844057199*^9}, 3.842014953322263*^9, {
   3.842015808317369*^9, 3.8420158229578238`*^9}, {3.84201617414082*^9, 
   3.8420161862428093`*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"1c8a51fe-61b3-446f-b3f3-b27c622b6763"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`aa$$ = 1, $CellContext`showDerivSin2x$$ = 
    False, $CellContext`showSin$$ = True, $CellContext`showSin2x$$ = 
    False, $CellContext`showSinShift$$ = False, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`aa$$], 1, "a"}, 1, 2}, {{
       Hold[$CellContext`showSin$$], True, 
       "\!\(\*StyleBox[\"g\",FontSlant->\"Italic\"]\)(\!\(\*StyleBox[\"x\",\
FontSlant->\"Italic\"]\)) = \
sin(\!\(\*StyleBox[\"x\",FontSlant->\"Italic\"]\))"}, {True, False}}, {{
       Hold[$CellContext`showSinShift$$], False, 
       "\!\(\*StyleBox[\"g\",FontSlant->\"Italic\"]\)(\!\(\*StyleBox[\"x\",\
FontSlant->\"Italic\"]\)-1) = sin(\!\(\*StyleBox[\"x\",FontSlant->\"Italic\"]\
\)-1)"}, {True, False}}, {{
       Hold[$CellContext`showSin2x$$], False, 
       "\!\(\*StyleBox[\"g\",FontSlant->\"Italic\"]\)(\!\(\*StyleBox[\"ax\",\
FontSlant->\"Italic\"]\)) = \
sin(\!\(\*StyleBox[\"ax\",FontSlant->\"Italic\"]\))"}, {True, False}}, {{
       Hold[$CellContext`showDerivSin2x$$], False, 
       "\!\(\*FractionBox[StyleBox[\"d\",FontSlant->\"Italic\"], \
StyleBox[\"dx\",FontSlant->\"Italic\"]]\)\!\(\*StyleBox[\"[\",FontSize->14]\)\
\!\(\*StyleBox[\"g\",FontSlant->\"Italic\"]\)(\!\(\*StyleBox[\"ax\",FontSlant-\
>\"Italic\"]\))\!\(\*StyleBox[\"]\",FontSize->14]\)"}, {True, False}}}, 
    Typeset`size$$ = {486., {109., 114.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`aa$$ = 1, $CellContext`showDerivSin2x$$ = 
        False, $CellContext`showSin$$ = True, $CellContext`showSin2x$$ = 
        False, $CellContext`showSinShift$$ = False}, 
      "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> ($CellContext`plotFunctions = {
          If[$CellContext`showSin$$, 
           $CellContext`f[$CellContext`x], Nothing], 
          If[$CellContext`showSinShift$$, 
           $CellContext`f[$CellContext`x - 1], Nothing], 
          If[$CellContext`showSin2x$$, 
           $CellContext`f[$CellContext`aa$$ $CellContext`x], Nothing], 
          If[$CellContext`showDerivSin2x$$, 
           Evaluate[
            D[
             $CellContext`f[$CellContext`aa$$ $CellContext`x], \
$CellContext`x]], Nothing]}; $CellContext`plotLegends = {
          
          If[$CellContext`showSin$$, 
           "\!\(\*StyleBox[\"z\",FontSlant->\"Italic\"]\) = \
\!\(\*StyleBox[\"g\",FontSlant->\"Italic\"]\)(\!\(\*StyleBox[\"x\",FontSlant->\
\"Italic\"]\)) = sin(\!\(\*StyleBox[\"x\",FontSlant->\"Italic\"]\))", 
           Nothing], 
          
          If[$CellContext`showSinShift$$, 
           "\!\(\*StyleBox[\"z\",FontSlant->\"Italic\"]\) = \
\!\(\*StyleBox[\"g\",FontSlant->\"Italic\"]\)(\!\(\*StyleBox[\"x\",FontSlant->\
\"Italic\"]\)-1)", Nothing], 
          If[$CellContext`showSin2x$$, 
           
           Row[{"\!\(\*StyleBox[\"z\",FontSlant->\"Italic\"]\) = \
\!\(\*StyleBox[\"g\",FontSlant->\"Italic\"]\)(\!\(\*StyleBox[\"ax\",FontSlant-\
>\"Italic\"]\)), \!\(\*StyleBox[\"a\",FontSlant->\"Italic\"]\) = ", \
$CellContext`aa$$}], Nothing], 
          
          If[$CellContext`showDerivSin2x$$, 
           "\!\(\*StyleBox[\"z\",FontSlant->\"Italic\"]\) = \
\!\(\*StyleBox[FractionBox[\"d\", \
\"dx\"],FontSlant->\"Italic\"]\)\!\(\*StyleBox[\"[\",FontSize->16]\)\!\(\*\
StyleBox[\"g\",FontSlant->\"Italic\"]\)(\!\(\*StyleBox[\"ax\",FontSlant->\"\
Italic\"]\))\!\(\*StyleBox[\"]\",FontSize->16]\)", 
           Nothing]}; $CellContext`plotStyles = {
          If[$CellContext`showSin$$, Red, Nothing], 
          If[$CellContext`showSinShift$$, 
           ColorData[1, 3], Nothing], 
          If[$CellContext`showSin2x$$, 
           ColorData[1, 4], Nothing], 
          If[$CellContext`showDerivSin2x$$, 
           ColorData[1, 1], Nothing]}; 
       Plot[$CellContext`plotFunctions, {$CellContext`x, 0, 2 Pi}, 
         AxesLabel -> {
          "\!\(\*StyleBox[\"x\",FontSlant->\"Italic\"]\)", 
           "\!\(\*StyleBox[\"z\",FontSlant->\"Italic\"]\)"}, 
         PlotLegends -> $CellContext`plotLegends, 
         PlotRange -> {{0, 2 Pi}, {-2.5, 2.5}}, 
         PlotStyle -> $CellContext`plotStyles, Epilog -> {
           
           Inset[$CellContext`attribution, {0.2, -2.53}, {0, 0}, {
            Automatic, 0.5}]}]), 
      "Specifications" :> {{{$CellContext`aa$$, 1, "a"}, 1, 2, Appearance -> 
         "Open"}, {{$CellContext`showSin$$, True, 
          "\!\(\*StyleBox[\"g\",FontSlant->\"Italic\"]\)(\!\(\*StyleBox[\"x\",\
FontSlant->\"Italic\"]\)) = \
sin(\!\(\*StyleBox[\"x\",FontSlant->\"Italic\"]\))"}, {
         True, False}}, {{$CellContext`showSinShift$$, False, 
          "\!\(\*StyleBox[\"g\",FontSlant->\"Italic\"]\)(\!\(\*StyleBox[\"x\",\
FontSlant->\"Italic\"]\)-1) = sin(\!\(\*StyleBox[\"x\",FontSlant->\"Italic\"]\
\)-1)"}, {
         True, False}}, {{$CellContext`showSin2x$$, False, 
          "\!\(\*StyleBox[\"g\",FontSlant->\"Italic\"]\)(\!\(\*StyleBox[\"ax\"\
,FontSlant->\"Italic\"]\)) = sin(\!\(\*StyleBox[\"ax\",FontSlant->\"Italic\"]\
\))"}, {True, False}}, {{$CellContext`showDerivSin2x$$, False, 
          "\!\(\*FractionBox[StyleBox[\"d\",FontSlant->\"Italic\"], StyleBox[\
\"dx\",FontSlant->\"Italic\"]]\)\!\(\*StyleBox[\"[\",FontSize->14]\)\!\(\*\
StyleBox[\"g\",FontSlant->\"Italic\"]\)(\!\(\*StyleBox[\"ax\",FontSlant->\"\
Italic\"]\))\!\(\*StyleBox[\"]\",FontSize->14]\)"}, {True, False}}}, 
      "Options" :> {ContentSize -> {600, 250}}, 
      "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{614., {217., 222.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`f[
          Pattern[$CellContext`x, 
           Blank[]]] := Sin[$CellContext`x]; Null}; Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.842015823482627*^9, 3.842015830449931*^9}, {
   3.842015916467164*^9, 3.8420159421541977`*^9}, {3.8420159750987167`*^9, 
   3.842015992255165*^9}, 3.8420161866597548`*^9},
 CellLabel->"Out[1]=",
 CellID->708169245,ExpressionUUID->"81eb52a0-90bc-44dc-b56f-03eea1ce13d4"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Caption",
 Cell[BoxData[
  TemplateBox[{"Caption", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{
         "The caption provides all the information needed to understand the \
Demonstration. It should be between three and five sentences long, but \
clarity is more important than length. Include only text in this section \
\[LongDash] no code, graphics, etc. Do not change the cell style or copy \
cells from other sections. Do not copy text from books or the web. Write your \
ideas in your own words. If you want to refer to something on the web, link \
to it in the Details.", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "a97b5d36-1c59-4018-b3f0-6bfc71662d3d"]
}], "ManipulateCaptionSection",
 CellTags->"Caption",ExpressionUUID->"3ed78bfd-4459-4d2a-906f-3e9e6aba33a4"],

Cell["\<\
Illustration of the formal definition of the limit of a function.\
\>", "ManipulateCaption",
 CellChangeTimes->{{3.842014860199045*^9, 
  3.8420148680160027`*^9}},ExpressionUUID->"71921e4e-c8c2-4f05-96e3-\
4e3047349e9a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Thumbnail",
 Cell[BoxData[
  TemplateBox[{"Thumbnail", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{
         "To create the thumbnail, copy and paste the output cell from the ", 
          
          StyleBox["Manipulate", "MRbig"], 
          " section and adjust the controls to the most visually appealing \
setting. Do not convert it to a bitmap. The thumbnail is what visitors see \
when browsing the Demonstrations site and while the Flash preview loads.", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "5363174b-397a-4e31-b8e5-95e1af887bc9"]
}], "ThumbnailSection",
 CellTags->"Thumbnail",ExpressionUUID->"401cc3c4-8319-4e19-82e7-df5fcb711a42"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  TagBox[GridBox[{
     {
      GraphicsBox[{{{}, {}, 
         TagBox[
          {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
           Opacity[1.], LineBox[CompressedData["
1:eJwt2Hk4VO/7B/AZ58xYkqVJaY69vmRJpVXJuVGy9qEiqfQhQogsEcq+RiSh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            "]]},
          Annotation[#, "Charting`Private`Tag$197187#1"]& ], 
         TagBox[
          {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
           Opacity[1.], LineBox[CompressedData["
1:eJwllGlQ02cQxgkEkBAh4R2tVCB/KAMauaxXUfRdRQsVQRSDLdQKkSPFCIqk
RYNWlEO02qigEMxQDlGGAaqDB7aSV4OgHPFIRWywZuSwcrQcpiSApH+nH3Z2
dmef3356HldhytZ4czMzs1C6PnTFYaHV4jjpmkNvQsdMJgRNGmrTduor3C+d
q9dOIzA1Nx6jqG9xGOfVxE0jAgU5xbOkDmDKf+/7lHEE4tWSPRO8PKw6cXaW
rh+BZkqUP8IrwrN8nruQDgTW2teew7wqnJ8WE3KkGEFpa8m+QV4DrmbsrzBb
gaC2Lk8r9mnFlvFBnzrucIBE/KRoKFWDUdd9cdkZLiT3Leypr32Bt6rkuxa2
coDlmuX56jMdlv6zWizrsYfTnDZ+aUwPbvhenlS32Q6E2m1Ki/Z+vPmsgJop
YsO++1nCFM8BHKy4ExY8xIKre9kR874YxldaDnTuj7aBUunuAb/tI3hnVv6c
R1es4WjJ9JZ3Q6P4cIxFrS2yAjONDn47OI7NvHnKwGwmeKQlpG/j6/EfJ4ty
q5+ZQ6/+QqTtnX+xE0tU9W4dAzb2JR06u8+Axcv4llonEw7rlS1ycZnEcSv+
vKJSTeEBlfDIg5op7JW+0pRcYcA+3E7nwJ3vccXLiKYDa/WYhfWx3eMzeChz
TkDQvDEcNBw14SYwgwcFCzb8FTmMu+7FMaK8GABvX7zzVfTj68ebvqH0DPjy
ttbmfaQOJ1hKdGq1OfxcVWfgIg3elSq9zpZbACR+Uvo0owH7Ji5Sb4plAml7
cWJJxC3lIwcvW4m/JYx43b0WfkGj/LX2aLGXhRV0SeZ0xznqlFIGP7z9JT3b
hmcK/+5XsroPBifXW0O4rjMwtXxY2Vfpml+SMQvyi3PCD4+NKvMXODIbBDYQ
XhbH6Y3UK2XyhJZYigWQJHfOzTQoo/J3qNlvWCDa8p3/kotTSsP6S8aSRlvQ
oYL+HyZnlD1969Lv5bKhuS17JMueQcpWL57fETsb1kuFy+Uqc1KTLeEmettB
lO2gmzqKSXIFu0Is9HZgV9183mrAkizrLq3K7bCHpFuBEfbF1qRwYXFNRwgH
YirFN5b72pAfyKnCkAYOTDNWCH36WCR0vuBSqzsXlu7ZVsA/xyZrk1uiuXlc
YDY4p2xwtyMlTkL3dj0XMlKPn/F7bk/cVZfPh0U7QHDOZm/FDQ6Red/jP210
ACo6S1BxiEsSxplPHvIRtPfblJ0TOBDh1TEq7yfaV8K+tQ48RMRHI6Y3nkHQ
xbxsKHBDRBJR/5x9DsFApajO0QOR43rJadl5BJzBQSdXb0Rq/Y1TFxQIvt4/
NuG7ChHjXVNnZTWCsWOmmtDtiMiesk81tSCgLjl+TP8h8vI9opyHCJYGaR/T
XFKepg4MbkPw+duLuTSX3Jgrm2xT0771pvQ0l3RHIZHmGYJb1z0e01zi2eMY
+LoHQVjzkhyaS/zqD7pU9CGIEekDaA5Zma01xr9BkMa6OU5zyCZPxS9vBxAU
hq2MpTkkdTflMjqKoLcTAmgOyQjINF6jc8KQbj5O60j27Ne/p+kRsOY3VdE6
UlhXftJgQOC3M+gjWkfKjjATb08iWM+wUdN3pHpL/LoMOociy1uz6DtS79bs
vGYGgWjDj6voPWkc9zB+yK2M//OL/AcG5ESs
            "]]},
          Annotation[#, "Charting`Private`Tag$197187#2"]& ], 
         TagBox[
          {RGBColor[0.560181, 0.691569, 0.194885], AbsoluteThickness[1.6], 
           Opacity[1.], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQPbcuic0wpdqOAQIOsN9+pP5WfqU9jL/w1PzC1/I7
4fx16ztv5+idgvPT7S/OfFN0Gc7Pe6r5eMu6m3A+l2KL+n2LB3B+n8BprYUJ
j+H8pNsh+5nPPIPzC4+2JOWrv4LzNxbwBEt4vkW4pzr7lUH4Bzi/af6fwC9v
PsL5DJcfOOyp+gznq5WkVYRofYXzn3ydHsa99xuc7/U0q3ZS4Q843+/JBG05
uV9w/qvDSQ0n1v6G8/UEr8k6x/9F+M/+a+Kdz//gfPe3Ud+VQhkcYPwbh1IY
o3QY4fytHUfiFL4i+GmspQ/OnWOC85OLqrfyzGKG8/XTtc/5JLLA+eeFdLhL
LVnh/N3rmmbrMLPB+dWMWgFn7iL4XHeqPPK2sMP5T5cpTplfwwHnT9GQZNkZ
ygnnT5iVdjxRgQvOj5oSe47nOYL/w2Xpz/n7uOH8x0+dKg6188D5i2wNpc8m
8sL5a1tLBdN1+eD89tBkb+avCL7pnYUr28/yw/kzNGevPestAOfXH+id4b0T
wfeVDl16SkUQznfMOx4t2Ingz5dJUjnzFcFXObx8ml+0EMJ/uoe0Lu1D8NM+
s1w8qSUM5ydt/KTQ2Y/gT7jE03vkOIK/77Paz///EXwAxkPjhA==
            "]]},
          Annotation[#, "Charting`Private`Tag$197187#3"]& ]}, {}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->{True, True},
       AxesLabel->{None, None},
       AxesOrigin->{0, 0},
       DisplayFunction->Identity,
       Epilog->{
         AbsolutePointSize[8], 
         RGBColor[1, 0.5, 0], {
          PointBox[{2.5, 7.}]}, {{
           Thickness[Large], 
           RGBColor[1, 0.5, 0], 
           StyleBox[
            InsetBox[
             FormBox["\"\"", TraditionalForm], {2.5, 0.}], {
            FontFamily -> "Times", 18}, StripOnInput -> False], 
           Opacity[0.6], 
           LineBox[{{2.5, -0.5995}, {2.5, 0.5995}}]}}},
       Frame->{{False, False}, {False, False}},
       FrameLabel->{{None, None}, {None, None}},
       FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
       GridLines->{None, None},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       ImagePadding->All,
       ImageSize->{223.39108276367188`, Automatic},
       Method->{
        "DefaultBoundaryStyle" -> Automatic, 
         "DefaultGraphicsInteraction" -> {
          "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
           "Effects" -> {
            "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2},
              "Droplines" -> {
              "freeformCursorMode" -> True, 
               "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
         "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
         None, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
             (Identity[#]& )[
              Part[#, 1]], 
             (Identity[#]& )[
              Part[#, 2]]}& ), "CopiedValueFunction" -> ({
             (Identity[#]& )[
              Part[#, 1]], 
             (Identity[#]& )[
              Part[#, 2]]}& )}},
       PlotRange->{{0, 5}, {-6.199, 8.189}},
       PlotRangeClipping->True,
       PlotRangePadding->{{0, 0}, {0, 0}},
       Ticks->{Automatic, Automatic}]},
     {
      GraphicsBox[
       TagBox[RasterBox[CompressedData["
1:eJztnQdcFVfaxlFsqCiiFHsHKzbE3jVqFFew92isUVDArojYK3ZQI4JK7x0E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         "], {{0, 24.5}, {125., 0}}, {0, 255},
         ColorFunction->RGBColor,
         ImageResolution->{144, 144}],
        BoxForm`ImageTag[
        "Byte", ColorSpace -> "RGB", Interleaving -> True, MetaInformation -> 
         Association[
          "Exif" -> Association[
            "Software" -> 
             "Created with the Wolfram Language : www.wolfram.com", 
             "DateTime" -> 
             DateObject[{2020, 9, 11, 10, 7, 17.}, "Instant", "Gregorian", 
               4.294967292*^9], "TimeZoneOffset" -> 4294967292], "Comments" -> 
           Association[
            "Software" -> 
             "Created with the Wolfram Language : www.wolfram.com", 
             "Creation Time" -> 
             DateObject[{2020, 9, 11, 10, 7, 17.}, "Instant", 
               "Gregorian", -4.]]]],
        Selectable->False],
       DefaultBaseStyle->"ImageGraphics",
       ImageSizeRaw->{125., 24.5},
       PlotRange->{{0, 125.}, {0, 24.5}}]}
    },
    AutoDelete->False,
    GridBoxItemSize->{"Columns" -> {{Large}}, "Rows" -> {{Large}}}],
   "Grid"]}]], "Output",
 CellEditDuplicate->False,
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.842015089647626*^9, {3.842015124625918*^9, 3.8420151544796553`*^9}, {
   3.842015956149169*^9, 
   3.842015956320114*^9}},ExpressionUUID->"58c040db-333b-4c73-bea5-\
902ccd2013e9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Snapshots",
 Cell[BoxData[
  TemplateBox[{"Snapshots", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{"To create snapshots, paste the output cell from the ", 
          StyleBox["Manipulate", "MRbig"], 
          " section in this section at least three times, and adjust the \
controls of each copy to show a range of interesting settings. Do not convert \
the screenshots to bitmaps. Optional captions for the screenshots may be \
included in the Details section.", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "d854de0f-efbb-449a-8b04-a7b3ca5773d5"]
}], "SnapshotsSection",
 CellTags->"Snapshots",ExpressionUUID->"96bb7a68-4496-4362-86d3-c2a0812907f2"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  TagBox[
   RowBox[{
    RowBox[{GridBox[{
       {
        GraphicsBox[{{{}, {}, 
           TagBox[
            {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
             Opacity[1.], LineBox[CompressedData["
1:eJwt2nk4VF8fAHDMWJK4Y0opRRtCkkRJfU+UvURRqRSVfU+lUhSRNYpIouwl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              "]]},
            Annotation[#, "Charting`Private`Tag$200839#1"]& ], 
           TagBox[
            {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
             Opacity[1.], LineBox[CompressedData["
1:eJwlmXk81N/3x+3Z1xapENmXlFIh502RaJEQRQlJRIQSJVmSIpItJbKXSKJs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              "]]},
            Annotation[#, "Charting`Private`Tag$200839#2"]& ], 
           TagBox[
            {RGBColor[0.560181, 0.691569, 0.194885], AbsoluteThickness[1.6], 
             Opacity[1.], LineBox[CompressedData["
1:eJwtmHk8VN//x4cZMz5STY36KMVUioTUp0WL3ockoqIiSxtF9qUoSTWRnUiF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              "]]},
            Annotation[#, "Charting`Private`Tag$200839#3"]& ]}, {}},
         AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
         Axes->{True, True},
         AxesLabel->{None, None},
         AxesOrigin->{0, 0},
         DisplayFunction->Identity,
         Epilog->{
           AbsolutePointSize[8], 
           RGBColor[1, 0.5, 0], {
            PointBox[{0.8492425980780821, 1.9861607142857143`}], 
            PointBox[{2.5, 1.3968253968253967`}], 
            PointBox[{4.1507574019219176`, 1.9861607142857145`}]}, {{
             Thickness[Large], 
             RGBColor[1, 0.5, 0], 
             StyleBox[
              InsetBox[
               FormBox["\"\"", TraditionalForm], {0.8492425980780821, 0.}], {
              FontFamily -> "Times", 18}, StripOnInput -> False], 
             Opacity[0.6], 
             
             LineBox[{{0.8492425980780821, -0.3942460317460319}, {
              0.8492425980780821, 0.3942460317460319}}]}, {
             Thickness[Large], 
             RGBColor[1, 0.5, 0], 
             StyleBox[
              InsetBox[
               FormBox["\"\"", TraditionalForm], {2.5, 0.}], {
              FontFamily -> "Times", 18}, StripOnInput -> False], 
             Opacity[0.6], 
             
             LineBox[{{2.5, -0.3942460317460319}, {2.5, 
              0.3942460317460319}}]}, {
             Thickness[Large], 
             RGBColor[1, 0.5, 0], 
             StyleBox[
              InsetBox[
               FormBox["\"\"", TraditionalForm], {4.1507574019219176`, 0.}], {
              FontFamily -> "Times", 18}, StripOnInput -> False], 
             Opacity[0.6], 
             
             LineBox[{{4.1507574019219176`, -0.3942460317460319}, {
              4.1507574019219176`, 0.3942460317460319}}]}}},
         Frame->{{False, False}, {False, False}},
         FrameLabel->{{None, None}, {None, None}},
         FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
         GridLines->{None, None},
         GridLinesStyle->Directive[
           GrayLevel[0.5, 0.4]],
         ImagePadding->All,
         ImageSize->500,
         Method->{
          "DefaultBoundaryStyle" -> Automatic, 
           "DefaultGraphicsInteraction" -> {
            "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
             "Effects" -> {
              "Highlight" -> {"ratio" -> 2}, 
               "HighlightPoint" -> {"ratio" -> 2}, 
               "Droplines" -> {
                "freeformCursorMode" -> True, 
                 "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
           "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
           None, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
               (Identity[#]& )[
                Part[#, 1]], 
               (Identity[#]& )[
                Part[#, 2]]}& ), "CopiedValueFunction" -> ({
               (Identity[#]& )[
                Part[#, 1]], 
               (Identity[#]& )[
                Part[#, 2]]}& )}},
         PlotRange->{{0, 5}, {-5.875793650793653, 3.586111111111112}},
         PlotRangeClipping->True,
         PlotRangePadding->{{0, 0}, {0, 0}},
         Ticks->{Automatic, Automatic}]},
       {
        GraphicsBox[
         TagBox[RasterBox[CompressedData["
1:eJztnQdcFVfaxlFsqCiiFHsHKzbE3jVqFFew92isUVDArojYK3ZQI4JK7x0E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           "], {{0, 24.5}, {125., 0}}, {0, 255},
           ColorFunction->RGBColor,
           ImageResolution->{144, 144}],
          BoxForm`ImageTag[
          "Byte", ColorSpace -> "RGB", Interleaving -> True, MetaInformation -> 
           Association[
            "Exif" -> Association[
              "Software" -> 
               "Created with the Wolfram Language : www.wolfram.com", 
               "DateTime" -> 
               DateObject[{2020, 9, 11, 10, 7, 17.}, "Instant", "Gregorian", 
                 4.294967292*^9], "TimeZoneOffset" -> 4294967292], "Comments" -> 
             Association[
              "Software" -> 
               "Created with the Wolfram Language : www.wolfram.com", 
               "Creation Time" -> 
               DateObject[{2020, 9, 11, 10, 7, 17.}, "Instant", 
                 "Gregorian", -4.]]]],
          Selectable->False],
         DefaultBaseStyle->"ImageGraphics",
         ImageSizeRaw->{125., 24.5},
         PlotRange->{{0, 125.}, {0, 24.5}}]}
      },
      AutoDelete->False,
      GridBoxItemSize->{"Columns" -> {{Large}}, "Rows" -> {{Large}}}], 
     TagBox[GridBox[{
        {
         GraphicsBox[{{{}, {}, 
            TagBox[
             {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
              Opacity[1.], LineBox[CompressedData["
1:eJwV13lcTO8XB/DblCSlmTsRWQppVyKR7TkqoU2rrU0pRdGiFC0SQrQoCm1I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               "]]},
             Annotation[#, "Charting`Private`Tag$202681#1"]& ], 
            TagBox[
             {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
              Opacity[1.], LineBox[CompressedData["
1:eJwV13k8lU8XAHBblnuvvbSjkEQi2tWZdpVSJH6lFIoKpVLZhbJWSIjKkqzZ
irJlbGVfQtbr3ufaE7JHlHfev3y+nzP3mZkzM2fGGtMbepd5uLi40ri5uP7/
95WLKb+6ueOeR2fil+elduDSRlkdQ9n/wPd5vvDenA688LXAQ1b2KuRa9T35
XNKBXxU+llkkaw/lCmMQ3tqBrXbbWf+W8YGMQI3ALm4mbpyzDB6VeQG3K8aD
0vWYWKCjS3FYJhFaXZ4o6g4zcWvhZ7uhgUSorh03Tppm4qS4sJKfGUmgXL7l
3PwCE5+4dcJkcP87ODtbn+Mp0YlDhHJD+i3SwFs+RUNxWyeWeFnOM9byHoak
PPIzXTpxdGWk7U+ZHOhTb9u6wM/Ck2FZG9j+OfBCK+9jvygLH7Ko6m6YzYE7
r0wSvixj4SHe3wa5jbkgomY3eGkDC2/ffWKnj1c+lO92Ull1nIXr0+Z5FH9h
EJODzy8CWNi1UuWoukkJtOkV5VWIsnFCxqd1yc9LQEKmQOzyUjZuCNvHq1BN
4pnJctPSbCxvYZS/bEcp3Kaz/Wc3snElr6cql+QXYAvppj08xsZSuzsk6r5+
BYPbL45kebJxappPh5VqJYRs5XZx/8XGgxKD/kcvVUJlh323zRQbK949umd9
cCUMJ6a90Jtj4ygtenT3bCUMJQhxufFSOKjC/8rZL1WwzMzVblaEwne7n44d
Nq4B+Zliu9UKFI6kV3mIH6yHaFOlYLUTFN6z29HY7UI9RBmd+/DqJIWZNspb
ft2rB8d1Iy/49Sm8rMGvrzqpHpSCpIqqDCkcGKZzxFvsG5jHBgfJXaKwh0Kt
yELHN2D4G6yk3aawBXx7MXSrETIUrvrnPKMwV8x0bodfI8zTYDT0OYXD+FYx
K2MbQSFph9mtUAqXV1yRTmxuhJFVBxxWRlB4/en5mMs7myCGDx7tiaHwgKXi
Oxb3d7h24UxXeRqF3ap0ampWfAeNdFqcZQYZn+qtkXyN73C1xdWL7wOFtSfy
1SIuf4e5d/rxah8pnOisl2VY8R14326+czafwteCnAvqA5rh6lFD0akyCvNM
xbBxYjOkFiWvMqygcLhhOVdacTOMKJ0/k1VJ4cpVkvsfTzbD4SZnvSs1FFaO
Tyg7YtQCIYWHvcIbKDyU11hfLNMKj+y90nSYFPaUnh3L2N4K++t2j9p2UnjV
A2nJ6FOt4Kc+fP0Zi8I6h64auHq0Quxa1tIqisIp9f/advW3wub+F+eEeyls
06vUnZnaBsGOPCasIQpTF9oEiyra4OHmHKOOYQrrt3qr1vS0wf2LKpONIxTe
XtVv37uiHcSjxxZnj1KYN+OtmJRXO2zSCJfWmSTrv8Fg69qYdlCSbTm0bork
8w2fserndgj1kFsxT1wbYhZ/aKIdnDcGfw3/TdbHac2eeyYd4ON3zzD2D4Vp
0/VmHg4dIJ3UMHNujsLON9x8nj7vgOd7Ak6IzlPY1JTdFF/VAb3azJVX/1JY
RfvV9dZtTFh96eyFHwsUfl2kE9ijx4T2d9dLXLg4WHzX/MdRayYMWm/uE+Xm
4OmN53iEYplQVOdzVYGHg4skl7/YIdYJFwN4vFfzcbDm4/KCg8qd0MBnOhdA
HMd/v+fUoU6gjVRs4VrEwf6zzZuuOXWC92tjvgbif7ceGdwN7YQkBWa4Jj8H
2w5tcXR/3wk60cJ/g4jPsMk8BzqhfGqT0n4BDi43OjAUx8sClyd2U8HEuxom
xD9Is8A6Qiqoizj12JtteAcLPJx2c6kIcrDsF73zVadZkBq4eK8tcdAeHo+W
Gyzo3PnV4D3xouyMhG5fFsy3OMEv4sEkscm5QhZUWMeEGAtxsLF84XJBJgsM
1l3hf0xc9+oGLP7NAm+9Vt0c4n1LZS7LSrDhjJ7cHQ5xZkCtr8pGNiQ9tL2z
iMbBijSX9O3abLijM3xKgTjcY2PzATM2RPMXCe8lZvxlzp10YYPM4qWJRsSu
d/3XnH/Bhs6m5QpWxOO/dh2+msmGyoQJd0di86s/rezq2ND4q7bkEXFLV3jQ
g0E29Ak1DzwmVlBVYH7loWDijMZEADFrcH5ER4yCvq3iPU+Jw+KbuBtXU5Am
FJ7vS3zK/N3i/5Qp2LVpxvkBMW2NpyJ7OwX2AmeU7hCXawVucjlIwcCXNiFz
4kdGr7et1qOg9eDh8yeJD9xJhvwLFASLBcrvIOYJyD587joF5mmJF6WJC5O/
6P65R0FgsocEF7FLWYPhC08SfyK+i0XypdXNNtkeSMF6zsGObOI//4YsWl5R
oLBRcvIpcfaKPzfuJlEQN3f9kRnx3a0C95d8omD8+75nGsSaeovdMkso0D/o
u5KLeNx6jbd+PQUSjZqyFWQ9031UA8aZFDgKbol5QmzzdldY4A8KGm2cY04S
/2QaJNTxcMBlIn1NJdk/STOm6TaiHDCTfxDzgNhy8c1s4VUcOJ9s9nYLcc8x
3/JjWziQRylteUb2Z4xFaP3gXg68jx4v0SK+6BHb6nOCAz2doa1dZH8zcwsG
yiw4IDu8N1SeOLy5avTKHQ7kNyjvLyTnw2i8dWbRA/I9o/z7RsRNShOCB8I5
8PdahKcLLwdXhykqFVZzIOld645ocv58MzXVTdo4oPfC5fgaYu36vTv+9XIg
7qbJ+CtyXksFjI9oLXDgHt/LCX9ynvPvBlzNVu+C3FKvkb3kvDsEvbI13NMF
JTT/uDhSD7anJtlPHyV+aPJbgDizt9RH07wLymCPRSGpJymnZxPTQ7pgvOxS
uOAMha1u8r/XfdMFqTlXNPRI/dngL5k7ktYFyRvqrMKmKRxXsrFSpaIL/NOC
S1eQevV6s+lgwlwXDGvbr/09RuEnYlUboi92w7F26rroTwrnbFuddcKmG6K/
PH0uOkjhngs3YN6xG6TCWO30HxTelSJ52jC0G4pzVT/P9JF6eMTYWbi2G1Js
jXliuyi832O4zn5XD1g6CL3a20bqcRKcVTzSA7V618T5Wsn98C2wp+lMD9Rr
fMwsbqbwqMzW2U23esh55/hrNpHx5bus7UvogadyOm8Hayk8MyVqpyfVCztf
entGl1BYbrXpwoJcL+yxP35fsZjCJw5k+qSo94KBm3ZqYiGF3wYZvRY83gtS
3z/0xnymsN6m6LICj15wlJSLtfxE8me5eYXyWC9czXa13pdE6m/Hacxb3Qcv
D4u92faY1OsIjrVtWx/81fl74JQfhd+ftVnF7usDS8nBmxY+5H5o97LP5e6H
iDP6130eUji2NVfDdls/iHUa0mKdKdz3XTaBFdMPNJniUU1rcl/WDwXk2A/A
PuneczVHKCwRYA+KXgPgvaT4tsNhCufq8o8EBw9AqsXanfIHKUyvkzl2M20A
mE//NlsjCr+r0Vuk2DsABlLitm1bKTxSmW0ffPIHhKkdWicpR2HbL56mNxQH
IcvdXE59nI2lew7xT2sMwld7Hs/lw2xcxSOU5IQGYb9m8fn5fjZWQI/HfP4b
hDXRop4ZnWzclvvcLdZvEO4tx3Vt5Wy8Nz3udduvQTjhfIZH/jUbi0eUt+/P
/gmXW0Kqkg+wccZNhv6yI8Owm5cZP/qAhavDJe1TzgzD5fpxqTkHFu4rXRG5
z3wYIqcnAxdus/CK5Uo/rVyHgfV6Y9b0ZRb2LDroUZQ1DPzPAsZfHWHhMxKu
H66tHYHUFOmzDeR9+efDmOTnuRHIrrA07w4l71HH64NqhqMg6LU6bkMoE7tH
zp+aHBoDnceNh7Rc2zFXI4XyHSbgifXdb75qrXjdnSv3T2+YgqnytoE/Nt9x
z1ToGfrnaTj6tE+aE9+Aj/Zecw6ynSGPKd4PUwO1+ERPgLK09B9QUb8sUKdb
jgdLTN3KU+ZAOkZqrGm0CKuKN6/eb/IXZmyMNHbkZGEaTF1iTvyDKLVzt27H
ROHDw2d/rzXgQlEWCUVWK19Aa7E591kVbrTe6u69dq9MyPIuvSA7xY3Kq9dx
b/9WCFcW2VG1tTxIlv2BzY3LwOyWYxYjnBdx1RudqpyvgU0WyrU6l/gQk6bU
ETn4DeokVOh2OxahYFXkldjXBHmp7hEqvPzopZDZu58OLeDIveFkdSc/suK/
H8vgawca00HbJlMAid2dfcSzhQlb7yUKP/0kgAS/xEQGazHhkkRrQ1quAEpf
bb9i7QEmZGtvOT9WKIDQ46ObNukz4UrWL9s7NQKovqYuWtyWvCuemEc49Akg
7WVsxnQyE+7vPTHyaJkgOjk8KKIm3Qm9cWuCI50EkexN70vck50w5MmZ5XUT
ROsV03Hfn04YN402sfQQRAGTLfJfuVnAJbNGWd1XEF0czv9zS5QFK0Jli4tD
SXuR0SDPDSw46SUz2vteEG2vDLv80IQF+RardVR+CKLsVV3LhktZUHKwMyNg
iPjcwTKRKhZUyr1aOvVLECGPU+obvrGghb2q+/M0GU/crOqJThaMG65y0OUT
QssmXj45OsWC9dorE27JCKGbFjV1EvJsCF6/nC/HgMSTSlj1TmwwvrAuvttI
CK3fvLG78gEb5IM1jooYCyGxKhE1/IgNmQvHA8xMhdCARGBESAAbmprdV4nc
IO01xj24Ytkg+XBI08ybxO3XDxdUsCGIgy8L5wmhd1E5xlaCFJxdWiO4vUAI
afo50P1pFKw93p5sWkR+z2jECQwK3mdPjn0qI/3tv7uljbwTGp4quZg2CSGt
6KwdUsspEN/zLOTTMIlzv6hbWE9BQPiVskuyNNR6YdbJ9xAF9+6633aSo6F6
MQWEtCm4oPdaJnQdDZWf3So0cYQCFVrzvWoVGtKZsk7UPU5Bhf3B9dt20JDR
7Ihgrz4FPP/J+zD0aOhdr4KD60UKfmiiLYoGNDRpeW3TIlMK6sWMOXuNaIjL
RYHpZUZBZPmzHfcu0FBmhNkyzysUaG3nHeRco6H8s595jKwosFvadfSTBw1p
P21qsiLvDuOJv9PfHtHQSde9z4vuU3CgbvmbIR8aKv2TtUfSgbwTvE7NrQmg
Ic+G5UdSnChInS5M9n9JQ1q5vmvzH5B3z/dIhmkWDd2UWFh9wI+Cuoy8bKds
GgqjxfJY+FPw8XGLeWgeDc14cYoePabA86Do5+oiGoo96Vud/5SCNVku1ttq
aSi99uQsTzBZj+DztYx+GhpViOybjqBg1QfayuuDNMToVdWbe0kB+9sni4ph
Gpo3NZyZI+8gc1EJ7keTJB8mzb/GIimw8f2qscBNR1GfD11Pf0OBWuJtt/OL
6IjReMYvJJa8+8pka/IE6chIrYx5/y0F9xc5XrkvSkejj1REN8dT4O626cXY
Kjoa4C0N/P+76kAks1dXlo5iPwWs2pNMgUCBz+ZUOTrarvWwjvsdBf5z3VXX
NtCRk9ORROcUCkLuhv3r3kZHhdtn6YfTKTB6fvDYvl101NRQ8OkX8crM8dCo
PXRU+vW2e3AGBVFjOurnD9LROzfRmw3vKUi04jZv1qMj7ZflfjJZFFj5paZr
niFx8xKRRGLVpHN/g/4j4xW1i1f9SPZnf1aI7kU68m+8uESVvPvu8Jt1p5jR
0apanYF44m0KYmoMCzpadlO/enU2Bfmm1yrKrenI22ZxyV9ilwdLpRRt6ehk
ilujRQ4Fe6NKTR/eIfM3vD5aQ/y1U3p+ryMdqWXJHHuSS4H3fJV2lAsdyR6N
eDRAfGyl/fN/D+jIUnS2Yk8e2Y9Gjap53nQU/KvAjE0cdM/Ncbk/HaUPtX5S
yqfAIGRj+b2nJJ+s7aI3iZdltS9uDiLr9fGT5Xvi9kavS5ohdJRwWbVklPjl
uGZq0AsyX6bdauXPFJiId/0ZfUnaC1vcvUS8Vu3pYd0oku+B9upnxD0ntIJT
3pD1MEmSKSaOs/5B0ePpaMY01XqI+Kp/yMZrSWS+PThLooCcv+T9DuUp5HtN
n6Y1iUcqRr+uyyD7ReHGJn3i9IFXkg8z6Sjza8EFa+LbAscudn8i/SW5engQ
b103825vHh1pFfu+fE48c+DtbGQB2V//shPeEDvlRXqUFpH+4/+uTCHm2hwu
/KOU5F/1I/8HYs+E4FDhchL/OW6RRSwg83TN5io6urizdE8mse9zn+QztWS/
3N7pm0YswvDc4viNrMf45SPxxEHuLjiyieRT1NAxglhq9v6R0hY6kl8nLeNP
HH7jduNAOxnv0yoNe+LVfdbnhVl05Bl3I9uUOMrYsl+dQ0dWpSveaRPLN5ra
nukh8f2dwsrECUfOzzn001GrcxlT6P/5KjR8GDlIRzdrfiztJflM36onWjpM
9qv/6YJ8Yo0UnRcDo+R7i5fVBRB/lDssJzxJR5P4wJH/r9fO8L0p6r/J9wYG
lVWJ93ltLXL4S0fUit51n8l6f/2rdiySi4EEW//b7Up85I7y9xJeBkp38Mne
TXzykuwPBo2BXraebUsj+6upZcVtdWEGmjy82tmM2OjEkr8GYgw0xMd8IEls
sosmHinFQPl1T5MsyX61WTK5XV2OfN89/EI/2f/jfiPFBusYSH6b0KgzsR3P
Dx0HJQbio/1uFyN2+tV5sWQTA3nbBuYok/PkV1HmbaDFQMtk/Vy3kPMogool
HICBql/mF6dmkvX4mP/y9T4GihIYNZQnDn+Tkd6vTcYr+voO3weST+eIVnsD
BmIUU8ZhpB6oTD43fW3EQMbeP5dMppF8XgsYKj7HQDMMx+U6xJ8MH3IxTBnI
KOfq/CipL1/Vb6x/bcNA5vd0l4qQetTdu+9+sRexrl9dMKlv+yJrYzb4MdDA
zCYcTepflNHZmqAnDCSmqL83KYbcP1W2a82eM5Bmh+5MShQ5b+lR1bxvSH4U
C0TdSH1tcPwne7CA9O9wtO34MwrUt/geSyki+ZXKuyQZRO63kSV3l3wh8zd5
frUpgIITlzZW9VaR+X0uGtd+QkHlIWO7R20MNL/9ecWcNwXF4rkVZZMMlHmK
18XLmdT7qoOTm2YYSNZo3JqP3Cdunt+kw+YYSGXz1konct/s+T1w25JHGPEp
/y42IfdTLnOptJCYMBLMmn02cpPUu3i7W0eVhRFTrzNBldx3MbvVV9ZcEkYJ
fxcOqB0g/Z2gecyZC6NqwT5xrX0UdJl0DypZCiMr01m8H1Eg5/4895GNMNLO
+pJ3SIuC2K+z/yFHYXSyvFRqpSYFb3WLwz4EC6OBpUy3+bVkvS7pS4WXkfjC
9/db59hQfkvFpbxSGHFZ5Tftm2bDgMeivukaYaSW1+pwaIwN6+M+Zek3CSO3
ayPHNPvZkDi40kCYI4wu/thYldjAhqTbPc/c/gij+pPzvn/i2ZDy0E7cYqMI
4qLX3lPQYcOQ1nn3h2oi6GLinfdah9hkfxyYeKNB4hq/fI4h8nvTxd+pHSJo
dIWI4ElNNiTAh7Czh0SQW0WW8ORKNsTOjsqcMBFBAVOFsXE/WBBubaW6JZDE
Na5uTnRhQbv86Uj9YBKvYjmm32PBcuYusVuhIggNhymm3WRB2FH6eOorEURR
3q+DTFnwXDEpa30S6X/xipaxgywI4PRrrSoh/f9b0iZKZ4GXgdkx3ikRJBYk
derzk06I0WUaX54h5hhJ/3vYCflHDGzK5kRQupSeh6YzeX/uPhzoxyNK5idO
d7/eCcbrlFskxUSRW9DF+sjDnbD597ipvLIoSo+TUuz5ywRWmLvDwUuiSPZW
SrKrKRO2MKMTvWpEEbrccNiV3gFiqpYzafXEDjnjzVwdMOSqeri1kbQXqaUp
TLdDrFxez/p2UTRq2+8QS7XD4utNMpV9xBcyFNSy2uGPE+8xfi4xVO+pP3/f
uB3a6FuLtJeLISruglnJmzYIU4pIqTkmhtyc/5bWL26FyYlDbz2Oi5H/F877
RfC3gm7B+MsduqS9Zrnn2ZkW4Nc/6v9WTwyJeYoJZHW0gJ3T7DXn/8jv5coX
MaNbQK/OcP1GCzGUPhtS+0u5BRh2i9/4u4uh0Yi6N6u3NYNr4eOwYzkk7hwo
TFdqgsHOwuDZXDGk1tElIbusCc7MTQTE54shNGgkpyTQBCpbz/rwFoqhm9mP
jZf2NkJr8jqHvK+k/YXFo2ZRjbA5FJ9TbiL9Mywj8hY3Qp/1mDT9F4n/yOU2
mPwGx1cavK2UF0eFD7R4L66ug702ZefEfcQRVxHF3CD9BSJXmcpXT4kjN/dI
ucVGGSBfEh9y4pwE4uJqK0iRjMEBG4s3NBRIoMLH++Z654rxlQm+bxUbJJHb
siznnzsbsGnGuKzPU0kU5SzWbIc6sJW7/vzRQEl0cfMv14xrHdhOP7OF8UwS
yXadd/gX3IG9p+yeBISQ9rfMr1f/6MCpO2bnQl9JIopu4bU9mIlnixaa45LJ
92vKxvSHOnFAA+NxaZkkSneTGG86TeHwN9aWjyokEfp44T/adQq/uVO7X7uK
xLtbgrQfUPijVMCfqlpJdPPL4wfsFAozz0paNn6XRFwLabfuCXCwYvfy/V3d
kqhwjXjFyXwOVst0kI7tJXHXw6OSjRy882HH7OV+SXTy1Kt/7B8crKP4Kv3H
IPn+RPf3oKVd+NZ1WemxMWK/h8/MbndhJ60Hs+8nyHx/miyz8e3CD4W7mu5M
Ef9rePIguguHpb3xm5kh42Vhg5K6LhzjxmeR+4fM/09LwlhfF04+dXmf0zwZ
z9Uv4+v/deHMtV9X7/lHxq/fonl1STcumFg3u7AgiQLYxjffq3Tj/wFlt54v

               "]]},
             Annotation[#, "Charting`Private`Tag$202681#2"]& ], 
            TagBox[
             {RGBColor[0.560181, 0.691569, 0.194885], AbsoluteThickness[1.6], 
              Opacity[1.], LineBox[CompressedData["
1:eJwV13k8VN0fB/BrRpKlMFJpoZoSJRQ9UvoeS0rUQ5ZsIY+tUChSKI+UiCwJ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               "]]},
             Annotation[#, "Charting`Private`Tag$202681#3"]& ]}, {}},
          AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
          Axes->{True, True},
          AxesLabel->{None, None},
          AxesOrigin->{0, 0},
          DisplayFunction->Identity,
          Epilog->{
            AbsolutePointSize[8], 
            RGBColor[1, 0.5, 0], {
             PointBox[{-0.5914999640608736, 2.1469188205135388`}], 
             PointBox[{1.9955313865420496`, 1.2523756325638309`}], 
             PointBox[{4.556494893308298, 2.123083556789364}]}, {{
              Thickness[Large], 
              RGBColor[1, 0.5, 0], 
              StyleBox[
               InsetBox[
                FormBox["\"\"", TraditionalForm], {-0.5914999640608736, 
                0.}], {FontFamily -> "Times", 18}, StripOnInput -> False], 
              Opacity[0.6], 
              
              LineBox[{{-0.5914999640608736, -0.18898675132275136`}, \
{-0.5914999640608736, 0.18898675132275136`}}]}, {
              Thickness[Large], 
              RGBColor[1, 0.5, 0], 
              StyleBox[
               InsetBox[
                FormBox["\"\"", TraditionalForm], {1.9955313865420496`, 
                0.}], {FontFamily -> "Times", 18}, StripOnInput -> False], 
              Opacity[0.6], 
              
              LineBox[{{1.9955313865420496`, -0.18898675132275136`}, {
               1.9955313865420496`, 0.18898675132275136`}}]}, {
              Thickness[Large], 
              RGBColor[1, 0.5, 0], 
              StyleBox[
               InsetBox[
                FormBox["\"\"", TraditionalForm], {4.556494893308298, 0.}], {
               FontFamily -> "Times", 18}, StripOnInput -> False], 
              Opacity[0.6], 
              
              LineBox[{{4.556494893308298, -0.18898675132275136`}, {
               4.556494893308298, 0.18898675132275136`}}]}}},
          Frame->{{False, False}, {False, False}},
          FrameLabel->{{None, None}, {None, None}},
          FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
          GridLines->{None, None},
          GridLinesStyle->Directive[
            GrayLevel[0.5, 0.4]],
          ImagePadding->All,
          ImageSize->500,
          Method->{
           "DefaultBoundaryStyle" -> Automatic, 
            "DefaultGraphicsInteraction" -> {
             "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
              "Effects" -> {
               "Highlight" -> {"ratio" -> 2}, 
                "HighlightPoint" -> {"ratio" -> 2}, 
                "Droplines" -> {
                 "freeformCursorMode" -> True, 
                  "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
            "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
            None, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                (Identity[#]& )[
                 Part[#, 1]], 
                (Identity[#]& )[
                 Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                (Identity[#]& )[
                 Part[#, 1]], 
                (Identity[#]& )[
                 Part[#, 2]]}& )}},
          PlotRange->{{0, 5}, {-2.035645460317461, 2.5000365714285717`}},
          PlotRangeClipping->True,
          PlotRangePadding->{{0, 0}, {0, 0}},
          Ticks->{Automatic, Automatic}]},
        {
         GraphicsBox[
          TagBox[RasterBox[CompressedData["
1:eJztnQdcFVfaxlFsqCiiFHsHKzbE3jVqFFew92isUVDArojYK3ZQI4JK7x0E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            "], {{0, 24.5}, {125., 0}}, {0, 255},
            ColorFunction->RGBColor,
            ImageResolution->{144, 144}],
           BoxForm`ImageTag[
           "Byte", ColorSpace -> "RGB", Interleaving -> True, MetaInformation -> 
            Association[
             "Exif" -> Association[
               "Software" -> 
                "Created with the Wolfram Language : www.wolfram.com", 
                "DateTime" -> 
                DateObject[{2020, 9, 11, 10, 7, 17.}, "Instant", "Gregorian", 
                  4.294967292*^9], "TimeZoneOffset" -> 4294967292], 
              "Comments" -> 
              Association[
               "Software" -> 
                "Created with the Wolfram Language : www.wolfram.com", 
                "Creation Time" -> 
                DateObject[{2020, 9, 11, 10, 7, 17.}, "Instant", 
                  "Gregorian", -4.]]]],
           Selectable->False],
          DefaultBaseStyle->"ImageGraphics",
          ImageSizeRaw->{125., 24.5},
          PlotRange->{{0, 125.}, {0, 24.5}}]}
       },
       AutoDelete->False,
       GridBoxItemSize->{"Columns" -> {{Large}}, "Rows" -> {{Large}}}],
      "Grid"]}], "\[IndentingNewLine]"}],
   "Grid"]}]], "Output",
 CellEditDuplicate->False,
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.842015050295882*^9, 3.842015069644743*^9}, {
  3.8420151478334208`*^9, 3.8420151563791113`*^9}, {3.84201598668475*^9, 
  3.842016004923606*^9}},
 CellID->835389362,ExpressionUUID->"28ce2d21-e862-4a50-b19b-1b190171b769"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Details",
 StyleBox[" (optional) ", "SectionGloss"],
 Cell[BoxData[
  TemplateBox[{"Details", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{
         "This optional section is for a more detailed description of the \
Demonstration than the caption, but it should still be as concise as \
possible. This section may also include numbered snapshot captions (e.g., \
Snapshot 1: phrase or sentence without an initial capital and without a \
period, unless more than one sentence is used) and explanations of the ", 
          StyleBox["Manipulate", "MRbig"], 
          " control labels. Define any symbols undefined so far. Include only \
text in this section \[LongDash] no code, graphics, etc. Do not change the \
cell style or copy cells from other sections. \n\nA book reference uses this \
format: \n    L. D. Schmidt, ", 
          StyleBox[
          "The Engineering of Chemical Reactions", FontSlant -> "Italic"], 
          ", New York: Oxford University Press, 1998. \n\nAn article \
reference uses this format: \n    D. Pearson, \"A Polynomial-Time Algorithm \
for the Change-Making Problem,\" ", 
          StyleBox["Operations Research Letters", FontSlant -> "Italic"], 
          ", ", 
          StyleBox["33", FontWeight -> "Bold"], 
          "(3), 2005 pp. 231\[Dash]234."}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "b42cafa3-93cc-45b2-9bce-00512b05ae14"]
}], "DetailsSection",
 CellTags->"Details",ExpressionUUID->"b9971572-9357-4ce2-a011-62ff9eede7fa"],

Cell[TextData[{
 "To explore the relationship between the graphs of a function ",
 StyleBox["f",
  FontSlant->"Italic"],
 " and its first two derivatives, use the crosshairs to bend the graph of ",
 StyleBox["y ",
  FontSlant->"Italic"],
 "= ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ")."
}], "DemoNotes",
 CellChangeTimes->{{3.842015839766839*^9, 3.842015902443284*^9}},
 CellID->1361039527,ExpressionUUID->"85398564-2ab9-4890-987b-6687a7c114c4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Control Suggestions",
 StyleBox[" (optional) ", "SectionGloss"],
 Cell[BoxData[
  TemplateBox[{"Control Suggestions", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{
         "Check the boxes beside items that are appropriate control \
suggestions for this Demonstration. For more information, see the ", 
          ButtonBox[
          "guidelines", 
           BaseStyle -> {"Hyperlink", FontColor -> RGBColor[0.4, 0.45, 0.5]}, 
           ButtonData -> {
             URL["http://demonstrations.wolfram.com/guidelines.php"], None}], 
          " page.", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "f1fe398c-f37e-4aca-9161-633bae63965a"]
}], "ControlSuggestionsSection",
 CellTags->
  "Control Suggestions",ExpressionUUID->"af8a4061-fdd4-44d0-82cc-\
9fec786547ab"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Resize Images",ExpressionUUID->"fcee1195-e255-4dbd-8863-4af840debdbd"]}],
  
  "\"Click inside an image to reveal its orange resize frame.\\nDrag any of \
the orange resize handles to resize the image.\""]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "ResizeImages",ExpressionUUID->"ac542041-3d26-42bf-920d-b54a74785eef"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Rotate and Zoom in 3D",ExpressionUUID->
    "df0b52c8-7325-4803-bb1e-958545cedfd1"]}],
  RowBox[{
   "\"Drag a 3D graphic to rotate it. Starting the drag near the center \
tumbles\\nthe graphic; starting near a corner turns it parallel to the plane \
of the screen.\\nHold down \"", 
    FrameBox[
    "Ctrl", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" (or \"", 
    FrameBox[
    "Cmd", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], 
    "\" on Mac) and drag up and down to zoom.\""}]]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "RotateAndZoomIn3D",ExpressionUUID->"e14e98ed-7514-4081-99ea-c2ffb624df9b"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Drag Locators",ExpressionUUID->"61b2b2a8-69c4-4012-b6da-8923112012e2"]}],
  
  RowBox[{"\"Drag any locator (\"", 
    GraphicsBox[
     LocatorBox[
      Scaled[{0.5, 0.5}]], ImageSize -> 20], 
    "\", etc.) to move it around.\""}]]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "DragLocators",ExpressionUUID->"384b79dc-c11a-492d-87e1-2c4b84403891"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Create and Delete Locators",ExpressionUUID->
    "8e06b60e-3149-4a23-ab31-0a8ab2f5ceaf"]}],
  RowBox[{"\"Insert a new locator in the graphic by holding down the \"", 
    FrameBox[
    "Alt", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], 
    "\" key\\nand clicking where you want it to be. Delete a locator by \
clicking it\\nwhile holding down the \"", 
    FrameBox[
    "Alt", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" key.\""}]]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "CreateAndDeleteLocators",ExpressionUUID->"98a81657-e34e-4dab-ac86-\
717d7eff050a"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Slider Zoom",ExpressionUUID->"c8d377e3-56fc-4adc-88e3-cf7642fb3181"]}],
  RowBox[{"\"Hold down the \"", 
    FrameBox[
    "Alt", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], 
    "\" key while moving a slider to make fine adjustments in the slider \
value.\\nHold \"", 
    FrameBox[
    "Ctrl", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" and/or \"", 
    FrameBox[
    "Shift", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" at the same time as \"", 
    FrameBox[
    "Alt", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], 
    "\" to make ever finer adjustments.\""}]]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "SliderZoom",ExpressionUUID->"b84ac2ce-e422-4d4d-953e-073d63c15a9e"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Gamepad Controls",ExpressionUUID->
    "1fbb5ded-9a1c-4ba0-a087-0d1c0be219ce"]}],
  "\"Control this Demonstration with a gamepad or other\\nhuman interface \
device connected to your computer.\""]], "ControlSuggestions",
 CellChangeTimes->{3.35696210375764*^9, 3.3895522232313623`*^9},
 FontFamily->"Verdana",
 CellTags->
  "GamepadControls",ExpressionUUID->"b4dbde82-29d9-4853-88cd-e053ae8d181c"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Automatic Animation",ExpressionUUID->
    "ec8a5240-77b9-42a0-8b9e-365efb47dfeb"]}],
  RowBox[{"\"Animate a slider in this Demonstration by clicking the\"", 
    AdjustmentBox[
     Cell[
      GraphicsData[
      "CompressedBitmap", 
       "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcIKwAgOI/R/IhBKc\n\
/4EAyGAG0f+nTZsGwgysIJIRKsWKLAXGIHFmEpUgLADxWUAkI24jZs+eTaEt\n\
IG+wQKRmzJgBlYf5lhEA30OqWA=="], "Graphics", ImageSize -> {9, 9}, ImageMargins -> 
      0, CellBaseline -> Baseline], BoxBaselineShift -> 0.1839080459770115, 
     BoxMargins -> {{0., 0.}, {-0.1839080459770115, 0.1839080459770115}}], 
    "\"button\\nnext to the slider, and then clicking the play button that \
appears.\\nAnimate all controls by selecting \"", 
    StyleBox["Autorun", FontWeight -> "Bold"], "\" from the\"", 
    AdjustmentBox[
     Cell[
      GraphicsData[
      "CompressedBitmap", 
       "eJyNULENwyAQfEySIlMwTVJlCGRFsosokeNtqBmDBagoaZjAI1C8/8GUUUC6\n\
57h7cQ8PvU7Pl17nUav7oj/TPH7V7b2QJAUAXBkKmCPRowxICy64bRvGGNF7\n\
X8CctGoDSN4xhIDGGDhzFXwUh3/ClBKrDQPmnGXtI6u0OOd+tZBVUqy1xSaH\n\
UqiK6pPe4XdEdAz6563tx/gejuORGMxJaz8mdpJn7hc="], "Graphics", 
      ImageSize -> {10, 10}, ImageMargins -> 0, CellBaseline -> Baseline], 
     BoxBaselineShift -> 0.1839080459770115, 
     BoxMargins -> {{0., 0.}, {-0.1839080459770115, 0.1839080459770115}}], 
    "\"menu.\""}]]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "AutomaticAnimation",ExpressionUUID->"6e84bbe0-7d8e-44ab-aac1-048973c18d4f"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Bookmark Animation",ExpressionUUID->
    "5bdb2812-7da3-4bb1-a7fc-436054c40542"]}],
  RowBox[{
   "\"See a prepared animation of this Demonstration by selecting\\n\"", 
    StyleBox["Animate Bookmarks", FontWeight -> "Bold"], "\" from the\"", 
    AdjustmentBox[
     Cell[
      GraphicsData[
      "CompressedBitmap", 
       "eJyNULENwyAQfEySIlMwTVJlCGRFsosokeNtqBmDBagoaZjAI1C8/8GUUUC6\n\
57h7cQ8PvU7Pl17nUav7oj/TPH7V7b2QJAUAXBkKmCPRowxICy64bRvGGNF7\n\
X8CctGoDSN4xhIDGGDhzFXwUh3/ClBKrDQPmnGXtI6u0OOd+tZBVUqy1xSaH\n\
UqiK6pPe4XdEdAz6563tx/gejuORGMxJaz8mdpJn7hc="], "Graphics", 
      ImageSize -> {10, 10}, ImageMargins -> 0, CellBaseline -> Baseline], 
     BoxBaselineShift -> 0.1839080459770115, 
     BoxMargins -> {{0., 0.}, {-0.1839080459770115, 0.1839080459770115}}], 
    "\"menu.\""}]]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "BookmarkAnimation",ExpressionUUID->"0cf5a50d-6c0e-4089-a29f-941bc4ca8891"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Search Terms",
 StyleBox[" (optional) ", "SectionGloss"],
 Cell[BoxData[
  TemplateBox[{"Search Terms", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{
         "Provide words and phrases that people might search for, with each \
one in a separate cell. Categories are added after the Demonstration is \
submitted, so the best things to enter here are terms (including any \
synonyms) that refer to specific parts of the Demonstration. Do not \
capitalize words unless they are proper names or proper adjectives.", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "b8b4550c-a7c1-4c5e-acf4-64f68ac8ea51"]
}], "SearchTermsSection",
 CellTags->
  "Search Terms",ExpressionUUID->"a3a3a6a7-7876-4115-a51a-6d092bee139b"],

Cell["Chain Rule", "SearchTerms",
 CellChangeTimes->{{3.8432245385041933`*^9, 3.843224539685296*^9}},
 CellID->763001907,ExpressionUUID->"0bc42057-771d-4239-8a27-f3a28e8e1d84"],

Cell["Calculus 1", "SearchTerms",
 CellChangeTimes->{{3.8432245385041933`*^9, 3.843224541357581*^9}},
 CellID->890928401,ExpressionUUID->"d57e09dc-efcd-4c5d-a17a-82060fce9f7c"]
}, Open  ]],

Cell[TextData[{
 "Related Links",
 StyleBox[" (optional) ", "SectionGloss"],
 Cell[BoxData[
  TemplateBox[{"Related Links", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{
         "Provide hyperlinks (not just bare URLs) to any relevant wolfram.com \
pages, with the page title as the linked text. Links to ", 
          ButtonBox[
          "NKS | Online", 
           BaseStyle -> {"Hyperlink", FontColor -> RGBColor[0.4, 0.45, 0.5]}, 
           ButtonData -> {
             URL["http://www.wolframscience.com/nks"], None}], 
          " should use the section title, not a page number. Links to \
non-Wolfram sites go in the Details section.", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "d5b26c0d-c135-41cd-9d97-dc9003b05c57"]
}], "RelatedLinksSection",
 CellTags->
  "Related Links",ExpressionUUID->"83b0243b-b7e3-4afb-8a4e-185fec8161fe"],

Cell[CellGroupData[{

Cell[TextData[{
 "Authoring Information",
 Cell[BoxData[
  TemplateBox[{"Authoring Information", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{
         "'Contributed by: John Smith' for single authors; 'Contributed by: \
John Smith, Robert Ford, and Jane Doe' for multiple authors. To credit people \
other than Demonstrations authors, please see the detailed ", 
          ButtonBox[
          "guidelines", 
           BaseStyle -> {"Hyperlink", FontColor -> RGBColor[0.4, 0.45, 0.5]}, 
           ButtonData -> {
             URL["http://demonstrations.wolfram.com/guidelines.php"], None}], 
          ".", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "990970f3-a922-4bea-919a-d6fa2da1f6d5"]
}], "AuthorSection",
 CellTags->
  "Authoring \
Information",ExpressionUUID->"c2736cdb-c24c-4dd4-9a22-5bbef1a7a20a"],

Cell["Contributed by: Julie C. La Corte, Georgia State University", "Author",
 CellChangeTimes->{
  3.35696210375764*^9, {3.432333043774981*^9, 3.432333045441087*^9}, 
   3.842014800162849*^9},ExpressionUUID->"e6a077c9-f528-4852-97e7-\
764f2f3a1895"]
}, Open  ]]
}, Open  ]]
},
ScreenStyleEnvironment->"DemonstrationSource",
WindowSize->{852, 747},
WindowMargins->{{Automatic, 203}, {Automatic, 0}},
TaggingRules->{
 "DocuToolsSettingsInternal" -> {
   "$PacletVersion" -> "0.10.2121", "$MVersion" -> "12", "$FlaggedVersion" -> 
    11.3, "$ApplicationName" -> "Pubs", "$LinkBase" -> "Pubs", 
    "$ApplicationDirectory" -> "C:\\Users\\jayw\\Desktop\\CVSTree\\Pubs\\", 
    "$DocumentationDirectory" -> 
    "C:\\Users\\jayw\\Desktop\\CVSTree\\Pubs\\Documentation\\English\\", 
    "$UseNewPageDialog" -> "False", "$CondensedBlogMenus" -> "True"}, 
  "PresenterSettings" -> {
   "OutlineThumbnails" -> {"1" -> "Thumbnail"}, 
    "OutlinePalette" -> {"Thumbnails" -> {}, "ThumbnailMagnification" -> 0.8},
     "SideNotesPalette" -> {"PaletteNumber" -> 0}}, "BlogsDirectory" -> 
  "\\\\wrisync02.wri.wolfram.com\\backup$\\jayw\\My \
Documents\\jaywstasks\\BlogTools\\Blogs\\", "ChatNotebookID" -> 
  "fef9786d-4748-42a0-a328-5496e837f205", "Originator" -> 
  "chatframework@wolfram.com", "ScreenName" -> "", "ChatCreationDate" -> 
  "DateObject[{2018, 6, 18, 13, 5, 54.5673134}, Instant, Gregorian, -5.]", 
  "CustomWindowTitle" -> "None", "ChatNotebookDate" -> "18 Jun 2018 13:05:54",
   "ChatNotebookWindowTitle" -> "chatframework's Chat - (18 Jun 2018 13:05)", 
  "Participants" -> {"chatframework@wolfram.com", "wan4ren2jie2@gmail.com"}, 
  "AllParticipants" -> {
   "chatframework@wolfram.com", "wan4ren2jie2@gmail.com"}, 
  "Contacts" -> {
   "andre@wolfram.com", "bradym@wolfram.com", "brianv@wolfram.com", 
    "jayw@wolfram.com", "wan4ren2jie2@gmail.com"}, 
  "EmailListData" -> {0, 0, 0, 0, 1}, "ScrollLock" -> False, "Terminated" -> 
  True, "QuestionState" -> "Timeup", 
  "AttachedCells" -> {
   "Initialization Code" -> None, "Manipulate" -> None, "Caption" -> None, 
    "Snapshots" -> None, "Details" -> None, "Related Links" -> None, 
    "Search Terms" -> None, "Control Suggestions" -> None, "Thumbnail" -> 
    None, "Authoring Information" -> None}},
FrontEndVersion->"12.1 for Mac OS X x86 (64-bit) (June 19, 2020)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Demonstration.nb", 
  CharacterEncoding -> "UTF-8"],
ExpressionUUID->"20d36a69-2317-4a77-8f54-30f5ce6e1be0"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Initialization Code"->{
  Cell[897, 29, 1833, 39, 68, "InitializationSection",ExpressionUUID->"1d34a731-8c48-4189-8b6f-89ef5777db9f",
   CellTags->"Initialization Code"]},
 "Manipulate"->{
  Cell[2755, 72, 1524, 30, 68, "ManipulateSection",ExpressionUUID->"b7acceb9-ca4b-4965-b319-bd8a6214a587",
   CellTags->"Manipulate"]},
 "Caption"->{
  Cell[36843, 742, 1138, 24, 68, "ManipulateCaptionSection",ExpressionUUID->"3ed78bfd-4459-4d2a-906f-3e9e6aba33a4",
   CellTags->"Caption"]},
 "Thumbnail"->{
  Cell[38251, 778, 1016, 23, 68, "ThumbnailSection",ExpressionUUID->"401cc3c4-8319-4e19-82e7-df5fcb711a42",
   CellTags->"Thumbnail"]},
 "Snapshots"->{
  Cell[65354, 1273, 1018, 22, 68, "SnapshotsSection",ExpressionUUID->"96bb7a68-4496-4362-86d3-c2a0812907f2",
   CellTags->"Snapshots"]},
 "Details"->{
  Cell[155525, 2842, 1796, 36, 68, "DetailsSection",ExpressionUUID->"b9971572-9357-4ce2-a011-62ff9eede7fa",
   CellTags->"Details"]},
 "Control Suggestions"->{
  Cell[157854, 2901, 1131, 28, 68, "ControlSuggestionsSection",ExpressionUUID->"af8a4061-fdd4-44d0-82cc-9fec786547ab",
   CellTags->"Control Suggestions"]},
 "ResizeImages"->{
  Cell[158988, 2931, 410, 10, 29, "ControlSuggestions",ExpressionUUID->"ac542041-3d26-42bf-920d-b54a74785eef",
   CellTags->"ResizeImages"]},
 "RotateAndZoomIn3D"->{
  Cell[159401, 2943, 783, 19, 29, "ControlSuggestions",ExpressionUUID->"e14e98ed-7514-4081-99ea-c2ffb624df9b",
   CellTags->"RotateAndZoomIn3D"]},
 "DragLocators"->{
  Cell[160187, 2964, 438, 13, 29, "ControlSuggestions",ExpressionUUID->"384b79dc-c11a-492d-87e1-2c4b84403891",
   CellTags->"DragLocators"]},
 "CreateAndDeleteLocators"->{
  Cell[160628, 2979, 739, 18, 29, "ControlSuggestions",ExpressionUUID->"98a81657-e34e-4dab-ac86-717d7eff050a",
   CellTags->"CreateAndDeleteLocators"]},
 "SliderZoom"->{
  Cell[161370, 2999, 944, 23, 29, "ControlSuggestions",ExpressionUUID->"b84ac2ce-e422-4d4d-953e-073d63c15a9e",
   CellTags->"SliderZoom"]},
 "GamepadControls"->{
  Cell[162317, 3024, 469, 11, 29, "ControlSuggestions",ExpressionUUID->"b4dbde82-29d9-4853-88cd-e053ae8d181c",
   CellTags->"GamepadControls"]},
 "AutomaticAnimation"->{
  Cell[162789, 3037, 1564, 33, 29, "ControlSuggestions",ExpressionUUID->"6e84bbe0-7d8e-44ab-aac1-048973c18d4f",
   CellTags->"AutomaticAnimation"]},
 "BookmarkAnimation"->{
  Cell[164356, 3072, 1008, 23, 29, "ControlSuggestions",ExpressionUUID->"0cf5a50d-6c0e-4089-a29f-941bc4ca8891",
   CellTags->"BookmarkAnimation"]},
 "Search Terms"->{
  Cell[165401, 3100, 1073, 24, 68, "SearchTermsSection",ExpressionUUID->"a3a3a6a7-7876-4115-a51a-6d092bee139b",
   CellTags->"Search Terms"]},
 "Related Links"->{
  Cell[166847, 3135, 1191, 28, 68, "RelatedLinksSection",ExpressionUUID->"83b0243b-b7e3-4afb-8a4e-185fec8161fe",
   CellTags->"Related Links"]},
 "Authoring Information"->{
  Cell[168063, 3167, 1158, 28, 68, "AuthorSection",ExpressionUUID->"c2736cdb-c24c-4dd4-9a22-5bbef1a7a20a",
   CellTags->"Authoring Information"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Initialization Code", 171844, 3250},
 {"Manipulate", 172009, 3253},
 {"Caption", 172159, 3256},
 {"Thumbnail", 172317, 3259},
 {"Snapshots", 172469, 3262},
 {"Details", 172620, 3265},
 {"Control Suggestions", 172780, 3268},
 {"ResizeImages", 172956, 3271},
 {"RotateAndZoomIn3D", 173122, 3274},
 {"DragLocators", 173288, 3277},
 {"CreateAndDeleteLocators", 173460, 3280},
 {"SliderZoom", 173630, 3283},
 {"GamepadControls", 173792, 3286},
 {"AutomaticAnimation", 173962, 3289},
 {"BookmarkAnimation", 174135, 3292},
 {"Search Terms", 174302, 3295},
 {"Related Links", 174465, 3298},
 {"Authoring Information", 174638, 3301}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 314, 5, 98, "Title",ExpressionUUID->"b9e6fe14-67c5-4f7d-9ec0-13c361826e91"],
Cell[897, 29, 1833, 39, 68, "InitializationSection",ExpressionUUID->"1d34a731-8c48-4189-8b6f-89ef5777db9f",
 CellTags->"Initialization Code"],
Cell[CellGroupData[{
Cell[2755, 72, 1524, 30, 68, "ManipulateSection",ExpressionUUID->"b7acceb9-ca4b-4965-b319-bd8a6214a587",
 CellTags->"Manipulate"],
Cell[CellGroupData[{
Cell[4304, 106, 25614, 498, 1104, "Input",ExpressionUUID->"1c8a51fe-61b3-446f-b3f3-b27c622b6763"],
Cell[29921, 606, 6873, 130, 451, "Output",ExpressionUUID->"81eb52a0-90bc-44dc-b56f-03eea1ce13d4",
 CellID->708169245]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[36843, 742, 1138, 24, 68, "ManipulateCaptionSection",ExpressionUUID->"3ed78bfd-4459-4d2a-906f-3e9e6aba33a4",
 CellTags->"Caption"],
Cell[37984, 768, 230, 5, 23, "ManipulateCaption",ExpressionUUID->"71921e4e-c8c2-4f05-96e3-4e3047349e9a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[38251, 778, 1016, 23, 68, "ThumbnailSection",ExpressionUUID->"401cc3c4-8319-4e19-82e7-df5fcb711a42",
 CellTags->"Thumbnail"],
Cell[39270, 803, 26047, 465, 198, "Output",ExpressionUUID->"58c040db-333b-4c73-bea5-902ccd2013e9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[65354, 1273, 1018, 22, 68, "SnapshotsSection",ExpressionUUID->"96bb7a68-4496-4362-86d3-c2a0812907f2",
 CellTags->"Snapshots"],
Cell[66375, 1297, 89113, 1540, 746, "Output",ExpressionUUID->"28ce2d21-e862-4a50-b19b-1b190171b769",
 CellID->835389362]
}, Open  ]],
Cell[CellGroupData[{
Cell[155525, 2842, 1796, 36, 68, "DetailsSection",ExpressionUUID->"b9971572-9357-4ce2-a011-62ff9eede7fa",
 CellTags->"Details"],
Cell[157324, 2880, 493, 16, 39, "DemoNotes",ExpressionUUID->"85398564-2ab9-4890-987b-6687a7c114c4",
 CellID->1361039527]
}, Open  ]],
Cell[CellGroupData[{
Cell[157854, 2901, 1131, 28, 68, "ControlSuggestionsSection",ExpressionUUID->"af8a4061-fdd4-44d0-82cc-9fec786547ab",
 CellTags->"Control Suggestions"],
Cell[158988, 2931, 410, 10, 29, "ControlSuggestions",ExpressionUUID->"ac542041-3d26-42bf-920d-b54a74785eef",
 CellTags->"ResizeImages"],
Cell[159401, 2943, 783, 19, 29, "ControlSuggestions",ExpressionUUID->"e14e98ed-7514-4081-99ea-c2ffb624df9b",
 CellTags->"RotateAndZoomIn3D"],
Cell[160187, 2964, 438, 13, 29, "ControlSuggestions",ExpressionUUID->"384b79dc-c11a-492d-87e1-2c4b84403891",
 CellTags->"DragLocators"],
Cell[160628, 2979, 739, 18, 29, "ControlSuggestions",ExpressionUUID->"98a81657-e34e-4dab-ac86-717d7eff050a",
 CellTags->"CreateAndDeleteLocators"],
Cell[161370, 2999, 944, 23, 29, "ControlSuggestions",ExpressionUUID->"b84ac2ce-e422-4d4d-953e-073d63c15a9e",
 CellTags->"SliderZoom"],
Cell[162317, 3024, 469, 11, 29, "ControlSuggestions",ExpressionUUID->"b4dbde82-29d9-4853-88cd-e053ae8d181c",
 CellTags->"GamepadControls"],
Cell[162789, 3037, 1564, 33, 29, "ControlSuggestions",ExpressionUUID->"6e84bbe0-7d8e-44ab-aac1-048973c18d4f",
 CellTags->"AutomaticAnimation"],
Cell[164356, 3072, 1008, 23, 29, "ControlSuggestions",ExpressionUUID->"0cf5a50d-6c0e-4089-a29f-941bc4ca8891",
 CellTags->"BookmarkAnimation"]
}, Open  ]],
Cell[CellGroupData[{
Cell[165401, 3100, 1073, 24, 68, "SearchTermsSection",ExpressionUUID->"a3a3a6a7-7876-4115-a51a-6d092bee139b",
 CellTags->"Search Terms"],
Cell[166477, 3126, 176, 2, 23, "SearchTerms",ExpressionUUID->"0bc42057-771d-4239-8a27-f3a28e8e1d84",
 CellID->763001907],
Cell[166656, 3130, 176, 2, 23, "SearchTerms",ExpressionUUID->"d57e09dc-efcd-4c5d-a17a-82060fce9f7c",
 CellID->890928401]
}, Open  ]],
Cell[166847, 3135, 1191, 28, 68, "RelatedLinksSection",ExpressionUUID->"83b0243b-b7e3-4afb-8a4e-185fec8161fe",
 CellTags->"Related Links"],
Cell[CellGroupData[{
Cell[168063, 3167, 1158, 28, 68, "AuthorSection",ExpressionUUID->"c2736cdb-c24c-4dd4-9a22-5bbef1a7a20a",
 CellTags->"Authoring Information"],
Cell[169224, 3197, 250, 4, 23, "Author",ExpressionUUID->"e6a077c9-f528-4852-97e7-764f2f3a1895"]
}, Open  ]]
}, Open  ]]
}
]
*)

